@@ -37,13 +37,6 @@
 
 ResizeGesture::ResizeGesture (CanvasMode* parent) : CanvasGesture(parent)
 {
-	m_handle = Canvas::INSIDE;
-	m_rotation = 0.0;
-	m_origRatio = 1.0;
-	m_extraWidth = 0.0;
-	m_extraHeight = 0.0;
-	m_extraX = 0.0;
-	m_extraY = 0.0;
 	m_transaction = UndoTransaction();
 }
 
@@ -52,7 +45,7 @@ void ResizeGesture::prepare(Canvas::FrameHandle framehandle)
 	if (framehandle > 0)
 		m_handle = framehandle;
 	
-	if (m_doc->m_Selection->count() == 0)
+	if (m_doc->m_Selection->isEmpty())
 	{
 		m_handle = Canvas::OUTSIDE;
 		return;
@@ -63,7 +56,7 @@ void ResizeGesture::prepare(Canvas::FrameHandle framehandle)
 		m_doc->m_Selection->getGroupRect(&ex, &ey, &ew, &eh);
 		double gx, gy, gh, gw;
 		m_doc->m_Selection->getVisualGroupRect(&gx, &gy, &gw, &gh);
-		m_bounds = QRectF(QPointF(gx,gy), QSizeF(gw, gh));
+		m_bounds = QRectF(QPointF(gx, gy), QSizeF(gw, gh));
 		m_rotation = 0.0;
 		m_extraX = ex - gx;
 		m_extraY = ey - gy;
@@ -114,20 +107,19 @@ void ResizeGesture::clear()
 	}
 }
 
-void ResizeGesture::activate(bool flag)
+void ResizeGesture::activate(bool fromGesture)
 {
+	CanvasGesture::activate(fromGesture);
 }
 
 
-
-void ResizeGesture::deactivate(bool forgesture)
+void ResizeGesture::deactivate(bool forGesture)
 {
-	if (!forgesture)
+	if (!forGesture)
 		clear();
+	CanvasGesture::deactivate(forGesture);
 }
 
-
-
 void ResizeGesture::drawControls(QPainter* p) 
 {
 	QColor drawColor = qApp->palette().color(QPalette::Active, QPalette::Highlight);
@@ -176,13 +168,10 @@ void ResizeGesture::drawControls(QPainter* p)
 			}
 			QPainterPath clip = m.map(currItem->PoLine.toQPainterPath(false));
 			p->drawPath(clip);
-		//	QPolygon clip = m.map(currItem->Clip);
-		//	currItem->DrawPolyL(p, clip);
 		}
 		else if (m_doc->m_Selection->isMultipleSelection())
 		{
 			double x, y, w, h;
-			m_doc->m_Selection->setGroupRect();
 			m_doc->m_Selection->getGroupRect(&x, &y, &w, &h);
 			double scx = localRect.width() / w;
 			double scy = localRect.height() / h;
@@ -203,8 +192,6 @@ void ResizeGesture::drawControls(QPainter* p)
 						m.rotate(currItem->rotation());
 					QPainterPath clip = m.map(currItem->PoLine.toQPainterPath(false));
 					p->drawPath(clip);
-				//	QPolygon clip = m.map(currItem->Clip);
-				//	currItem->DrawPolyL(p, clip);
 				}
 			}
 		}
@@ -224,7 +211,7 @@ void ResizeGesture::mouseReleaseEvent(QMouseEvent *m)
 		{
 			doResize(m->modifiers() & Qt::AltModifier);
 			m_doc->setRedrawBounding(currItem);
-			if (currItem->asImageFrame())
+			if (currItem->isImageFrame())
 				currItem->adjustPictScale();
 		}
 		//add action itemResizeToMargin for right click on item`s handlers
@@ -286,7 +273,7 @@ void ResizeGesture::doResize(bool scaleContent)
 	}
 	if (m_doc->m_Selection->isMultipleSelection())
 	{
-		int RotModeBack = m_doc->rotationMode();
+		int oldRotMode = m_doc->rotationMode();
 		m_doc->setRotationMode ( 0 );
 		double gx, gy, gh, gw;
 		m_doc->m_Selection->getGroupRect(&gx, &gy, &gw, &gh);
@@ -302,7 +289,7 @@ void ResizeGesture::doResize(bool scaleContent)
 		double dy = newBounds.y() - oldBounds.y();
 		if (dx != 0 || dy != 0)
 			m_doc->moveGroup(dx + m_extraX, dy + m_extraY);
-		m_doc->setRotationMode ( RotModeBack );
+		m_doc->setRotationMode(oldRotMode);
 	}
 	else
 	{
@@ -467,7 +454,6 @@ void ResizeGesture::adjustBounds(QMouseEvent *m)
 {
 	QTransform rotation;
 	FPoint docPoint = m_canvas->globalToCanvas(m->globalPos());
-	QPointF oldXY = m_bounds.topLeft();
 
 	// proportional resize
 	bool constrainRatio = ((m->modifiers() & Qt::ControlModifier) != Qt::NoModifier);
@@ -514,9 +500,10 @@ void ResizeGesture::adjustBounds(QMouseEvent *m)
 	if (m_rotation != 0)
 	{
 		// rotate point around item position
-		rotation.translate(m_bounds.x(), m_bounds.y());
+		QRectF normalizedBounds = m_bounds.normalized();
+		rotation.translate(normalizedBounds.x(), normalizedBounds.y());
 		rotation.rotate(m_rotation);
-		rotation.translate(-m_bounds.x(), -m_bounds.y());
+		rotation.translate(-normalizedBounds.x(), -normalizedBounds.y());
 //		qDebug() << "resize rotated" << m_rotation << "°" << m_bounds << rotation << ":" << point-globalBounds.topLeft() << "-->" << rotation.map(point)-globalBounds.topLeft();
 		QPointF qp = QPointF(docPoint.x(), docPoint.y());
 		qp = rotation.inverted().map(qp);
@@ -579,7 +566,7 @@ void ResizeGesture::adjustBounds(QMouseEvent *m)
 //				qDebug() << "NORTHWEST" << point << m_origBounds.topLeft() << m_origRatio
 //				<< (point.x() - m_origBounds.left() < (point.y()-m_origBounds.top()) * m_origRatio);
 				
-				if (docPoint.x() - m_origBounds.left() < (docPoint.y()-m_origBounds.top()) * m_origRatio)
+				if (docPoint.x() - m_origBounds.left() < (docPoint.y() - m_origBounds.top()) * m_origRatio)
 					m_bounds.setTop(m_bounds.top() - newHeight + m_bounds.height());
 				else
 					m_bounds.setLeft(m_bounds.left() - newWidth + m_bounds.width());
@@ -608,7 +595,7 @@ void ResizeGesture::adjustBounds(QMouseEvent *m)
 				break;
 			case Canvas::SOUTHEAST:
 				// cf. NORTHWEST
-				if (docPoint.x() - m_origBounds.left() > (docPoint.y()-m_origBounds.top()) * m_origRatio)
+				if (docPoint.x() - m_origBounds.left() > (docPoint.y() - m_origBounds.top()) * m_origRatio)
 					m_bounds.setHeight(newHeight);
 				else
 					m_bounds.setWidth(newWidth);
@@ -633,7 +620,7 @@ void ResizeGesture::adjustBounds(QMouseEvent *m)
 //		qDebug() << "constrained:" << m_bounds << double(m_bounds.width()) / m_bounds.height();
 	}
 
-	// shif key modifier
+	// shift key modifier
 	// move around around the pivot
 	if (centerPivot)
 		m_bounds.moveCenter(m_origBounds.center());
@@ -669,7 +656,7 @@ void ResizeGesture::adjustBounds(QMouseEvent *m)
 	}
 
 	// re-rotate: if top left has changed, then it needs rotation
-	if (m_rotation != 0 && oldXY != m_bounds.topLeft())
+	if (m_rotation != 0)
 	{
 		m_bounds.moveTo(rotation.map(m_bounds.topLeft()));
 		// fix opposite corner to avoid aggregating rounding errors
@@ -681,40 +668,41 @@ void ResizeGesture::adjustBounds(QMouseEvent *m)
 				newFixPoint = m_bounds.bottomRight();
 				break;
 			case Canvas::WEST:
-				origFixPoint = m_origBounds.topRight() + QPointF(0, m_origBounds.height()/2);
-				newFixPoint = m_bounds.topRight() + QPointF(0, m_bounds.height()/2);
+				origFixPoint = m_origBounds.topRight() + QPointF(0, m_origBounds.height() / 2);
+				newFixPoint = m_bounds.topRight() + QPointF(0, m_bounds.height() / 2);
 				break;
 			case Canvas::SOUTHWEST:
 				origFixPoint = m_origBounds.topRight();
 				newFixPoint = m_bounds.topRight();
 				break;
 			case Canvas::SOUTH:
-				origFixPoint = m_origBounds.topLeft() + QPointF(m_origBounds.width()/2, 0);
-				newFixPoint = m_bounds.topLeft() + QPointF(m_bounds.width()/2, 0);
+				origFixPoint = m_origBounds.topLeft() + QPointF(m_origBounds.width() / 2, 0);
+				newFixPoint = m_bounds.topLeft() + QPointF(m_bounds.width() / 2, 0);
 				break;
 			case Canvas::SOUTHEAST:
 				origFixPoint = m_origBounds.topLeft();
 				newFixPoint = m_bounds.topLeft();
 				break;
 			case Canvas::EAST:
-				origFixPoint = m_origBounds.topLeft() + QPointF(0, m_origBounds.height()/2);
-				newFixPoint = m_bounds.topLeft() + QPointF(0, m_bounds.height()/2);
+				origFixPoint = m_origBounds.topLeft() + QPointF(0, m_origBounds.height() / 2);
+				newFixPoint = m_bounds.topLeft() + QPointF(0, m_bounds.height() / 2);
 				break;
 			case Canvas::NORTHEAST:
 				origFixPoint = m_origBounds.bottomLeft();
 				newFixPoint = m_bounds.bottomLeft();
 				break;
 			case Canvas::NORTH:
-				origFixPoint = m_origBounds.bottomLeft() + QPointF(m_origBounds.width()/2, 0);
-				newFixPoint = m_bounds.bottomLeft() + QPointF(m_bounds.width()/2, 0);
+				origFixPoint = m_origBounds.bottomLeft() + QPointF(m_origBounds.width() / 2, 0);
+				newFixPoint = m_bounds.bottomLeft() + QPointF(m_bounds.width() / 2, 0);
 				break;
 			default:
 				origFixPoint = m_origBounds.topLeft();
 				newFixPoint = m_bounds.topLeft();
 				break;
 		}
+		QRectF normalizedBounds = m_bounds.normalized();
 		origFixPoint = m_origBounds.topLeft() + rotation.map(origFixPoint - m_origBounds.topLeft());
-		newFixPoint = m_bounds.topLeft() + rotation.map(newFixPoint - m_bounds.topLeft());
+		newFixPoint = normalizedBounds.topLeft() + rotation.map(newFixPoint - normalizedBounds.topLeft());
 		if (origFixPoint != newFixPoint)
 			m_bounds.translate(origFixPoint - newFixPoint);
 	}
@@ -962,7 +950,7 @@ void ResizeGesture::mousePressEvent(QMouseEvent *m)
 {
 	FPoint point = m_canvas->globalToCanvas(m->globalPos());
 	m_mousePressPoint = m->globalPos();
-	if (m_doc->m_Selection->count() == 0)
+	if (m_doc->m_Selection->isEmpty())
 	{
 		m_handle = Canvas::OUTSIDE;
 	}
