@@ -834,7 +834,7 @@ void CanvasMode::setResizeCursor(int how, double rot)
 bool CanvasMode::commonMouseMove(QMouseEvent *m)
 {
 	//m_mousePointDoc = m_canvas->globalToCanvas(m->globalPos());
-	if ((m_canvas->m_viewMode.m_MouseButtonPressed && (m->buttons() & Qt::RightButton) && (m->modifiers() & Qt::ControlModifier)) || ((!(m->modifiers() & Qt::ControlModifier)) && (m->buttons() & Qt::MidButton)))
+	if ((m_canvas->m_viewMode.m_MouseButtonPressed && (m->buttons() & Qt::RightButton) && (m->modifiers() & Qt::ControlModifier)) || ((!(m->modifiers() & Qt::ControlModifier)) && (m->buttons() & Qt::MiddleButton)))
 	{
 		if (!m_panGesture)
 		{
@@ -932,11 +932,11 @@ void CanvasMode::commonkeyPressEvent_Default(QKeyEvent *e)
 				case modeCopyProperties:
 				case modeEditGradientVectors:
 				case modeEditMeshGradient:
-				case modeLinkFrames:
-				case modeUnlinkFrames:
 				case modeRotation:
 					m_view->deselectItems(false);
 					/* fall through */
+				case modeLinkFrames:
+				case modeUnlinkFrames:
 				case modeEditWeldPoint:
 				case modeEyeDropper:
 				case modeImportObject:
