@@ -109,8 +109,6 @@ void CalligraphicMode::mouseMoveEvent(QMouseEvent *m)
 	const FPoint mousePointDoc = m_canvas->globalToCanvas(m->globalPos());
 	
 	PageItem *currItem;
-	FPoint npf, npf2;
-//	QRect tx;
 	m->accept();
 	m_canvas->displayCorrectedXYHUD(m->globalPos(), mousePointDoc.x(), mousePointDoc.y());
 
@@ -184,7 +182,6 @@ void CalligraphicMode::mousePressEvent(QMouseEvent *m)
 	const FPoint mousePointDoc = m_canvas->globalToCanvas(m->globalPos());
 	double Rxp = 0;
 	double Ryp = 0;
-	FPoint npf, npf2;
 	QTransform pm;
 
 	m_mouseButtonPressed = true;
@@ -202,7 +199,7 @@ void CalligraphicMode::mousePressEvent(QMouseEvent *m)
 	m_xp = qRound(Rxp);
 	Ryp = m_doc->ApplyGridF(FPoint(m_xp, m_yp)).y();
 	m_yp = qRound(Ryp);
-	if (m->button() == Qt::MidButton)
+	if (m->button() == Qt::MiddleButton)
 	{
 		m_view->MidButt = true;
 		if (m->modifiers() & Qt::ControlModifier)
