@@ -56,8 +56,7 @@
 
 CanvasMode_EditGradient::CanvasMode_EditGradient(ScribusView* view) : CanvasMode(view), m_ScMW(view->m_ScMW) 
 {
-	m_Mxp = m_Myp = -1;
-	m_gradientPoint = noPointDefined;
+
 }
 
 inline bool CanvasMode_EditGradient::GetItem(PageItem** pi)
@@ -113,7 +112,7 @@ void CanvasMode_EditGradient::drawControlsGradientVectors(QPainter* psx, PageIte
 		qmatrix.translate(0, currItem->GrStrokeStartY * (1.0 - currItem->GrStrokeScale));
 		qmatrix.translate(-currItem->GrStrokeStartX, -currItem->GrStrokeStartY);
 		qmatrix.scale(1, currItem->GrStrokeScale);
-		if (currItem->GrTypeStroke == 7)
+		if (currItem->GrTypeStroke == Gradient_Radial)
 			psx->drawPoint(qmatrix.map(QPointF(currItem->GrStrokeFocalX, currItem->GrStrokeFocalY)));
 		QTransform m;
 		m.translate(currItem->GrStrokeStartX, currItem->GrStrokeStartY);
@@ -153,7 +152,7 @@ void CanvasMode_EditGradient::drawControlsGradientVectors(QPainter* psx, PageIte
 		qmatrix.translate(0, currItem->GrMaskStartY * (1.0 - currItem->GrMaskScale));
 		qmatrix.translate(-currItem->GrMaskStartX, -currItem->GrMaskStartY);
 		qmatrix.scale(1, currItem->GrMaskScale);
-		if ((currItem->GrMask == 2) || (currItem->GrMask == 5))
+		if ((currItem->GrMask == GradMask_Radial) || (currItem->GrMask == GradMask_RadialLumAlpha))
 			psx->drawPoint(qmatrix.map(QPointF(currItem->GrMaskFocalX, currItem->GrMaskFocalY)));
 		QTransform m;
 		m.translate(currItem->GrMaskStartX, currItem->GrMaskStartY);
@@ -178,7 +177,7 @@ void CanvasMode_EditGradient::drawControlsGradientVectors(QPainter* psx, PageIte
 		QTransform qmatrix;
 		qmatrix.translate(currItem->GrStartX, currItem->GrStartY);
 		qmatrix.rotate(rotEnd);
-		if (currItem->GrType != 13)
+		if (currItem->GrType != Gradient_Conical)
 		{
 			double mask_gradientSkew = 0.0;
 			if (currItem->GrSkew == 90)
@@ -196,7 +195,7 @@ void CanvasMode_EditGradient::drawControlsGradientVectors(QPainter* psx, PageIte
 		qmatrix.translate(0, currItem->GrStartY * (1.0 - currItem->GrScale));
 		qmatrix.translate(-currItem->GrStartX, -currItem->GrStartY);
 		qmatrix.scale(1, currItem->GrScale);
-		if ((currItem->GrType == 7) || (currItem->GrType == 13))
+		if ((currItem->GrType == Gradient_Radial) || (currItem->GrType == Gradient_Conical))
 			psx->drawPoint(qmatrix.map(QPointF(currItem->GrFocalX, currItem->GrFocalY)));
 		QTransform m;
 		m.translate(currItem->GrStartX, currItem->GrStartY);
@@ -229,7 +228,7 @@ void CanvasMode_EditGradient::drawControlsGradientVectors(QPainter* psx, PageIte
 	}
 }
 
-void CanvasMode_EditGradient::enterEvent(QEvent *)
+void CanvasMode_EditGradient::enterEvent(QEvent* /*e*/)
 {
 	if (!m_canvas->m_viewMode.m_MouseButtonPressed)
 	{
@@ -237,7 +236,7 @@ void CanvasMode_EditGradient::enterEvent(QEvent *)
 	}
 }
 
-void CanvasMode_EditGradient::leaveEvent(QEvent *e)
+void CanvasMode_EditGradient::leaveEvent(QEvent* /*e*/)
 {
 }
 
@@ -245,6 +244,8 @@ void CanvasMode_EditGradient::leaveEvent(QEvent *e)
 void CanvasMode_EditGradient::activate(bool fromGesture)
 {
 //	qDebug() << "CanvasMode_EditGradient::activate" << fromGesture;
+	CanvasMode::activate(fromGesture);
+
 	m_canvas->m_viewMode.m_MouseButtonPressed = false;
 	m_canvas->resetRenderMode();
 	m_doc->DragP = false;
@@ -264,6 +265,17 @@ void CanvasMode_EditGradient::deactivate(bool forGesture)
 {
 //	qDebug() << "CanvasMode_EditGradient::deactivate" << forGesture;
 	m_view->setRedrawMarkerShown(false);
+	CanvasMode::deactivate(forGesture);
+}
+
+void CanvasMode_EditGradient::keyPressEvent(QKeyEvent *e)
+{
+	commonkeyPressEvent_Default(e);
+}
+
+void CanvasMode_EditGradient::keyReleaseEvent(QKeyEvent *e)
+{
+	commonkeyReleaseEvent(e);
 }
 
 void CanvasMode_EditGradient::mouseDoubleClickEvent(QMouseEvent *m)
@@ -294,7 +306,7 @@ void CanvasMode_EditGradient::mouseDoubleClickEvent(QMouseEvent *m)
 			}
 			return;
 		}
-		if (!(GetItem(&currItem) && (m_doc->appMode == modeEdit) && currItem->asTextFrame()))
+		if (!(GetItem(&currItem) && (m_doc->appMode == modeEdit) && currItem->isTextFrame()))
 		{
 			mousePressEvent(m);
 			return;
@@ -302,7 +314,6 @@ void CanvasMode_EditGradient::mouseDoubleClickEvent(QMouseEvent *m)
 	}
 }
 
-
 void CanvasMode_EditGradient::mouseMoveEvent(QMouseEvent *m)
 {
 	const FPoint mousePointDoc = m_canvas->globalToCanvas(m->globalPos());
@@ -420,7 +431,7 @@ void CanvasMode_EditGradient::mouseMoveEvent(QMouseEvent *m)
 				currItem->GrMaskStartY -= np.y();
 				currItem->GrMaskFocalX -= np.x();
 				currItem->GrMaskFocalY -= np.y();
-				if ((currItem->GrMask == 2) || (currItem->GrMask == 5))
+				if ((currItem->GrMask == GradMask_Radial) || (currItem->GrMask == GradMask_RadialLumAlpha))
 				{
 					double radEnd = distance(currItem->GrMaskEndX - currItem->GrMaskStartX, currItem->GrMaskEndY - currItem->GrMaskStartY);
 					double radFoc = distance(currItem->GrMaskFocalX - currItem->GrMaskStartX, currItem->GrMaskFocalY - currItem->GrMaskStartY);
@@ -459,7 +470,7 @@ void CanvasMode_EditGradient::mouseMoveEvent(QMouseEvent *m)
 				QPointF shRe = m.map(shR - np);
 				currItem->GrMaskFocalX = shRe.x();
 				currItem->GrMaskFocalY = shRe.y();
-				if ((currItem->GrMask == 2) || (currItem->GrMask == 5))
+				if ((currItem->GrMask == GradMask_Radial) || (currItem->GrMask == GradMask_RadialLumAlpha))
 				{
 					double radEnd = distance(currItem->GrMaskEndX - currItem->GrMaskStartX, currItem->GrMaskEndY - currItem->GrMaskStartY);
 					double radFoc = distance(currItem->GrMaskFocalX - currItem->GrMaskStartX, currItem->GrMaskFocalY - currItem->GrMaskStartY);
@@ -495,7 +506,7 @@ void CanvasMode_EditGradient::mouseMoveEvent(QMouseEvent *m)
 			{
 				currItem->GrMaskEndX -= np.x();
 				currItem->GrMaskEndY -= np.y();
-				if ((currItem->GrMask == 2) || (currItem->GrMask == 5))
+				if ((currItem->GrMask == GradMask_Radial) || (currItem->GrMask == GradMask_RadialLumAlpha))
 				{
 					double radEnd = distance(currItem->GrMaskEndX - currItem->GrMaskStartX, currItem->GrMaskEndY - currItem->GrMaskStartY);
 					double radFoc = distance(currItem->GrMaskFocalX - currItem->GrMaskStartX, currItem->GrMaskFocalY - currItem->GrMaskStartY);
@@ -534,7 +545,7 @@ void CanvasMode_EditGradient::mouseMoveEvent(QMouseEvent *m)
 				QTransform qmatrix;
 				qmatrix.translate(currItem->GrStartX, currItem->GrStartY);
 				qmatrix.rotate(rotEnd);
-				if (currItem->GrType != 13)
+				if (currItem->GrType != Gradient_Conical)
 				{
 					double mask_gradientSkew = 0.0;
 					if (currItem->GrSkew == 90)
@@ -557,7 +568,7 @@ void CanvasMode_EditGradient::mouseMoveEvent(QMouseEvent *m)
 				QPointF shRe = m.map(shR - np);
 				currItem->GrFocalX = shRe.x();
 				currItem->GrFocalY = shRe.y();
-				if ((currItem->GrType == 7) || (currItem->GrType == 13))
+				if ((currItem->GrType == Gradient_Radial) || (currItem->GrType == Gradient_Conical))
 				{
 					double radEnd = distance(currItem->GrEndX - currItem->GrStartX, currItem->GrEndY - currItem->GrStartY);
 					double radFoc = distance(currItem->GrFocalX - currItem->GrStartX, currItem->GrFocalY - currItem->GrStartY);
@@ -578,14 +589,14 @@ void CanvasMode_EditGradient::mouseMoveEvent(QMouseEvent *m)
 				m.translate(currItem->GrStartX, currItem->GrStartY);
 				m.rotate(rotEnd);
 				m.rotate(-90);
-				if (currItem->GrType != 13)
+				if (currItem->GrType != Gradient_Conical)
 					m.rotate(currItem->GrSkew);
 				m.translate(radEnd * currItem->GrScale, 0);
 				QPointF shP = m.map(QPointF(0,0));
 				QPointF shR = QPointF(shP.x() -np.x(), shP.y() - np.y());
 				double radNew = distance(shR.x() - currItem->GrStartX, shR.y() - currItem->GrStartY);
 				double rotNew = xy2Deg(shR.x() - currItem->GrStartX, shR.y() - currItem->GrStartY) + 90;
-				if (currItem->GrType != 13)
+				if (currItem->GrType != Gradient_Conical)
 					currItem->GrSkew = rotNew - rotEnd;
 				else
 					currItem->GrSkew = 0;
@@ -597,7 +608,7 @@ void CanvasMode_EditGradient::mouseMoveEvent(QMouseEvent *m)
 			{
 				currItem->GrEndX -= np.x();
 				currItem->GrEndY -= np.y();
-				if ((currItem->GrType == 7) || (currItem->GrType == 13))
+				if ((currItem->GrType == Gradient_Radial) || (currItem->GrType == Gradient_Conical))
 				{
 					double radEnd = distance(currItem->GrEndX - currItem->GrStartX, currItem->GrEndY - currItem->GrStartY);
 					double radFoc = distance(currItem->GrFocalX - currItem->GrStartX, currItem->GrFocalY - currItem->GrStartY);
@@ -697,7 +708,7 @@ void CanvasMode_EditGradient::mouseMoveEvent(QMouseEvent *m)
 		QTransform itemMatrix = currItem->getTransform();
 		upRect = itemMatrix.mapRect(upRect);
 		m_doc->regionsChanged()->update(upRect.adjusted(-10.0, -10.0, 10.0, 10.0)); */
-		if (currItem->GrType == 13)
+		if (currItem->GrType == Gradient_Conical)
 			currItem->createConicalMesh();
 		m_doc->regionsChanged()->update(QRectF());
 	}
@@ -718,7 +729,7 @@ void CanvasMode_EditGradient::mousePressEvent(QMouseEvent *m)
 	m_gradientPoint = noPointDefined;
 	m_Mxp = mousePointDoc.x(); //m->x();
 	m_Myp = mousePointDoc.y(); //m->y();
-	if (m->button() == Qt::MidButton)
+	if (m->button() == Qt::MiddleButton)
 	{
 		m_view->MidButt = true;
 		if (m->modifiers() & Qt::ControlModifier)
@@ -810,7 +821,7 @@ void CanvasMode_EditGradient::mousePressEvent(QMouseEvent *m)
 		QTransform qmatrix;
 		qmatrix.translate(currItem->GrStartX, currItem->GrStartY);
 		qmatrix.rotate(rotEnd);
-		if (currItem->GrType != 13)
+		if (currItem->GrType != Gradient_Conical)
 		{
 			double mask_gradientSkew = 0.0;
 			if (currItem->GrSkew == 90)
@@ -923,32 +934,33 @@ void CanvasMode_EditGradient::mousePressEvent(QMouseEvent *m)
 void CanvasMode_EditGradient::mouseReleaseEvent(QMouseEvent *m)
 {
 #ifdef GESTURE_FRAME_PREVIEW
-        clearPixmapCache();
+	clearPixmapCache();
 #endif // GESTURE_FRAME_PREVIEW
 	m_canvas->m_viewMode.m_MouseButtonPressed = false;
 	m_canvas->resetRenderMode();
 	m->accept();
 	PageItem* currItem = m_doc->m_Selection->itemAt(0);
-	if (m_gradientPoint != noPointDefined && UndoManager::undoEnabled()){
+	if (m_gradientPoint != noPointDefined && UndoManager::undoEnabled())
+	{
 		QList<FPoint> tmp;
 		ScItemState<QList<FPoint> > *is = new ScItemState<QList<FPoint> >(Um::GradPos + "i");
 		is->set("GRAD_POS");
-		is->set("OLDSTARTX",OldGrStartX);
-		is->set("STARTX",currItem->gradientStartX());
-		is->set("OLDSTARTY",OldGrStartY);
-		is->set("STARTY",currItem->gradientStartY());
-		is->set("OLDENDX",OldGrEndX);
-		is->set("ENDX",currItem->gradientEndX());
-		is->set("OLDENDY",OldGrEndY);
-		is->set("ENDY",currItem->gradientEndY());
-		is->set("OLDFOCALX",OldGrFocalX);
-		is->set("FOCALX",currItem->gradientFocalX());
-		is->set("OLDFOCALY",OldGrFocalY);
-		is->set("FOCALY",currItem->gradientFocalY());
-		is->set("OLDSCALE",OldGrScale);
-		is->set("SCALE",currItem->gradientScale());
-		is->set("OLDSKEW",OldGrSkew);
-		is->set("SKEW",currItem->gradientSkew());
+		is->set("OLDSTARTX", OldGrStartX);
+		is->set("STARTX", currItem->gradientStartX());
+		is->set("OLDSTARTY", OldGrStartY);
+		is->set("STARTY", currItem->gradientStartY());
+		is->set("OLDENDX", OldGrEndX);
+		is->set("ENDX", currItem->gradientEndX());
+		is->set("OLDENDY", OldGrEndY);
+		is->set("ENDY", currItem->gradientEndY());
+		is->set("OLDFOCALX", OldGrFocalX);
+		is->set("FOCALX", currItem->gradientFocalX());
+		is->set("OLDFOCALY", OldGrFocalY);
+		is->set("FOCALY", currItem->gradientFocalY());
+		is->set("OLDSCALE", OldGrScale);
+		is->set("SCALE", currItem->gradientScale());
+		is->set("OLDSKEW", OldGrSkew);
+		is->set("SKEW", currItem->gradientSkew());
 		tmp.append(OldGrControl1);
 		tmp.append(currItem->gradientControl1());
 		tmp.append(OldGrControl2);
@@ -960,39 +972,39 @@ void CanvasMode_EditGradient::mouseReleaseEvent(QMouseEvent *m)
 		tmp.append(OldGrControl5);
 		tmp.append(currItem->gradientControl5());
 		is->setItem(tmp);
-		is->set("OLDSTROKESTARTX",OldGrStrokeStartX);
-		is->set("STROKESTARTX",currItem->gradientStrokeStartX());
-		is->set("OLDSTROKESTARTY",OldGrStrokeStartY);
-		is->set("STROKESTARTY",currItem->gradientStrokeStartY());
-		is->set("OLDSTROKEENDX",OldGrStrokeEndX);
-		is->set("STROKEENDX",currItem->gradientStrokeEndX());
-		is->set("OLDSTROKEENDY",OldGrStrokeEndY);
-		is->set("STROKEENDY",currItem->gradientStrokeEndY());
-		is->set("OLDSTROKEFOCALX",OldGrStrokeFocalX);
-		is->set("STROKEFOCALX",currItem->gradientStrokeFocalX());
-		is->set("OLDSTROKEFOCALY",OldGrStrokeFocalY);
-		is->set("STROKEFOCALY",currItem->gradientStrokeFocalY());
-		is->set("OLDSTROKESCALE",OldGrStrokeScale);
-		is->set("STROKESCALE",currItem->gradientStrokeScale());
-		is->set("OLDSTROKESKEW",OldGrStrokeSkew);
-		is->set("STROKESKEW",currItem->gradientStrokeSkew());
-		is->set("OLDMARKSTARTX",OldGrMaskStartX);
-		is->set("MARKSTARTX",currItem->GrMaskStartX);
-		is->set("OLDMARKSTARTY",OldGrMaskStartY);
-		is->set("MARKSTARTY",currItem->GrMaskStartY);
-		is->set("OLDMARKENDX",OldGrMaskEndX);
-		is->set("MARKENDX",currItem->GrMaskEndX);
-		is->set("OLDMARKENDY",OldGrMaskEndY);
-		is->set("MARKENDY",currItem->GrMaskEndY);
-		is->set("OLDMARKFOCALX",OldGrMaskFocalX);
-		is->set("MARKFOCALX",currItem->GrMaskFocalX);
-		is->set("OLDMARKFOCALY",OldGrMaskFocalY);
-		is->set("MARKFOCALY",currItem->GrMaskFocalY);
-		is->set("OLDMARKSCALE",OldGrMaskScale);
-		is->set("MARKSCALE",currItem->GrMaskScale);
-		is->set("OLDMARKSKEW",OldGrMaskSkew);
-		is->set("MARKSKEW",currItem->GrMaskSkew);
-		undoManager->action(currItem,is);
+		is->set("OLDSTROKESTARTX", OldGrStrokeStartX);
+		is->set("STROKESTARTX", currItem->gradientStrokeStartX());
+		is->set("OLDSTROKESTARTY", OldGrStrokeStartY);
+		is->set("STROKESTARTY", currItem->gradientStrokeStartY());
+		is->set("OLDSTROKEENDX", OldGrStrokeEndX);
+		is->set("STROKEENDX", currItem->gradientStrokeEndX());
+		is->set("OLDSTROKEENDY", OldGrStrokeEndY);
+		is->set("STROKEENDY", currItem->gradientStrokeEndY());
+		is->set("OLDSTROKEFOCALX", OldGrStrokeFocalX);
+		is->set("STROKEFOCALX", currItem->gradientStrokeFocalX());
+		is->set("OLDSTROKEFOCALY", OldGrStrokeFocalY);
+		is->set("STROKEFOCALY", currItem->gradientStrokeFocalY());
+		is->set("OLDSTROKESCALE", OldGrStrokeScale);
+		is->set("STROKESCALE", currItem->gradientStrokeScale());
+		is->set("OLDSTROKESKEW", OldGrStrokeSkew);
+		is->set("STROKESKEW", currItem->gradientStrokeSkew());
+		is->set("OLDMARKSTARTX", OldGrMaskStartX);
+		is->set("MARKSTARTX", currItem->GrMaskStartX);
+		is->set("OLDMARKSTARTY", OldGrMaskStartY);
+		is->set("MARKSTARTY", currItem->GrMaskStartY);
+		is->set("OLDMARKENDX", OldGrMaskEndX);
+		is->set("MARKENDX", currItem->GrMaskEndX);
+		is->set("OLDMARKENDY", OldGrMaskEndY);
+		is->set("MARKENDY", currItem->GrMaskEndY);
+		is->set("OLDMARKFOCALX", OldGrMaskFocalX);
+		is->set("MARKFOCALX", currItem->GrMaskFocalX);
+		is->set("OLDMARKFOCALY", OldGrMaskFocalY);
+		is->set("MARKFOCALY", currItem->GrMaskFocalY);
+		is->set("OLDMARKSCALE", OldGrMaskScale);
+		is->set("MARKSCALE", currItem->GrMaskScale);
+		is->set("OLDMARKSKEW", OldGrMaskSkew);
+		is->set("MARKSKEW", currItem->GrMaskSkew);
+		undoManager->action(currItem, is);
 	}
 	m_gradientPoint = noPointDefined;
 //	m_view->stopDragTimer();
