@@ -201,7 +201,7 @@ void CanvasMode_Normal::mouseDoubleClickEvent(QMouseEvent *m)
 				//mousePressEvent(m);
 				return;
 			}
-			//If we double click on an image frame and theres no image assigned, open the
+			//If we double click on an image frame and there's no image assigned, open the
 			//load picture dialog, else put it into edit mode if the frame is set to show the image
 			if (currItem->itemType() == PageItem::ImageFrame)
 			{
@@ -244,7 +244,7 @@ void CanvasMode_Normal::mouseDoubleClickEvent(QMouseEvent *m)
 				//if cursor is in mark`s place
 				m_ScMW->setTBvals(currItem);
 				//CB ignore the double click and go with a single one
-				//if we werent in mode edit before.
+				//if we weren't in mode edit before.
 				//unsure if this is correct, but its ok given we had no
 				//double click select until now.
 //				mousePressEvent(m);
@@ -757,7 +757,7 @@ void CanvasMode_Normal::mouseMoveEvent(QMouseEvent *m)
 				QTransform p;
 				m_canvas->Transform(currItem, p);
 				QRect mpo = QRect(m->x() - m_doc->guidesPrefs().grabRadius, m->y() - m_doc->guidesPrefs().grabRadius, m_doc->guidesPrefs().grabRadius * 2, m_doc->guidesPrefs().grabRadius * 2);
-				if ((QRegion(p.map(QPolygon(QRect(-3, -3, static_cast<int>(currItem->width() + 6), static_cast<int>(currItem->height() + 6))))).contains(mpo)))
+				if (QRegion(p.map(QPolygon(QRect(-3, -3, static_cast<int>(currItem->width() + 6), static_cast<int>(currItem->height() + 6))))).contains(mpo))
 				{
 					QRect tx = p.mapRect(QRect(0, 0, static_cast<int>(currItem->width()), static_cast<int>(currItem->height())));
 					if ((tx.intersects(mpo)) && (!currItem->locked()))
@@ -830,7 +830,7 @@ void CanvasMode_Normal::mousePressEvent(QMouseEvent *m)
 	m->accept();
 	m_view->registerMousePress(m->globalPos());
 
-	if (m->button() == Qt::MidButton)
+	if (m->button() == Qt::MiddleButton)
 	{
 		m_view->MidButt = true;
 		if (m->modifiers() & Qt::ControlModifier)
@@ -918,7 +918,7 @@ void CanvasMode_Normal::mousePressEvent(QMouseEvent *m)
 				m_canvas->setRenderModeFillBuffer();
 		}
 	}
-/*	if (m->button() == MidButton)
+/*	if (m->button() == MiddleButton)
 	{
 		MidButt = true;
 		if (m_doc->m_Selection->count() != 0)
