@@ -26,6 +26,13 @@ eColorSpaceType ScColorProfile::colorSpace() const
 	return ColorSpace_Unknown;
 }
 
+eColorSpaceType ScColorProfile::connectionSpace() const
+{
+	if (m_data)
+		return m_data->connectionSpace();
+	return ColorSpace_Unknown;
+}
+
 eProfileClass ScColorProfile::deviceClass() const
 {
 	if (m_data)
@@ -33,6 +40,34 @@ eProfileClass ScColorProfile::deviceClass() const
 	return Class_Unknown;
 }
 
+int ScColorProfile::channelsOfColorSpace() const
+{
+	if (m_data)
+		return m_data->channelsOfColorSpace();
+	return 0;
+}
+
+int ScColorProfile::channelsOfConnectionSpace() const
+{
+	if (m_data)
+		return m_data->channelsOfConnectionSpace();
+	return 0;
+}
+
+QString ScColorProfile::dataHash() const
+{
+	if (m_data)
+		return m_data->dataHash();
+	return QString();
+}
+
+bool ScColorProfile::isSuitableForOutput() const
+{
+	if (m_data)
+		return m_data->isSuitableForOutput();
+	return false;
+}
+
 QString ScColorProfile::profilePath() const
 {
 	if (m_data)
@@ -47,6 +82,13 @@ QString ScColorProfile::productDescription() const
 	return QString();
 }
 
+bool ScColorProfile::save(QByteArray& profileData) const
+{
+	if (m_data)
+		return m_data->save(profileData);
+	return false;
+}
+
 bool ScColorProfile::operator==(const ScColorProfile& other) const
 {
 	return m_data == other.m_data;
