@@ -8,8 +8,10 @@ for which a new license (GPL+exception) is in place.
 #ifndef SCCOLORPROFILE_H
 #define SCCOLORPROFILE_H
 
+#include <QByteArray>
 #include <QSharedPointer>
 #include <QWeakPointer>
+
 #include "scribusapi.h"
 #include "sccolorprofiledata.h"
 
@@ -28,15 +30,24 @@ public:
 	inline bool isNull()    const { return (m_data.isNull() || m_data->isNull()); }
 	inline operator bool () const { return !isNull(); }
 
+	bool isSuitableForOutput() const;
+
 	QString profilePath() const;
 	QString productDescription() const;
 	
 	eColorSpaceType colorSpace()  const;
+	eColorSpaceType connectionSpace()  const;
 	eProfileClass   deviceClass() const;
+
+	int channelsOfColorSpace() const;
+	int channelsOfConnectionSpace() const;
 	
 	const ScColorProfileData* data() const { return m_data.data(); }
+	QString dataHash() const;
 
-	bool operator==(const ScColorProfile& prof) const;
+	bool save(QByteArray& profileData) const;
+
+	bool operator==(const ScColorProfile& other) const;
 	
 protected:
 	QSharedPointer<ScColorProfileData> m_data;
