@@ -24,13 +24,15 @@ for which a new license (GPL+exception) is in place.
 #ifndef DOCUMENTCHECKER_H
 #define DOCUMENTCHECKER_H
 
+#include <QString>
+
 #include "scribusapi.h"
-#include "scribusstructs.h"
+#include "prefsstructs.h"
 
 class ScribusDoc;
 
 /*! \brief It create a error/warning list for CheckDocument GUI class.
-All errors and/or warnings are stored in errorCodes (inheritted QMap
+All errors and/or warnings are stored in errorCodes (inherited QMap
 see scribusstructs.h) and parsed into tree view in CheckDocument widgets.
 */
 class SCRIBUS_API DocumentChecker
@@ -40,9 +42,9 @@ class SCRIBUS_API DocumentChecker
 		//! Check the passed document for errors, return true on error found
 		static bool checkDocument(ScribusDoc *currDoc);
 		static bool checkDocument(ScribusDoc *currDoc, const QString& checkerProfile);
-		static void checkPages(ScribusDoc *currDoc, struct CheckerPrefs checkerSettings);
-		static void checkLayers(ScribusDoc *currDoc, struct CheckerPrefs checkerSettings);
-		static void checkItems(ScribusDoc *currDoc, struct CheckerPrefs checkerSettings);
+		static void checkPages(ScribusDoc *currDoc, const CheckerPrefs& checkerSettings);
+		static void checkLayers(ScribusDoc *currDoc, const CheckerPrefs& checkerSettings);
+		static void checkItems(ScribusDoc *currDoc, const CheckerPrefs& checkerSettings);
 };
 
 #endif
