@@ -84,6 +84,7 @@ public:
 		// handled by freetype:	PFB_MAC, DFONT, HQX, MACBIN,
 		SFNT, TTCF, UNKNOWN_FORMAT };
 
+	typedef uint cid_type;
 	typedef uint gid_type;
 	typedef uint ucs4_type;
 	struct GlyphEncoding
@@ -153,7 +154,6 @@ public:
 		// caches
 		mutable QHash<gid_type, qreal>     m_glyphWidth;
 		mutable QHash<gid_type, GlyphData> m_glyphOutline;
-		//mutable QHash<gid_type, uint>      m_cMap;
 		void* m_hbFont {nullptr};
 
 		// fill caches & members
@@ -162,7 +162,6 @@ public:
 		{ 
 			m_glyphWidth.clear();
 			m_glyphOutline.clear();
-			//m_cMap.clear();
 
 			status = qMax(m_cachedStatus, ScFace::LOADED);
 		}
@@ -171,7 +170,6 @@ public:
 		{
 			m_glyphWidth.clear();
 			m_glyphOutline.clear();
-			//m_cMap.clear();
 
 			status = ScFace::UNKNOWN;
 		}
@@ -194,6 +192,7 @@ public:
 		virtual qreal strokeWidth(qreal /*sz*/)      const { return 0.1; }
 		virtual qreal maxAdvanceWidth(qreal sz)  const { return sz; }
 		virtual gid_type char2CMap(uint /*ch*/)         const { return 0; }
+		virtual cid_type glyphIndexToCID(ScFace::gid_type index) const { return index; }
 		virtual QMap<QString,QString> fontDictionary(qreal sz=1.0) const;
 		virtual GlyphMetrics glyphBBox(gid_type gl, qreal sz) const;
 		virtual bool embedFont(QByteArray &/*str*/)       const { return false; }
@@ -396,6 +395,9 @@ public:
 	/// test if the face can render this char
 	bool canRender(QChar ch)   const;
 
+	// translate glyph index to CID (OpenType and CID fonts only)
+	cid_type glyphIndexToCID(gid_type index) const;
+
 	/// translate unicode to glyph index
 	gid_type char2CMap(uint ch)   const;
 
