@@ -48,7 +48,7 @@ FPointArray FPointArray::copy() const
 }
 
 
-FPointArray & FPointArray::operator=( const FPointArray &a )
+FPointArray & FPointArray::operator=(const FPointArray &a)
 { 
 	QVector<FPoint>::operator=(a);
 	m_svgState = nullptr;
@@ -90,59 +90,59 @@ void FPointArray::reverse()
 	}
 }
 
-bool FPointArray::setPoints( int nPoints, double firstx, double firsty, ... )
+bool FPointArray::setPoints(int nPoints, double firstx, double firsty, ...)
 {
 	va_list ap;
-	if ( nPoints < 0 || !FPointArray::resize(nPoints) )
+	if (nPoints < 0 || !FPointArray::resize(nPoints))
 		return false;
-	setPoint( 0, firstx, firsty );
+	setPoint(0, firstx, firsty);
 	int i = 1;
 	double x, y;
 	nPoints--;
-	va_start( ap, firsty );
-	while ( nPoints-- )
-	{
-		x = static_cast<double>(va_arg( ap, double ));
-		y = static_cast<double>(va_arg( ap, double ));
-		setPoint( i++, x, y );
-    }
-	va_end( ap );
-	return true;
-}
-
-bool FPointArray::putPoints( int index, int nPoints, double firstx, double firsty,  ... )
-{
-	va_list ap;
-	if ( index + nPoints > QVector<FPoint>::count())
-	{
-		if ( !FPointArray::resize(index + nPoints) )
-			return false;
-	}
-	if ( nPoints <= 0 )
-		return true;
-	setPoint( index, firstx, firsty );		// set first point
-	int i = index + 1;
-	double x, y;
-	nPoints--;
-	va_start( ap, firsty );
-	while ( nPoints-- )
+	va_start(ap, firsty);
+	while (nPoints--)
 	{
 		x = static_cast<double>(va_arg(ap, double));
 		y = static_cast<double>(va_arg(ap, double));
-		setPoint( i++, x, y );
-	}
-	va_end( ap );
+		setPoint(i++, x, y);
+    }
+	va_end(ap);
 	return true;
 }
 
-bool FPointArray::putPoints( int index, int nPoints, const FPointArray & from, int fromIndex )
+bool FPointArray::putPoints(int index, int nPoints, double firstx, double firsty,  ...)
 {
-	if ( index + nPoints > QVector<FPoint>::count() )
-	{	// extend array
-		if ( !FPointArray::resize(index + nPoints) )
+	va_list ap;
+	if (index + nPoints > QVector<FPoint>::count())
+	{
+		if (!FPointArray::resize(index + nPoints))
 			return false;
 	}
-	if ( nPoints <= 0 )
+	if (nPoints <= 0)
+		return true;
+	setPoint(index, firstx, firsty);		// set first point
+	int i = index + 1;
+	double x, y;
+	nPoints--;
+	va_start(ap, firsty);
+	while (nPoints--)
+	{
+		x = static_cast<double>(va_arg(ap, double));
+		y = static_cast<double>(va_arg(ap, double));
+		setPoint(i++, x, y);
+	}
+	va_end(ap);
+	return true;
+}
+
+bool FPointArray::putPoints(int index, int nPoints, const FPointArray & from, int fromIndex)
+{
+	if (index + nPoints > QVector<FPoint>::count())
+	{	// extend array
+		if (!FPointArray::resize(index + nPoints))
+			return false;
+	}
+	if (nPoints <= 0)
 		return true;
 	Iterator p = begin();
 	p += index;
@@ -178,9 +178,9 @@ QPointF FPointArray::pointQF(int i) const
 	return r;
 }
 
-void FPointArray::translate( double dx, double dy )
+void FPointArray::translate(double dx, double dy)
 {
-	FPoint pt( dx, dy );
+	FPoint pt(dx, dy);
 	Iterator pend = begin();
 	pend += QVector<FPoint>::count();
 	for (Iterator p = begin(); p != pend; p++)
@@ -190,7 +190,7 @@ void FPointArray::translate( double dx, double dy )
 	}
 }
 
-void FPointArray::scale( double sx, double sy )
+void FPointArray::scale(double sx, double sy)
 {
 	Iterator pend = begin();
 	pend += QVector<FPoint>::count();
@@ -210,35 +210,35 @@ QRectF FPointArray::boundingRect() const
 
 FPoint FPointArray::widthHeight() const
 {
-	if ( QVector<FPoint>::count() == 0 )
-		return FPoint( 0.0, 0.0 );		// null rectangle
+	if (QVector<FPoint>::count() == 0)
+		return FPoint(0.0, 0.0);		// null rectangle
 	ConstIterator pd = begin();
 	ConstIterator pend = begin();
 	pend += QVector<FPoint>::count();
 	double minx, maxx, miny, maxy;
 	minx = maxx = pd->xp;
 	miny = maxy = pd->yp;
-	for ( ++pd; pd != pend; ++pd )
+	for (++pd; pd != pend; ++pd)
 	{	// find min+max x and y
 		if (isMarkerI(pd))
 		{
 			continue;
 		}
-		if ( pd->xp < minx )
+		if (pd->xp < minx)
 			minx = pd->xp;
 		else
-			if ( pd->xp > maxx )
+			if (pd->xp > maxx)
 		    	maxx = pd->xp;
-		if ( pd->y() < miny )
+		if (pd->y() < miny)
 			miny = pd->yp;
 		else
-			if ( pd->yp > maxy )
+			if (pd->yp > maxy)
 	    		maxy = pd->yp;
     }
 	return FPoint(maxx - minx,maxy - miny);
 }
 
-void FPointArray::map( const QTransform& m )
+void FPointArray::map(const QTransform& m)
 {
 	const double m11 = m.m11();
 	const double m12 = m.m12();
@@ -304,7 +304,7 @@ void FPointArray::addPoint(const FPoint& p)
 
 bool FPointArray::hasLastQuadPoint(double x1, double y1, double x2, double y2, double x3, double y3, double x4, double y4) const
 {
-	int i = QVector<FPoint>::count()-4;
+	int i = QVector<FPoint>::count() - 4;
 	if (i < 0)
 		return false;
 	ConstIterator p = begin();
@@ -395,30 +395,30 @@ double FPointArray::lenPathDist(int seg, double t1, double t2) const
 	return newLen;
 }
 
-void FPointArray::pointTangentNormalAt( int seg, double t, FPoint* p, FPoint* tn, FPoint* n ) const
+void FPointArray::pointTangentNormalAt(int seg, double t, FPoint* p, FPoint* tn, FPoint* n) const
 {
 	// Calculate derivative if necessary.
 	FPoint d;
-	if( tn || n )
-		pointDerivativesAt( seg, t, p, &d, nullptr );
+	if (tn || n)
+		pointDerivativesAt(seg, t, p, &d, nullptr);
 	else
-		pointDerivativesAt( seg, t, p, nullptr, nullptr );
+		pointDerivativesAt(seg, t, p, nullptr, nullptr);
 	// Normalize derivative.
-	if( tn || n )
+	if (tn || n)
 	{
-		const double norm = sqrt( d.x() * d.x() + d.y() * d.y() );
-		d = norm ? d * ( 1.0 / norm ) : FPoint( 0.0, 0.0 );
+		const double norm = sqrt(d.x() * d.x() + d.y() * d.y());
+		d = norm ? d * (1.0 / norm) : FPoint(0.0, 0.0);
 	}
 	// Assign tangent vector.
-	if( tn )
+	if (tn)
 		*tn = d;
 	// Calculate normal vector.
-	if( n )
+	if (n)
 	{
 		// Calculate vector product of "binormal" x tangent
 		// (0,0,1) x (dx,dy,0), which is simply (dy,-dx,0).
-		n->setX( d.y() );
-		n->setY( -d.x() );
+		n->setX(d.y());
+		n->setY(-d.x());
 	}
 	FPoint p1 = point(seg);
 	FPoint k1 = point(seg+1);
@@ -428,38 +428,37 @@ void FPointArray::pointTangentNormalAt( int seg, double t, FPoint* p, FPoint* tn
 	*p = ((tm * tm * tm) * p1) + (3 * t * (tm * tm) * k1) + (3 * (t * t) * tm * k2 + (t * t * t) * p2);
 }
 
-void FPointArray::pointDerivativesAt( int seg, double t, FPoint* p, FPoint* d1, FPoint* d2 ) const
+void FPointArray::pointDerivativesAt(int seg, double t, FPoint* p, FPoint* d1, FPoint* d2) const
 {
 	// Copy points.
-	FPoint* q = new FPoint[ 4 ];
+	FPoint q[ 4 ];
 	q[ 0 ] = point(seg);
-	q[ 1 ] = point(seg+1);
-	q[ 3 ] = point(seg+2);
-	q[ 2 ] = point(seg+3);
+	q[ 1 ] = point(seg + 1);
+	q[ 3 ] = point(seg + 2);
+	q[ 2 ] = point(seg + 3);
 	// The De Casteljau algorithm.
 	for (unsigned short j = 1; j <= 3; j++)
 	{
 		for (unsigned short i = 0; i <= 3 - j; i++)
 		{
-			q[ i ] = ( 1.0 - t ) * q[ i ] + t * q[ i + 1 ];
+			q[ i ] = (1.0 - t) * q[ i ] + t * q[ i + 1 ];
 		}
 		// Save second derivative now that we have it.
-		if( j == 1 )
+		if (j == 1)
 		{
-			if( d2 )
-				*d2 = 6 * ( q[ 2 ] - 2 * q[ 1 ] + q[ 0 ] );
+			if (d2)
+				*d2 = 6 * (q[ 2 ] - 2 * q[ 1 ] + q[ 0 ]);
 		}
 		// Save first derivative now that we have it.
-		else if( j == 2 )
+		else if (j == 2)
 		{
-			if( d1 )
-				*d1 = 3 * ( q[ 1 ] - q[ 0 ] );
+			if (d1)
+				*d1 = 3 * (q[ 1 ] - q[ 0 ]);
 		}
 	}
 	// Save point.
-	if( p )
+	if (p)
 		*p = q[ 0 ];
-	delete[]( q );
 }
 
 bool FPointArray::isBezierClosed() const
@@ -544,7 +543,7 @@ QString FPointArray::svgPath(bool closed) const
 
 QPainterPath FPointArray::toQPainterPath(bool closed) const
 {
-	QPainterPath m_path = QPainterPath();
+	QPainterPath m_path;
 	bool nPath = true;
 	bool first = true;
 	FPoint np, np1, np2, np3, np4, firstP;
@@ -603,7 +602,7 @@ void FPointArray::fromQPainterPath(QPainterPath &path, bool close)
 				svgLineTo(elm.x, elm.y);
 				break;
 			case QPainterPath::CurveToElement:
-				svgCurveToCubic(elm.x, elm.y, path.elementAt(i+1).x, path.elementAt(i+1).y, path.elementAt(i+2).x, path.elementAt(i+2).y );
+				svgCurveToCubic(elm.x, elm.y, path.elementAt(i + 1).x, path.elementAt(i + 1).y, path.elementAt(i + 2).x, path.elementAt(i + 2).y);
 				break;
 			default:
 				break;
@@ -648,12 +647,12 @@ void FPointArray::svgLineTo(double x1, double y1)
 	m_svgState->WasM = false;
 	if (size() > 3)
 	{
-		FPoint b1 = point(size()-4);
-		FPoint b2 = point(size()-3);
-		FPoint b3 = point(size()-2);
-		FPoint b4 = point(size()-1);
-		FPoint n1 = FPoint(m_svgState->CurrX, m_svgState->CurrY);
-		FPoint n2 = FPoint(x1, y1);
+		FPoint b1 = point(size() - 4);
+		FPoint b2 = point(size() - 3);
+		FPoint b3 = point(size() - 2);
+		FPoint b4 = point(size() - 1);
+		FPoint n1(m_svgState->CurrX, m_svgState->CurrY);
+		FPoint n2(x1, y1);
 		if ((b1 == n1) && (b2 == n1) && (b3 == n2) && (b4 == n2))
 			return;
 	}
@@ -675,14 +674,14 @@ void FPointArray::svgCurveToCubic(double x1, double y1, double x2, double y2, do
 	m_svgState->WasM = false;
 	if (m_svgState->PathLen > 3)
 	{
-		FPoint b1 = point(size()-4);
-		FPoint b2 = point(size()-3);
-		FPoint b3 = point(size()-2);
-		FPoint b4 = point(size()-1);
-		FPoint n1 = FPoint(m_svgState->CurrX, m_svgState->CurrY);
-		FPoint n2 = FPoint(x1, y1);
-		FPoint n3 = FPoint(x3, y3);
-		FPoint n4 = FPoint(x2, y2);
+		FPoint b1 = point(size() - 4);
+		FPoint b2 = point(size() - 3);
+		FPoint b3 = point(size() - 2);
+		FPoint b4 = point(size() - 1);
+		FPoint n1(m_svgState->CurrX, m_svgState->CurrY);
+		FPoint n2(x1, y1);
+		FPoint n3(x3, y3);
+		FPoint n4(x2, y2);
 		if ((b1 == n1) && (b2 == n2) && (b3 == n3) && (b4 == n4))
 			return;
 	}
@@ -729,12 +728,12 @@ void FPointArray::calculateArc(bool relative, double &curx, double &cury, double
 	sin_th = sin(angle * (M_PI / 180.0));
 	cos_th = cos(angle * (M_PI / 180.0));
 	double dx;
-	if(!relative)
+	if (!relative)
 		dx = (curx - x) / 2.0;
 	else
 		dx = -x / 2.0;
 	double dy;
-	if(!relative)
+	if (!relative)
 		dy = (cury - y) / 2.0;
 	else
 		dy = -y / 2.0;
@@ -746,7 +745,7 @@ void FPointArray::calculateArc(bool relative, double &curx, double &cury, double
 	double Py = _y1 * _y1;
 	// Spec : check if radii are large enough
 	double check = Px / Pr1 + Py / Pr2;
-	if(check > 1)
+	if (check > 1)
 	{
 		r1 = r1 * sqrt(check);
 		r2 = r2 * sqrt(check);
@@ -757,11 +756,11 @@ void FPointArray::calculateArc(bool relative, double &curx, double &cury, double
 	a11 = cos_th / r2;
 	x0 = a00 * curx + a01 * cury;
 	y0 = a10 * curx + a11 * cury;
-	if(!relative)
+	if (!relative)
 		x1 = a00 * x + a01 * y;
 	else
 		x1 = a00 * (curx + x) + a01 * (cury + y);
-	if(!relative)
+	if (!relative)
 		y1 = a10 * x + a11 * y;
 	else
 		y1 = a10 * (curx + x) + a11 * (cury + y);
@@ -772,10 +771,10 @@ void FPointArray::calculateArc(bool relative, double &curx, double &cury, double
 	    */
 	d = (x1 - x0) * (x1 - x0) + (y1 - y0) * (y1 - y0);
 	sfactor_sq = 1.0 / d - 0.25;
-	if(sfactor_sq < 0)
+	if (sfactor_sq < 0)
 		sfactor_sq = 0;
 	sfactor = sqrt(sfactor_sq);
-	if(sweepFlag == largeArcFlag)
+	if (sweepFlag == largeArcFlag)
 		sfactor = -sfactor;
 	xc = 0.5 * (x0 + x1) - sfactor * (y1 - y0);
 	yc = 0.5 * (y0 + y1) + sfactor * (x1 - x0);
@@ -784,9 +783,9 @@ void FPointArray::calculateArc(bool relative, double &curx, double &cury, double
 	th0 = atan2(y0 - yc, x0 - xc);
 	th1 = atan2(y1 - yc, x1 - xc);
 	th_arc = th1 - th0;
-	if(th_arc < 0 && sweepFlag)
+	if (th_arc < 0 && sweepFlag)
 		th_arc += 2 * M_PI;
-	else if(th_arc > 0 && !sweepFlag)
+	else if (th_arc > 0 && !sweepFlag)
 		th_arc -= 2 * M_PI;
 	n_segs = static_cast<int>(ceil(fabs(th_arc / (M_PI * 0.5 + 0.001))));
 	for (i = 0; i < n_segs; i++)
@@ -814,21 +813,21 @@ void FPointArray::calculateArc(bool relative, double &curx, double &cury, double
 		y3 = yc + sin(_th1);
 		x2 = x3 + t * sin(_th1);
 		y2 = y3 - t * cos(_th1);
-		svgCurveToCubic(a00 * x1 + a01 * y1, a10 * x1 + a11 * y1, a00 * x2 + a01 * y2, a10 * x2 + a11 * y2, a00 * x3 + a01 * y3, a10 * x3 + a11 * y3 );
+		svgCurveToCubic(a00 * x1 + a01 * y1, a10 * x1 + a11 * y1, a00 * x2 + a01 * y2, a10 * x2 + a11 * y2, a00 * x3 + a01 * y3, a10 * x3 + a11 * y3);
 	}
 	}
-	if(!relative)
+	if (!relative)
 		curx = x;
 	else
 		curx += x;
-	if(!relative)
+	if (!relative)
 		cury = y;
 	else
 		cury += y;
 }
 
 
-static const char * getCoord( const char *ptr, double &number )
+static const char * getCoord(const char *ptr, double &number)
 {
 	int integer, exponent;
 	double decimal, frac;
@@ -842,32 +841,54 @@ static const char * getCoord( const char *ptr, double &number )
 	expsign = 1;
 	
 	// read the sign
-	if(*ptr == '+')
+	if (*ptr == '+')
 		ptr++;
-	else if(*ptr == '-')
+	else if (*ptr == '-')
 	{
 		ptr++;
 		sign = -1;
 	}
+
+	// Check for nan value
+	if (*ptr == 'n' || *ptr == 'N')
+	{
+		bool isNan = true;
+		const char *tmpPtr = ptr + 1;
+		isNan &= (*tmpPtr == 'a' || *tmpPtr == 'A');
+		if (*tmpPtr != '\0')
+			++tmpPtr;
+		isNan &= (*tmpPtr == 'n' || *tmpPtr == 'N');
+		if (*tmpPtr != '\0')
+			++tmpPtr;
+		isNan &= (*tmpPtr == ' ' || *tmpPtr == '\0');
+		if (isNan)
+		{
+			number = 0.0;
+			ptr += 3;
+			if (*ptr == ' ')
+				++ptr;
+			return ptr;
+		}
+	}
 	
 	// read the integer part
 	while (*ptr != '\0' && *ptr >= '0' && *ptr <= '9')
 		integer = (integer * 10) + *(ptr++) - '0';
-	if(*ptr == '.') // read the decimals
+	if (*ptr == '.') // read the decimals
 	{
 		ptr++;
 		while (*ptr != '\0' && *ptr >= '0' && *ptr <= '9')
 			decimal += (*(ptr++) - '0') * (frac *= 0.1);
 	}
 	
-	if(*ptr == 'e' || *ptr == 'E') // read the exponent part
+	if (*ptr == 'e' || *ptr == 'E') // read the exponent part
 	{
 		ptr++;
 		
 		// read the sign of the exponent
-		if(*ptr == '+')
+		if (*ptr == '+')
 			ptr++;
-		else if(*ptr == '-')
+		else if (*ptr == '-')
 		{
 			ptr++;
 			expsign = -1;
@@ -882,9 +903,9 @@ static const char * getCoord( const char *ptr, double &number )
 		}
 	}
 	number = integer + decimal;
-	number *= sign * pow( static_cast<double>(10), static_cast<double>( expsign * exponent ) );
+	number *= sign * pow(static_cast<double>(10), static_cast<double>(expsign * exponent));
 	// skip the following space
-	if(*ptr == ' ')
+	if (*ptr == ' ')
 		ptr++;
 	
 	return ptr;
@@ -894,7 +915,7 @@ static const char * getCoord( const char *ptr, double &number )
 bool FPointArray::parseSVG(const QString& svgPath)
 {
 	QString d = svgPath;
-	d = d.replace( QRegExp( "," ), " ");
+	d = d.replace(QRegExp(","), " ");
 
 	bool ret = false;
 	if (d.isEmpty())
@@ -921,19 +942,19 @@ bool FPointArray::parseSVG(const QString& svgPath)
 		case 'f':
 		case 'F':
 			{
-				ptr = getCoord( ptr, tox );
+				ptr = getCoord(ptr, tox);
 				break;
 			}
 		case 'm':
 			relative = true;
 		case 'M':
 			{
-				ptr = getCoord( ptr, tox );
-				ptr = getCoord( ptr, toy );
+				ptr = getCoord(ptr, tox);
+				ptr = getCoord(ptr, toy);
 				m_svgState->WasM = true;
 				subpathx = curx = relative ? curx + tox : tox;
 				subpathy = cury = relative ? cury + toy : toy;
-				svgMoveTo(curx, cury );
+				svgMoveTo(curx, cury);
 				moveCount++;
 				break;
 			}
@@ -941,39 +962,39 @@ bool FPointArray::parseSVG(const QString& svgPath)
 			relative = true;
 		case 'L':
 			{
-				ptr = getCoord( ptr, tox );
-				ptr = getCoord( ptr, toy );
+				ptr = getCoord(ptr, tox);
+				ptr = getCoord(ptr, toy);
 				curx = relative ? curx + tox : tox;
 				cury = relative ? cury + toy : toy;
-				svgLineTo( curx, cury );
+				svgLineTo(curx, cury);
 				break;
 			}
 		case 'h':
 			{
-				ptr = getCoord( ptr, tox );
+				ptr = getCoord(ptr, tox);
 				curx = curx + tox;
-				svgLineTo( curx, cury );
+				svgLineTo(curx, cury);
 				break;
 			}
 		case 'H':
 			{
-				ptr = getCoord( ptr, tox );
+				ptr = getCoord(ptr, tox);
 				curx = tox;
-				svgLineTo( curx, cury );
+				svgLineTo(curx, cury);
 				break;
 			}
 		case 'v':
 			{
-				ptr = getCoord( ptr, toy );
+				ptr = getCoord(ptr, toy);
 				cury = cury + toy;
-				svgLineTo( curx, cury );
+				svgLineTo(curx, cury);
 				break;
 			}
 		case 'V':
 			{
-				ptr = getCoord( ptr, toy );
+				ptr = getCoord(ptr, toy);
 				cury = toy;
-				svgLineTo(  curx, cury );
+				svgLineTo( curx, cury);
 				break;
 			}
 		case 'z':
@@ -988,19 +1009,19 @@ bool FPointArray::parseSVG(const QString& svgPath)
 			relative = true;
 		case 'C':
 			{
-				ptr = getCoord( ptr, x1 );
-				ptr = getCoord( ptr, y1 );
-				ptr = getCoord( ptr, x2 );
-				ptr = getCoord( ptr, y2 );
-				ptr = getCoord( ptr, tox );
-				ptr = getCoord( ptr, toy );
+				ptr = getCoord(ptr, x1);
+				ptr = getCoord(ptr, y1);
+				ptr = getCoord(ptr, x2);
+				ptr = getCoord(ptr, y2);
+				ptr = getCoord(ptr, tox);
+				ptr = getCoord(ptr, toy);
 				px1 = relative ? curx + x1 : x1;
 				py1 = relative ? cury + y1 : y1;
 				px2 = relative ? curx + x2 : x2;
 				py2 = relative ? cury + y2 : y2;
 				px3 = relative ? curx + tox : tox;
 				py3 = relative ? cury + toy : toy;
-				svgCurveToCubic( px1, py1, px2, py2, px3, py3 );
+				svgCurveToCubic(px1, py1, px2, py2, px3, py3);
 				contrlx = relative ? curx + x2 : x2;
 				contrly = relative ? cury + y2 : y2;
 				curx = relative ? curx + tox : tox;
@@ -1011,17 +1032,17 @@ bool FPointArray::parseSVG(const QString& svgPath)
 			relative = true;
 		case 'S':
 			{
-				ptr = getCoord( ptr, x2 );
-				ptr = getCoord( ptr, y2 );
-				ptr = getCoord( ptr, tox );
-				ptr = getCoord( ptr, toy );
+				ptr = getCoord(ptr, x2);
+				ptr = getCoord(ptr, y2);
+				ptr = getCoord(ptr, tox);
+				ptr = getCoord(ptr, toy);
 				px1 = 2 * curx - contrlx;
 				py1 = 2 * cury - contrly;
 				px2 = relative ? curx + x2 : x2;
 				py2 = relative ? cury + y2 : y2;
 				px3 = relative ? curx + tox : tox;
 				py3 = relative ? cury + toy : toy;
-				svgCurveToCubic( px1, py1, px2, py2, px3, py3 );
+				svgCurveToCubic(px1, py1, px2, py2, px3, py3);
 				contrlx = relative ? curx + x2 : x2;
 				contrly = relative ? cury + y2 : y2;
 				curx = relative ? curx + tox : tox;
@@ -1032,17 +1053,17 @@ bool FPointArray::parseSVG(const QString& svgPath)
 			relative = true;
 		case 'Q':
 			{
-				ptr = getCoord( ptr, x1 );
-				ptr = getCoord( ptr, y1 );
-				ptr = getCoord( ptr, tox );
-				ptr = getCoord( ptr, toy );
+				ptr = getCoord(ptr, x1);
+				ptr = getCoord(ptr, y1);
+				ptr = getCoord(ptr, tox);
+				ptr = getCoord(ptr, toy);
 				px1 = relative ? (curx + 2 * (x1 + curx)) * (1.0 / 3.0) : (curx + 2 * x1) * (1.0 / 3.0);
 				py1 = relative ? (cury + 2 * (y1 + cury)) * (1.0 / 3.0) : (cury + 2 * y1) * (1.0 / 3.0);
 				px2 = relative ? ((curx + tox) + 2 * (x1 + curx)) * (1.0 / 3.0) : (tox + 2 * x1) * (1.0 / 3.0);
 				py2 = relative ? ((cury + toy) + 2 * (y1 + cury)) * (1.0 / 3.0) : (toy + 2 * y1) * (1.0 / 3.0);
 				px3 = relative ? curx + tox : tox;
 				py3 = relative ? cury + toy : toy;
-				svgCurveToCubic( px1, py1, px2, py2, px3, py3 );
+				svgCurveToCubic(px1, py1, px2, py2, px3, py3);
 				contrlx = relative ? curx + x1 : (tox + 2 * x1) * (1.0 / 3.0);
 				contrly = relative ? cury + y1 : (toy + 2 * y1) * (1.0 / 3.0);
 				curx = relative ? curx + tox : tox;
@@ -1063,7 +1084,7 @@ bool FPointArray::parseSVG(const QString& svgPath)
 				py2 = relative ? ((cury + toy) + 2 * yc) * (1.0 / 3.0) : (toy + 2 * yc) * (1.0 / 3.0);
 				px3 = relative ? curx + tox : tox;
 				py3 = relative ? cury + toy : toy;
-				svgCurveToCubic( px1, py1, px2, py2, px3, py3 );
+				svgCurveToCubic(px1, py1, px2, py2, px3, py3);
 				contrlx = xc;
 				contrly = yc;
 				curx = relative ? curx + tox : tox;
@@ -1076,16 +1097,16 @@ bool FPointArray::parseSVG(const QString& svgPath)
 			{
 				bool largeArc, sweep;
 				double angle, rx, ry;
-				ptr = getCoord( ptr, rx );
-				ptr = getCoord( ptr, ry );
-				ptr = getCoord( ptr, angle );
-				ptr = getCoord( ptr, tox );
+				ptr = getCoord(ptr, rx);
+				ptr = getCoord(ptr, ry);
+				ptr = getCoord(ptr, angle);
+				ptr = getCoord(ptr, tox);
 				largeArc = tox == 1;
-				ptr = getCoord( ptr, tox );
+				ptr = getCoord(ptr, tox);
 				sweep = tox == 1;
-				ptr = getCoord( ptr, tox );
-				ptr = getCoord( ptr, toy );
-				calculateArc( relative, curx, cury, angle, tox, toy, rx, ry, largeArc, sweep );
+				ptr = getCoord(ptr, tox);
+				ptr = getCoord(ptr, toy);
+				calculateArc(relative, curx, cury, angle, tox, toy, rx, ry, largeArc, sweep);
 			}
 		}
 		lastCommand = command;
