@@ -14,6 +14,7 @@ for which a new license (GPL+exception) is in place.
 #include "scimgdataloader_tiff.h"
 #include "scribuscore.h"
 #include "util_color.h"
+#include "util_image.h"
 
 static void TagExtender(TIFF *tiff)
 {
@@ -27,7 +28,7 @@ static void TagExtender(TIFF *tiff)
 ScImgDataLoader_TIFF::ScImgDataLoader_TIFF()
 {
 	m_photometric = PHOTOMETRIC_MINISBLACK;
-	m_samplesperpixel = 72;
+	m_samplesPerPixel = 72;
 
 	initSupportedFormatList();
 }
@@ -51,7 +52,7 @@ void ScImgDataLoader_TIFF::loadEmbeddedProfile(const QString& fn, int /*page*/)
 	if (!tif)
 		return;
 
-	uint32 EmbedLen = 0;
+	uint32_t EmbedLen = 0;
 	void*  EmbedBuffer;
 	if (TIFFGetField(tif, TIFFTAG_ICCPROFILE, &EmbedLen, &EmbedBuffer))
 	{
@@ -156,7 +157,7 @@ bool ScImgDataLoader_TIFF::testAlphaChannelAvailability(const QString& fn, int /
 	if (!tif)
 		return false;
 
-	uint16 extrasamples, *extratypes;
+	uint16_t extrasamples, *extratypes;
 	hasAlpha = false;
 	do
 	{
@@ -248,118 +249,115 @@ void ScImgDataLoader_TIFF::unmultiplyRGBA(RawImage *image)
 	}
 }
 
-bool ScImgDataLoader_TIFF::getImageData(TIFF* tif, RawImage *image, uint widtht, uint heightt, uint size, uint16 photometric, uint16 bitspersample, uint16 samplesperpixel, bool &bilevel, bool &isCMYK)
+bool ScImgDataLoader_TIFF::getImageData(TIFF* tif, RawImage *image, uint widtht, uint heightt, uint size, const SampleFormatInfo& sampleInfo, bool &bilevel, bool &isCMYK)
 {
-	uint32 *bits = nullptr;
-	if (photometric == PHOTOMETRIC_SEPARATED)
+	if (sampleInfo.photometric != PHOTOMETRIC_SEPARATED)
 	{
-		if (samplesperpixel > 5)
+		if (!getImageData_RGBA(tif, image, widtht, heightt, size, sampleInfo))
+			return false;
+		if (sampleInfo.bitsPerSample == 1)
+			bilevel = true;
+		m_pixelFormat = Format_RGBA_8;
+		return true;
+	}
+
+	// Now we are in the PHOTOMETRIC_SEPARATED case
+	if (sampleInfo.samplesPerPixel > 5)
+	{
+		if (!getImageData_RGBA(tif, image, widtht, heightt, size, sampleInfo))
+			return false;
+		if (sampleInfo.bitsPerSample == 1)
+			bilevel = true;
+		isCMYK = false;
+		m_pixelFormat = Format_RGBA_8;
+		return true;
+	}
+
+	if (sampleInfo.samplesFormat != SAMPLEFORMAT_UINT && sampleInfo.samplesFormat != SAMPLEFORMAT_INT)
+	{
+		m_message = QObject::tr("This image uses an unsupported non integer sample format");
+		m_msgType = errorMsg;
+		return false;
+	}
+
+	if (sampleInfo.bitsPerSample > 16)
+	{
+		m_message = QObject::tr("This image uses an unsupported bit depth: %1 bits per sample.").arg(sampleInfo.bitsPerSample);
+		m_msgType = errorMsg;
+		return false;
+	}
+
+	if (TIFFIsTiled(tif))
+	{
+		uint32_t columns, rows;
+		uint32_t *tile_buf;
+		uint32_t xt, yt;
+		TIFFGetField(tif, TIFFTAG_TILEWIDTH,  &columns);
+		TIFFGetField(tif, TIFFTAG_TILELENGTH, &rows);
+		tile_buf = (uint32_t*) _TIFFmalloc(columns * rows * sizeof(uint32_t));
+		if (tile_buf == nullptr)
 		{
-			if (!getImageData_RGBA(tif, image, widtht, heightt, size, bitspersample, samplesperpixel))
-				return false;
-			if (bitspersample == 1)
-				bilevel = true;
-			isCMYK = false;
-			m_pixelFormat = Format_RGBA_8;
+			TIFFClose(tif);
+			return false;
 		}
-		else
+		uint32_t tileW = columns, tileH = rows;
+		for (yt = 0; yt < (uint32_t) image->height(); yt += rows)
 		{
-			if (TIFFIsTiled(tif))
+			if (yt > (uint) image->height())
+				break;
+			if (image->height() - yt < rows)
+				tileH = image->height() - yt;
+			tileW = columns;
+			uint32_t yi;
+			int chans = image->channels();
+			for (xt = 0; xt < (uint) image->width(); xt += columns)
 			{
-				uint32 columns, rows;
-				uint32 *tile_buf;
-				uint32 xt, yt;
-				TIFFGetField(tif, TIFFTAG_TILEWIDTH,  &columns);
-				TIFFGetField(tif, TIFFTAG_TILELENGTH, &rows);
-				tile_buf = (uint32*) _TIFFmalloc(columns*rows*sizeof(uint32));
-				if (tile_buf == nullptr)
+				TIFFReadTile(tif, tile_buf, xt, yt, 0, 0);
+				for (yi = 0; yi < tileH; yi++)
 				{
-					TIFFClose(tif);
-					return false;
-				}
-				uint32 tileW = columns, tileH = rows;
-				for (yt = 0; yt < (uint32) image->height(); yt += rows)
-				{
-					if (yt > (uint) image->height())
-						break;
-					if (image->height()-yt < rows)
-						tileH = image->height()-yt;
-					tileW = columns;
-					uint32 yi;
-					int chans = image->channels();
-					for (xt = 0; xt < (uint) image->width(); xt += columns)
-					{
-						TIFFReadTile(tif, tile_buf, xt, yt, 0, 0);
-						for (yi = 0; yi < tileH; yi++)
-						{
-							_TIFFmemcpy(image->scanLine(yt+(tileH-1-yi))+xt, tile_buf+tileW*yi, tileW*chans);
-						}
-					}
-				}
-				_TIFFfree(tile_buf);
-			}
-			else
-			{
-				tsize_t bytesperrow = TIFFScanlineSize(tif);
-				bits = (uint32 *) _TIFFmalloc(bytesperrow);
-				int chans = image->channels();
-				if (bits)
-				{
-					for (unsigned int y = 0; y < heightt; y++)
-					{
-						if (TIFFReadScanline(tif, bits, y, 0))
-						{
-							/* The code below allows loading of CMYK TIFFs generated by ImageMagick, 
-							   currently commented out because its an ugly hack atm
-							   When converting 8-bit PNGs with an alpha channel to CMYK Tiff, ImageMagick
-							   creates a 16-bit CMYK Tiff !?!??
-							if (bitspersample > 8)
-							{
-								uchar *ptrT = image->scanLine(y);
-								uchar *ptrS = (uchar*)bits;
-								for (unsigned int x = 0; x < widtht; x++)
-								{
-									ptrT[0] = ptrS[1];
-									ptrT[1] = ptrS[3];
-									ptrT[2] = ptrS[5];
-									ptrT[3] = ptrS[7];
-									if (samplesperpixel > 4)
-										ptrT[4] = ptrS[9];
-									ptrT += chans;
-									ptrS += chans * 2;
-								}
-							}
-							else */
-								memcpy(image->scanLine(y), bits, chans * widtht);
-						}
-					}
-					_TIFFfree(bits);
+					_TIFFmemcpy(image->scanLine(yt + (tileH - 1 - yi)) + xt, tile_buf + tileW * yi, tileW * chans);
 				}
 			}
-			isCMYK = true;
-			m_pixelFormat = (image->channels() == 5) ? Format_CMYKA_8 : Format_CMYK_8;
 		}
+		_TIFFfree(tile_buf);
 	}
 	else
 	{
-		if (!getImageData_RGBA(tif, image, widtht, heightt, size, bitspersample, samplesperpixel))
-			return false;
-		if (bitspersample == 1)
-			bilevel = true;
-		m_pixelFormat = Format_RGBA_8;
+		int chans = image->channels();
+		tsize_t bytesperrow = TIFFScanlineSize(tif);
+		uint32_t *bits = (uint32_t *) _TIFFmalloc(bytesperrow);
+		if (bits)
+		{
+			for (unsigned int y = 0; y < heightt; y++)
+			{
+				if (!TIFFReadScanline(tif, bits, y, 0))
+					break;
+
+				if (sampleInfo.bitsPerSample == 16 && sampleInfo.samplesFormat == SAMPLEFORMAT_UINT)
+					convertImageData((uint16_t*) bits, (uint8_t*) image->scanLine(y), chans * widtht);
+				else if (sampleInfo.bitsPerSample == 16 && sampleInfo.samplesFormat == SAMPLEFORMAT_INT)
+					convertImageData((int16_t*) bits, (uint8_t*) image->scanLine(y), chans * widtht);
+				else
+					memcpy(image->scanLine(y), bits, chans * widtht);
+			}
+			_TIFFfree(bits);
+		}
 	}
+	isCMYK = true;
+	m_pixelFormat = (image->channels() == 5) ? Format_CMYKA_8 : Format_CMYK_8;
+
 	return true;
 }
 
-bool ScImgDataLoader_TIFF::getImageData_RGBA(TIFF* tif, RawImage *image, uint widtht, uint heightt, uint size, uint16 bitspersample, uint16 samplesperpixel)
+bool ScImgDataLoader_TIFF::getImageData_RGBA(TIFF* tif, RawImage *image, uint widtht, uint heightt, uint size, const SampleFormatInfo& sampleInfo)
 {
-	uint32* bits = (uint32 *) _TIFFmalloc(size * sizeof(uint32));
+	uint32_t* bits = (uint32_t *) _TIFFmalloc(size * sizeof(uint32_t));
 	if (!bits)
 		return false;
 
-	uint16  extrasamples(0), *extratypes(nullptr);
-	if (!TIFFGetField (tif, TIFFTAG_EXTRASAMPLES, &extrasamples, &extratypes))
-		extrasamples = 0;
+	uint16_t  extraSamples(0), *extraTypes(nullptr);
+	if (!TIFFGetField (tif, TIFFTAG_EXTRASAMPLES, &extraSamples, &extraTypes))
+		extraSamples = 0;
 	
 	bool gotData = false;
 	if (TIFFReadRGBAImage(tif, widtht, heightt, bits, 0))
@@ -369,9 +367,9 @@ bool ScImgDataLoader_TIFF::getImageData_RGBA(TIFF* tif, RawImage *image, uint wi
 			memcpy(image->scanLine(heightt - 1 - y), bits + y * widtht, widtht * image->channels());
 			if (QSysInfo::ByteOrder == QSysInfo::BigEndian)
 			{
-				unsigned char *s = image->scanLine( heightt - 1 - y );
+				unsigned char *s = image->scanLine(heightt - 1 - y);
 				unsigned char r, g, b, a;
-				for (uint xi=0; xi < widtht; ++xi)
+				for (uint xi = 0; xi < widtht; ++xi)
 				{
 					r = s[0];
 					g = s[1];
@@ -385,7 +383,7 @@ bool ScImgDataLoader_TIFF::getImageData_RGBA(TIFF* tif, RawImage *image, uint wi
 				}
 			}
 		}
-		if (extrasamples > 0 && extratypes[0] == EXTRASAMPLE_ASSOCALPHA)
+		if (extraSamples > 0 && extraTypes[0] == EXTRASAMPLE_ASSOCALPHA)
 			unmultiplyRGBA(image);
 		gotData = true;
 	}
@@ -458,19 +456,19 @@ void ScImgDataLoader_TIFF::blendOntoTarget(RawImage *tmp, int layOpa, const QStr
 				}
 				else if (layBlend == "scrn")
 				{
-					src_r = 255 - ((255-src_r) * (255-d[0]) / 128);
-					src_g = 255 - ((255-src_g) * (255-d[1]) / 128);
-					src_b = 255 - ((255-src_b) * (255-d[2]) / 128);
+					src_r = 255 - ((255 - src_r) * (255 - d[0]) / 128);
+					src_g = 255 - ((255 - src_g) * (255 - d[1]) / 128);
+					src_b = 255 - ((255 - src_b) * (255 - d[2]) / 128);
 					if (cmyk)
-						src_a = 255 - ((255-src_a) * (255-d[3]) / 128);
+						src_a = 255 - ((255 - src_a) * (255 - d[3]) / 128);
 				}
 				else if (layBlend == "over")
 				{
-					src_r = d[0] < 128 ? src_r * d[0] / 128 : 255 - ((255-src_r) * (255-d[0]) / 128);
-					src_g = d[1] < 128 ? src_g * d[1] / 128 : 255 - ((255-src_g) * (255-d[1]) / 128);
-					src_b = d[2] < 128 ? src_b * d[2] / 128 : 255 - ((255-src_b) * (255-d[2]) / 128);
+					src_r = d[0] < 128 ? src_r * d[0] / 128 : 255 - ((255 - src_r) * (255 - d[0]) / 128);
+					src_g = d[1] < 128 ? src_g * d[1] / 128 : 255 - ((255 - src_g) * (255 - d[1]) / 128);
+					src_b = d[2] < 128 ? src_b * d[2] / 128 : 255 - ((255 - src_b) * (255 - d[2]) / 128);
 					if (cmyk)
-						src_a = d[3] < 128 ? src_a * d[3] / 128 : 255 - ((255-src_a) * (255-d[3]) / 128);
+						src_a = d[3] < 128 ? src_a * d[3] / 128 : 255 - ((255 - src_a) * (255 - d[3]) / 128);
 				}
 				else if (layBlend == "diff")
 				{
@@ -490,19 +488,19 @@ void ScImgDataLoader_TIFF::blendOntoTarget(RawImage *tmp, int layOpa, const QStr
 				}
 				else if (layBlend == "hLit")
 				{
-					src_r = src_r < 128 ? src_r * d[0] / 128 : 255 - ((255-src_r) * (255-d[0]) / 128);
-					src_g = src_g < 128 ? src_g * d[1] / 128 : 255 - ((255-src_g) * (255-d[1]) / 128);
-					src_b = src_b < 128 ? src_b * d[2] / 128 : 255 - ((255-src_b) * (255-d[2]) / 128);
+					src_r = src_r < 128 ? src_r * d[0] / 128 : 255 - ((255 - src_r) * (255 - d[0]) / 128);
+					src_g = src_g < 128 ? src_g * d[1] / 128 : 255 - ((255 - src_g) * (255 - d[1]) / 128);
+					src_b = src_b < 128 ? src_b * d[2] / 128 : 255 - ((255 - src_b) * (255 - d[2]) / 128);
 					if (cmyk)
-						src_a = src_a < 128 ? src_a * d[3] / 128 : 255 - ((255-src_a) * (255-d[3]) / 128);
+						src_a = src_a < 128 ? src_a * d[3] / 128 : 255 - ((255 - src_a) * (255 - d[3]) / 128);
 				}
 				else if (layBlend == "sLit")
 				{
-					src_r = src_r * d[0] / 256 + src_r * (255 - ((255-src_r)*(255-d[0]) / 256) - src_r * d[0] / 256) / 256;
-					src_g = src_g * d[1] / 256 + src_g * (255 - ((255-src_g)*(255-d[1]) / 256) - src_g * d[1] / 256) / 256;
-					src_b = src_b * d[2] / 256 + src_b * (255 - ((255-src_b)*(255-d[2]) / 256) - src_b * d[2] / 256) / 256;
+					src_r = src_r * d[0] / 256 + src_r * (255 - ((255 - src_r)*(255 - d[0]) / 256) - src_r * d[0] / 256) / 256;
+					src_g = src_g * d[1] / 256 + src_g * (255 - ((255 - src_g)*(255 - d[1]) / 256) - src_g * d[1] / 256) / 256;
+					src_b = src_b * d[2] / 256 + src_b * (255 - ((255 - src_b)*(255 - d[2]) / 256) - src_b * d[2] / 256) / 256;
 					if (cmyk)
-						src_a = src_a * d[3] / 256 + src_a * (255 - ((255-src_a)*(255-d[3]) / 256) - src_a * d[3] / 256) / 256;
+						src_a = src_a * d[3] / 256 + src_a * (255 - ((255 - src_a)*(255 - d[3]) / 256) - src_a * d[3] / 256) / 256;
 				}
 				else if (layBlend == "lite")
 				{
@@ -522,19 +520,19 @@ void ScImgDataLoader_TIFF::blendOntoTarget(RawImage *tmp, int layOpa, const QStr
 				}
 				else if (layBlend == "div ")
 				{
-					src_r = src_r == 255 ? 255 : ((d[0] * 256) / (255-src_r)) > 255 ? 255 : (d[0] * 256) / (255-src_r);
-					src_g = src_g == 255 ? 255 : ((d[1] * 256) / (255-src_g)) > 255 ? 255 : (d[1] * 256) / (255-src_g);
-					src_b = src_b == 255 ? 255 : ((d[2] * 256) / (255-src_b)) > 255 ? 255 : (d[2] * 256) / (255-src_b);
+					src_r = src_r == 255 ? 255 : ((d[0] * 256) / (255 - src_r)) > 255 ? 255 : (d[0] * 256) / (255 - src_r);
+					src_g = src_g == 255 ? 255 : ((d[1] * 256) / (255 - src_g)) > 255 ? 255 : (d[1] * 256) / (255 - src_g);
+					src_b = src_b == 255 ? 255 : ((d[2] * 256) / (255 - src_b)) > 255 ? 255 : (d[2] * 256) / (255 - src_b);
 					if (cmyk)
-						src_a = src_a == 255 ? 255 : ((d[3] * 256) / (255-src_a)) > 255 ? 255 : (d[3] * 256) / (255-src_a);
+						src_a = src_a == 255 ? 255 : ((d[3] * 256) / (255 - src_a)) > 255 ? 255 : (d[3] * 256) / (255 - src_a);
 				}
 				else if (layBlend == "idiv")
 				{
-					src_r = src_r == 0 ? 0 : (255 - (((255-d[0]) * 256) / src_r)) < 0 ? 0 : 255 - (((255-d[0]) * 256) / src_r);
-					src_g = src_g == 0 ? 0 : (255 - (((255-d[1]) * 256) / src_g)) < 0 ? 0 : 255 - (((255-d[1]) * 256) / src_g);
-					src_b = src_b == 0 ? 0 : (255 - (((255-d[2]) * 256) / src_b)) < 0 ? 0 : 255 - (((255-d[2]) * 256) / src_b);
+					src_r = src_r == 0 ? 0 : (255 - (((255 - d[0]) * 256) / src_r)) < 0 ? 0 : 255 - (((255 - d[0]) * 256) / src_r);
+					src_g = src_g == 0 ? 0 : (255 - (((255 - d[1]) * 256) / src_g)) < 0 ? 0 : 255 - (((255 - d[1]) * 256) / src_g);
+					src_b = src_b == 0 ? 0 : (255 - (((255 - d[2]) * 256) / src_b)) < 0 ? 0 : 255 - (((255 - d[2]) * 256) / src_b);
 					if (cmyk)
-						src_a = src_a == 0 ? 0 : (255 - (((255-d[3]) * 256) / src_a)) < 0 ? 0 : 255 - (((255-d[3]) * 256) / src_a);
+						src_a = src_a == 0 ? 0 : (255 - (((255 - d[3]) * 256) / src_a)) < 0 ? 0 : 255 - (((255 - d[3]) * 256) / src_a);
 				}
 				else if (layBlend == "hue ")
 				{
@@ -652,7 +650,7 @@ bool ScImgDataLoader_TIFF::loadPicture(const QString& fn, int page, int res, boo
 	bool bilevel = false;
 	bool failedPS = false;
 	bool foundPS = false;
-	short resolutionunit = RESUNIT_INCH; // Default unit is inch
+	short resolutionUnit = RESUNIT_INCH; // Default unit is inch
 	float xres = 72.0, yres = 72.0;
 	if (!QFile::exists(fn))
 		return false;
@@ -693,18 +691,22 @@ bool ScImgDataLoader_TIFF::loadPicture(const QString& fn, int page, int res, boo
 	bool isCMYK = false;
 	unsigned int widtht, heightt, size;
 	char *description=nullptr, *copyright=nullptr, *datetime=nullptr, *artist=nullptr, *scannerMake=nullptr, *scannerModel=nullptr;
-	uint16 bitspersample, fillorder, planar;
+	uint16_t bitsPerSample = 1;
+	uint16_t sampleFormat = SAMPLEFORMAT_UINT;
+	uint16_t fillorder = FILLORDER_MSB2LSB;
+	uint16_t planar = PLANARCONFIG_CONTIG;
 
 	TIFFGetField(tif, TIFFTAG_IMAGEWIDTH, &widtht);
 	TIFFGetField(tif, TIFFTAG_IMAGELENGTH, &heightt);
 	TIFFGetField(tif, TIFFTAG_XRESOLUTION, &xres);
 	TIFFGetField(tif, TIFFTAG_YRESOLUTION, &yres);
-	TIFFGetField(tif, TIFFTAG_RESOLUTIONUNIT , &resolutionunit);
+	TIFFGetField(tif, TIFFTAG_RESOLUTIONUNIT , &resolutionUnit);
 	size = widtht * heightt;
 	TIFFGetField(tif, TIFFTAG_PHOTOMETRIC, &m_photometric);
 	TIFFGetField(tif, TIFFTAG_PLANARCONFIG, &planar);
-	TIFFGetField(tif, TIFFTAG_BITSPERSAMPLE, &bitspersample);
-	TIFFGetField(tif, TIFFTAG_SAMPLESPERPIXEL, &m_samplesperpixel);
+	TIFFGetField(tif, TIFFTAG_BITSPERSAMPLE, &bitsPerSample);
+	TIFFGetField(tif, TIFFTAG_SAMPLESPERPIXEL, &m_samplesPerPixel);
+	TIFFGetField(tif, TIFFTAG_SAMPLEFORMAT, &sampleFormat);
 	TIFFGetField(tif, TIFFTAG_FILLORDER, &fillorder);
 
 	TIFFGetField(tif, TIFFTAG_MAKE, &scannerMake);
@@ -713,6 +715,14 @@ bool ScImgDataLoader_TIFF::loadPicture(const QString& fn, int page, int res, boo
 	TIFFGetField(tif, TIFFTAG_COPYRIGHT, &copyright);
 	TIFFGetField(tif, TIFFTAG_DATETIME, &datetime);
 	TIFFGetField(tif, TIFFTAG_ARTIST, &artist);
+
+	SampleFormatInfo sampleInfo;
+	sampleInfo.photometric = m_photometric;
+	sampleInfo.bitsPerSample = bitsPerSample;
+	sampleInfo.samplesPerPixel = m_samplesPerPixel;
+	sampleInfo.samplesFormat = sampleFormat;
+	sampleInfo.fillOrder = fillorder;
+
 	m_imageInfoRecord.exifInfo.cameraName = QString(scannerModel);
 	m_imageInfoRecord.exifInfo.cameraVendor = QString(scannerMake);
 	m_imageInfoRecord.exifInfo.comment = QString(description);
@@ -723,7 +733,7 @@ bool ScImgDataLoader_TIFF::loadPicture(const QString& fn, int page, int res, boo
 	m_imageInfoRecord.exifInfo.artist = QString(artist);
 	m_imageInfoRecord.exifInfo.thumbnail = QImage();
 	m_imageInfoRecord.exifDataValid = true;
-	uint32 EmbedLen = 0;
+	uint32_t EmbedLen = 0;
 	void*  EmbedBuffer;
 	if (TIFFGetField(tif, TIFFTAG_ICCPROFILE, &EmbedLen, &EmbedBuffer))
 	{
@@ -764,14 +774,14 @@ bool ScImgDataLoader_TIFF::loadPicture(const QString& fn, int page, int res, boo
 					isCMYK = true;
 					m_imageInfoRecord.colorspace = ColorSpaceCMYK;
 				}
-				else if (m_samplesperpixel == 1)
+				else if (m_samplesPerPixel == 1)
 				{
 					m_imageInfoRecord.colorspace = ColorSpaceGray;
 					isCMYK = false;
 				}
 				else
 					m_imageInfoRecord.colorspace = ColorSpaceRGB;
-				if (bitspersample == 1)
+				if (bitsPerSample == 1)
 					bilevel = true;
 				if (!m_imageInfoRecord.exifInfo.thumbnail.isNull())
 				{
@@ -855,7 +865,7 @@ bool ScImgDataLoader_TIFF::loadPicture(const QString& fn, int page, int res, boo
 				fakeHeader.color_mode = CM_CMYK;
 				chans = 5;
 			}
-			else if (m_samplesperpixel == 1)
+			else if (m_samplesPerPixel == 1)
 			{
 				fakeHeader.color_mode = CM_GRAYSCALE;
 				isCMYK = false;
@@ -900,10 +910,10 @@ bool ScImgDataLoader_TIFF::loadPicture(const QString& fn, int page, int res, boo
 		int chans = 4;
 		if (m_photometric == PHOTOMETRIC_SEPARATED)
 		{
-			if (m_samplesperpixel > 5) 
+			if (m_samplesPerPixel > 5) 
 				chans = 4;
 			else
-				chans = m_samplesperpixel;
+				chans = m_samplesPerPixel;
 		}
 		else
 			chans = 4;
@@ -924,7 +934,7 @@ bool ScImgDataLoader_TIFF::loadPicture(const QString& fn, int page, int res, boo
 			}
 
 			tmpImg.fill(0);
-			if (!getImageData(tif, &tmpImg, widtht, heightt, size, m_photometric, bitspersample, m_samplesperpixel, bilevel, isCMYK))
+			if (!getImageData(tif, &tmpImg, widtht, heightt, size, sampleInfo, bilevel, isCMYK))
 			{
 				TIFFClose(tif);
 				return false;
@@ -987,14 +997,14 @@ bool ScImgDataLoader_TIFF::loadPicture(const QString& fn, int page, int res, boo
 		while (test == 1);
 		TIFFClose(tif);
 	}
-	if (resolutionunit == RESUNIT_INCH)
+	if (resolutionUnit == RESUNIT_INCH)
 	{
 		m_image.setDotsPerMeterX ((int) (xres / 0.0254));
 		m_image.setDotsPerMeterY ((int) (yres / 0.0254));
 		m_imageInfoRecord.xres = qRound(xres);
 		m_imageInfoRecord.yres = qRound(yres);
 	}
-	else if (resolutionunit == RESUNIT_CENTIMETER)
+	else if (resolutionUnit == RESUNIT_CENTIMETER)
 	{
 		m_image.setDotsPerMeterX ((int) (xres * 100.0));
 		m_image.setDotsPerMeterY ((int) (yres * 100.0));
@@ -1006,10 +1016,10 @@ bool ScImgDataLoader_TIFF::loadPicture(const QString& fn, int page, int res, boo
 		m_imageInfoRecord.colorspace = ColorSpaceCMYK;
 		m_pixelFormat = (r_image.channels() == 5) ? Format_CMYKA_8 : Format_CMYK_8;
 	}
-	else if (m_samplesperpixel == 1)
+	else if (m_samplesPerPixel == 1)
 	{
 		// Do not set m_pixelFormat here as the real pixel format is most probably different than gray
-		if (bitspersample == 1)
+		if (bitsPerSample == 1)
 			m_imageInfoRecord.colorspace = ColorSpaceMonochrome;
 		else
 			m_imageInfoRecord.colorspace = ColorSpaceGray;
@@ -1052,7 +1062,7 @@ QString ScImgDataLoader_TIFF::getLayerString(QDataStream & s)
 
 bool ScImgDataLoader_TIFF::loadChannel( QDataStream & s, const PSDHeader & header, QList<PSDLayer> &layerInfo, uint layer, int channel, int component, RawImage &tmpImg)
 {
-	uint base = s.device()->pos();
+	qint64 base = s.device()->pos();
 	uchar cbyte;
 	ushort compression;
 	s >> compression;
@@ -1060,7 +1070,7 @@ bool ScImgDataLoader_TIFF::loadChannel( QDataStream & s, const PSDHeader & heade
 		return false;
 	if (compression == 0)
 	{
-		int count = layerInfo[layer].channelLen[channel]-2;
+		int count = layerInfo[layer].channelLen[channel] - 2;
 		for (int i = 0; i < tmpImg.height(); i++)
 		{
 			uchar *ptr =  tmpImg.scanLine(i);
@@ -1167,7 +1177,7 @@ bool ScImgDataLoader_TIFF::loadChannel( QDataStream & s, const PSDHeader & heade
 			}
 		}
 	}
-	s.device()->seek( base+layerInfo[layer].channelLen[channel] );
+	s.device()->seek( base + layerInfo[layer].channelLen[channel] );
 	return true;
 }
 
@@ -1323,8 +1333,8 @@ bool ScImgDataLoader_TIFF::loadLayerChannels( QDataStream & s, const PSDHeader &
 	// Known values:
 	//   0: no compression
 	//   1: RLE compressed
-	uint base = s.device()->pos();
-	uint base2 = base;
+	qint64 base = s.device()->pos();
+	qint64 base2 = base;
 	uint channel_num = layerInfo[layer].channelLen.count();
 	bool hasMask = false;
 	bool hasAlpha = false;
@@ -1608,19 +1618,19 @@ bool ScImgDataLoader_TIFF::loadLayerChannels( QDataStream & s, const PSDHeader &
 						}
 						else if (layBlend == "scrn")
 						{
-							src_r = 255 - ((255-src_r) * (255-d[0]) / 128);
-							src_g = 255 - ((255-src_g) * (255-d[1]) / 128);
-							src_b = 255 - ((255-src_b) * (255-d[2]) / 128);
+							src_r = 255 - ((255 - src_r) * (255 - d[0]) / 128);
+							src_g = 255 - ((255 - src_g) * (255 - d[1]) / 128);
+							src_b = 255 - ((255 - src_b) * (255 - d[2]) / 128);
 							if (header.color_mode == CM_CMYK)
-								src_a = 255 - ((255-src_a) * (255-d[3]) / 128);
+								src_a = 255 - ((255 - src_a) * (255 - d[3]) / 128);
 						}
 						else if (layBlend == "over")
 						{
-							src_g = d[1] < 128 ? src_g * d[1] / 128 : 255 - ((255-src_g) * (255-d[1]) / 128);
-							src_b = d[2] < 128 ? src_b * d[2] / 128 : 255 - ((255-src_b) * (255-d[2]) / 128);
-							src_a = d[3] < 128 ? src_a * d[3] / 128 : 255 - ((255-src_a) * (255-d[3]) / 128);
+							src_g = d[1] < 128 ? src_g * d[1] / 128 : 255 - ((255 - src_g) * (255 - d[1]) / 128);
+							src_b = d[2] < 128 ? src_b * d[2] / 128 : 255 - ((255 - src_b) * (255 - d[2]) / 128);
+							src_a = d[3] < 128 ? src_a * d[3] / 128 : 255 - ((255 - src_a) * (255 - d[3]) / 128);
 							if (header.color_mode == CM_CMYK)
-								src_r = d[0] < 128 ? src_r * d[0] / 128 : 255 - ((255-src_r) * (255-d[0]) / 128);
+								src_r = d[0] < 128 ? src_r * d[0] / 128 : 255 - ((255 - src_r) * (255 - d[0]) / 128);
 						}
 						else if (layBlend == "diff")
 						{
@@ -1640,19 +1650,19 @@ bool ScImgDataLoader_TIFF::loadLayerChannels( QDataStream & s, const PSDHeader &
 						}
 						else if (layBlend == "hLit")
 						{
-							src_r = src_r < 128 ? src_r * d[0] / 128 : 255 - ((255-src_r) * (255-d[0]) / 128);
-							src_g = src_g < 128 ? src_g * d[1] / 128 : 255 - ((255-src_g) * (255-d[1]) / 128);
-							src_b = src_b < 128 ? src_b * d[2] / 128 : 255 - ((255-src_b) * (255-d[2]) / 128);
+							src_r = src_r < 128 ? src_r * d[0] / 128 : 255 - ((255 - src_r) * (255 - d[0]) / 128);
+							src_g = src_g < 128 ? src_g * d[1] / 128 : 255 - ((255 - src_g) * (255 - d[1]) / 128);
+							src_b = src_b < 128 ? src_b * d[2] / 128 : 255 - ((255 - src_b) * (255 - d[2]) / 128);
 							if (header.color_mode == CM_CMYK)
-								src_a = src_a < 128 ? src_a * d[3] / 128 : 255 - ((255-src_a) * (255-d[3]) / 128);
+								src_a = src_a < 128 ? src_a * d[3] / 128 : 255 - ((255 - src_a) * (255 - d[3]) / 128);
 						}
 						else if (layBlend == "sLit")
 						{
-							src_r = src_r * d[0] / 256 + src_r * (255 - ((255-src_r)*(255-d[0]) / 256) - src_r * d[0] / 256) / 256;
-							src_g = src_g * d[1] / 256 + src_g * (255 - ((255-src_g)*(255-d[1]) / 256) - src_g * d[1] / 256) / 256;
-							src_b = src_b * d[2] / 256 + src_b * (255 - ((255-src_b)*(255-d[2]) / 256) - src_b * d[2] / 256) / 256;
+							src_r = src_r * d[0] / 256 + src_r * (255 - ((255 - src_r)*(255 - d[0]) / 256) - src_r * d[0] / 256) / 256;
+							src_g = src_g * d[1] / 256 + src_g * (255 - ((255 - src_g)*(255 - d[1]) / 256) - src_g * d[1] / 256) / 256;
+							src_b = src_b * d[2] / 256 + src_b * (255 - ((255 - src_b)*(255 - d[2]) / 256) - src_b * d[2] / 256) / 256;
 							if (header.color_mode == CM_CMYK)
-								src_a = src_a * d[3] / 256 + src_a * (255 - ((255-src_a)*(255-d[3]) / 256) - src_a * d[3] / 256) / 256;
+								src_a = src_a * d[3] / 256 + src_a * (255 - ((255 - src_a)*(255 - d[3]) / 256) - src_a * d[3] / 256) / 256;
 						}
 						else if (layBlend == "lite")
 						{
@@ -1672,19 +1682,19 @@ bool ScImgDataLoader_TIFF::loadLayerChannels( QDataStream & s, const PSDHeader &
 						}
 						else if (layBlend == "div ")
 						{
-							src_r = src_r == 255 ? 255 : ((d[0] * 256) / (255-src_r)) > 255 ? 255 : (d[0] * 256) / (255-src_r);
-							src_g = src_g == 255 ? 255 : ((d[1] * 256) / (255-src_g)) > 255 ? 255 : (d[1] * 256) / (255-src_g);
-							src_b = src_b == 255 ? 255 : ((d[2] * 256) / (255-src_b)) > 255 ? 255 : (d[2] * 256) / (255-src_b);
+							src_r = src_r == 255 ? 255 : ((d[0] * 256) / (255 - src_r)) > 255 ? 255 : (d[0] * 256) / (255 - src_r);
+							src_g = src_g == 255 ? 255 : ((d[1] * 256) / (255 - src_g)) > 255 ? 255 : (d[1] * 256) / (255 - src_g);
+							src_b = src_b == 255 ? 255 : ((d[2] * 256) / (255 - src_b)) > 255 ? 255 : (d[2] * 256) / (255 - src_b);
 							if (header.color_mode == CM_CMYK)
-								src_a = src_a == 255 ? 255 : ((d[3] * 256) / (255-src_a)) > 255 ? 255 : (d[3] * 256) / (255-src_a);
+								src_a = src_a == 255 ? 255 : ((d[3] * 256) / (255 - src_a)) > 255 ? 255 : (d[3] * 256) / (255 - src_a);
 						}
 						else if (layBlend == "idiv")
 						{
-							src_r = src_r == 0 ? 0 : (255 - (((255-d[0]) * 256) / src_r)) < 0 ? 0 : 255 - (((255-d[0]) * 256) / src_r);
-							src_g = src_g == 0 ? 0 : (255 - (((255-d[1]) * 256) / src_g)) < 0 ? 0 : 255 - (((255-d[1]) * 256) / src_g);
-							src_b = src_b == 0 ? 0 : (255 - (((255-d[2]) * 256) / src_b)) < 0 ? 0 : 255 - (((255-d[2]) * 256) / src_b);
+							src_r = src_r == 0 ? 0 : (255 - (((255 - d[0]) * 256) / src_r)) < 0 ? 0 : 255 - (((255 - d[0]) * 256) / src_r);
+							src_g = src_g == 0 ? 0 : (255 - (((255 - d[1]) * 256) / src_g)) < 0 ? 0 : 255 - (((255 - d[1]) * 256) / src_g);
+							src_b = src_b == 0 ? 0 : (255 - (((255 - d[2]) * 256) / src_b)) < 0 ? 0 : 255 - (((255 - d[2]) * 256) / src_b);
 							if (header.color_mode == CM_CMYK)
-								src_a = src_a == 0 ? 0 : (255 - (((255-d[3]) * 256) / src_a)) < 0 ? 0 : 255 - (((255-d[3]) * 256) / src_a);
+								src_a = src_a == 0 ? 0 : (255 - (((255 - d[3]) * 256) / src_a)) < 0 ? 0 : 255 - (((255 - d[3]) * 256) / src_a);
 						}
 						else if (layBlend == "hue ")
 						{
