@@ -288,7 +288,7 @@ public: // Start public functions
 	void DrawObj_Pre(ScPainter *p);
 	virtual void DrawObj_Post(ScPainter *p);
 	virtual void DrawObj_Decoration(ScPainter *p);
-	virtual void DrawObj_Item(ScPainter *p, QRectF e) = 0;
+	virtual void DrawObj_Item(ScPainter *p, const QRectF& e) = 0;
 	QImage DrawObj_toImage(double maxSize, int options = 0);
 	QImage DrawObj_toImage(QList<PageItem*> &emG, double scaling);
 	void DrawObj_Embedded(ScPainter *p, QRectF cullingArea, const CharStyle& style, PageItem* cembedded);
@@ -677,10 +677,10 @@ public: // Start public functions
 	void set4ColorTransparency(double t1, double t2, double t3, double t4);
 	void set4ColorShade(int t1, int t2, int t3, int t4);
 	void set4ColorColors(const QString& col1, const QString& col2, const QString& col3, const QString& col4);
-	void get4ColorGeometry(FPoint& c1, FPoint& c2, FPoint& c3, FPoint& c4);
+	void get4ColorGeometry(FPoint& c1, FPoint& c2, FPoint& c3, FPoint& c4) const;
 	void setDiamondGeometry(const FPoint& c1, const FPoint& c2, const FPoint& c3, const FPoint& c4, const FPoint& c5);
-	void get4ColorTransparency(double &t1, double &t2, double &t3, double &t4);
-	void get4ColorColors(QString &col1, QString &col2, QString &col3, QString &col4);
+	void get4ColorTransparency(double &t1, double &t2, double &t3, double &t4) const;
+	void get4ColorColors(QString &col1, QString &col2, QString &col3, QString &col4) const;
 	void setMeshPointColor(int x, int y, const QString& color, int shade, double transparency, bool forPatch = false);
 	void createGradientMesh(int rows, int cols);
 	void resetGradientMesh();
@@ -802,7 +802,7 @@ public: // Start public functions
 	 * of its Qt name.
 	 * See also PageItem::setItemName()
 	 */
-	QString itemName() const { return m_itemName; }
+	const QString& itemName() const { return m_itemName; }
 	/**
 	 * @brief Set name of the item
 	 * @param newName name for the item
@@ -1151,7 +1151,7 @@ public: // Start public functions
 	/** @brief Get the subclass item type
 	 *
 	 * This function should be used everywhere, where a itemType is required, but
-	 * no C++ type informations is available. e.g. when saving files, etc.
+	 * no C++ type information is available. e.g. when saving files, etc.
 	 * It returns the same type as itemType() for the standard classes, but
 	 * subclasses override it.
 	 */
@@ -1270,7 +1270,8 @@ public: // Start public functions
 		// End public functions
 
 public:	// Start public variables
-	int maxCharsInFrame();
+	int maxCharsInFrame() const;
+
 	bool AutoName {true};
 	double gXpos {0.0};
 	double gYpos {0.0};
@@ -1518,7 +1519,7 @@ protected: // Start protected functions
 	void DrawObj_Polygon(ScPainter *p);
 	void DrawObj_PolyLine(ScPainter *p);
 	void DrawObj_PathText(ScPainter *p, double sc);
-	void drawLockedMarker(ScPainter *p);
+	void drawLockedMarker(ScPainter *p) const;
 	void drawArrow(ScPainter *p, QTransform &arrowTrans, int arrowIndex);
 
 	/** @brief Manages undostack and is where all undo actions/states are sent. */
@@ -1853,7 +1854,7 @@ protected: // Start protected variables
 	double m_height {0.0}; ///<  Height of the item
 	double m_rotation {0.0}; ///< Rotation of the item
 	bool   m_isSelected {false}; ///< Is the item selected?
-	bool   m_imageVisible {true}; ///< Darstellungsart Bild/Titel
+	bool   m_imageVisible {true}; ///< Is the image/title visible?
 	double m_imageXScale {1.0}; ///< Scaling X Factor for images
 	double m_imageYScale {1.0}; ///< Scaling Y Factor for images
 	double m_imageXOffset {0.0}; ///< Image X Offset to frame
