@@ -29,6 +29,7 @@ for which a new license (GPL+exception) is in place.
 
 #include "commonstrings.h"
 #include "pageitem_group.h"
+#include "pageitemiterator.h"
 #include "prefsmanager.h"
 #include "scpainter.h"
 #include "scpage.h"
@@ -59,6 +60,21 @@ PageItem_Group::~PageItem_Group()
 //	}
 }
 
+bool PageItem_Group::isTextContainer() const
+{
+	PageItemIterator it(groupItemList, PageItemIterator::IterateInGroups);
+	for (; *it; ++it)
+	{
+		PageItem* item = *it;
+		if (item->isGroup())
+			continue;
+		if (item->isTextContainer())
+			return true;
+	}
+
+	return false;
+}
+
 void PageItem_Group::adjustXYPosition()
 {
 	for (int em = 0; em < groupItemList.count(); ++em)
@@ -152,7 +168,7 @@ void PageItem_Group::getNamedResources(ResourceCollection& lists) const
 	}
 }
 
-void PageItem_Group::DrawObj_Item(ScPainter *p, QRectF /*e*/)
+void PageItem_Group::DrawObj_Item(ScPainter *p, const QRectF& /*e*/)
 {
 	if (m_Doc->RePos)
 		return;
