@@ -8,6 +8,7 @@
 #include "pageitem_textframe.h"
 
 #include "scribusdoc.h"
+#include "textnote.h"
 #include "undomanager.h"
 #include "util.h"
 #include "util_text.h"
@@ -15,7 +16,7 @@
 #include "text/boxes.h"
 
 PageItem_NoteFrame::PageItem_NoteFrame(NotesStyle *nStyle, ScribusDoc *doc, double x, double y, double w, double h, double w2, const QString& fill, const QString& outline)
-    : PageItem_TextFrame(doc, x, y, w, h, w2, fill, outline)
+	: PageItem_TextFrame(doc, x, y, w, h, w2, fill, outline)
 {
 	m_nstyle = nStyle;
 	itemText.clear();
@@ -23,7 +24,7 @@ PageItem_NoteFrame::PageItem_NoteFrame(NotesStyle *nStyle, ScribusDoc *doc, doub
 	m_itemName = generateUniqueCopyName(nStyle->isEndNotes() ? tr("Endnote frame ") + m_nstyle->name() : tr("Footnote frame ") + m_nstyle->name(), false);
 	AutoName = false; //endnotes frame will saved with name
 	setUName(m_itemName);
-	
+
 	//set default style for note frame
 	ParagraphStyle newStyle;
 	if (nStyle->notesParStyle().isEmpty() || (nStyle->notesParStyle() == tr("No Style")))
@@ -37,22 +38,13 @@ PageItem_NoteFrame::PageItem_NoteFrame(NotesStyle *nStyle, ScribusDoc *doc, doub
 	m_textFlowMode = TextFlowUsesFrameShape;
 	setColumns(1);
 
-	if (m_nstyle->isAutoNotesHeight())
-		m_SizeVLocked = true;
-	else
-		m_SizeVLocked = false;
-	if (m_nstyle->isAutoNotesWidth())
-		m_SizeHLocked = true;
-	else
-		m_SizeHLocked = false;
-	if (m_nstyle->isAutoNotesHeight() && m_nstyle->isAutoNotesWidth())
-		m_SizeLocked = true;
-	else
-		m_SizeLocked = false;
+	m_SizeVLocked = m_nstyle->isAutoNotesHeight();
+	m_SizeHLocked = m_nstyle->isAutoNotesWidth();
+	m_SizeLocked = m_nstyle->isAutoNotesHeight() && m_nstyle->isAutoNotesWidth();
 }
 
 PageItem_NoteFrame::PageItem_NoteFrame(ScribusDoc *doc, double x, double y, double w, double h, double w2, const QString& fill, const QString& outline)
-    : PageItem_TextFrame(doc, x, y, w, h, w2, fill, outline)
+	: PageItem_TextFrame(doc, x, y, w, h, w2, fill, outline)
 {
 	m_textFlowMode = TextFlowUsesFrameShape;
 }
@@ -84,7 +76,7 @@ PageItem_NoteFrame::PageItem_NoteFrame(PageItem_TextFrame* inFrame, NotesStyle *
 	itemText.blockSignals(true);
 	itemText.setDefaultStyle(newStyle);
 	itemText.blockSignals(false);
-	
+
 	double frameHeight = calculateLineSpacing(newStyle, this);
 	if (frameHeight == 0.0 && !m_nstyle->isAutoNotesHeight())
 		frameHeight = newStyle.charStyle().fontSize()/10;
@@ -151,7 +143,7 @@ void PageItem_NoteFrame::setNoteStyle(NotesStyle *nStyle, PageItem_TextFrame* ma
 
 	m_itemName = generateUniqueCopyName(m_nstyle->isEndNotes() ? "Endnote frame " + m_nstyle->name() : "Footnote frame " + m_nstyle->name(), false);
 	setUName(m_itemName);
-	
+
 	//set default style for note frame
 	ParagraphStyle newStyle;
 	if (nStyle->notesParStyle().isEmpty() || (nStyle->notesParStyle() == tr("No Style")))
@@ -328,42 +320,38 @@ void PageItem_NoteFrame::updateNotesText()
 	int pos = 0;
 	int startPos = 0;
 	TextNote *note = nullptr;
-	Mark* prevMrk = nullptr;
+	Mark* prevMark = nullptr;
 	while (pos < itemText.length())
 	{
-		if (itemText.hasMark(pos))
+		if (itemText.hasMark(pos, MARKNoteFrameType))
 		{
-			Mark* mark = itemText.mark(pos);
-			if  (mark->isType(MARKNoteFrameType))
+			if (prevMark != nullptr)
 			{
-				if (prevMrk != nullptr)
+				note = prevMark->getNotePtr();
+				if (note != nullptr)
 				{
-					note = prevMrk->getNotePtr();
-					if (note != nullptr)
+					int offset = 0;
+					if (itemText.text(pos - 1) == SpecialChars::PARSEP)
+						++offset;
+					int len = pos - startPos -offset;
+					if (len <= 0)
+						note->clearSaxedText();
+					else
 					{
-						int offset = 0;
-						if (itemText.text(pos-1) == SpecialChars::PARSEP)
-							++offset;
-						int len = pos - startPos -offset;
-						if (len <= 0)
-							note->clearSaxedText();
-						else
-						{
-							note->setSaxedText(getItemTextSaxed(startPos, len));
-							note->textLen = len;
-						}
-						itemText.deselectAll();
+						note->setSaxedText(getItemTextSaxed(startPos, len));
+						note->textLen = len;
 					}
+					itemText.deselectAll();
 				}
-				prevMrk = mark;
-				startPos = pos +1;
 			}
+			prevMark = itemText.mark(pos);
+			startPos = pos + 1;
 		}
 		++pos;
 	}
-	if (prevMrk != nullptr)
+	if (prevMark != nullptr)
 	{
-		note = prevMrk->getNotePtr();
+		note = prevMark->getNotePtr();
 		Q_ASSERT(note != nullptr);
 		if (startPos != pos)
 		{
@@ -425,20 +413,3 @@ void PageItem_NoteFrame::unWeld(bool doUndo)
 		weldList.clear();
 	}
 }
-
-int PageItem_NoteFrame::findNoteCpos(TextNote* note)
-{
-	//find position of note in note`s frame
-	if (itemText.length() == 0)
-		return -1;
-	for (int pos=0; pos < itemText.length(); ++pos)
-	{
-		Mark* mark = itemText.mark(pos);
-		if (itemText.hasMark(pos) && mark->isType(MARKNoteFrameType))
-		{
-			if (mark->getNotePtr() == note)
-				return (pos);
-		}
-	}
-	return -1;
-}
