@@ -48,7 +48,7 @@ PageItem_Polygon::PageItem_Polygon(ScribusDoc *pa, double x, double y, double w,
 {
 }
 
-void PageItem_Polygon::DrawObj_Item(ScPainter *p, QRectF /*e*/)
+void PageItem_Polygon::DrawObj_Item(ScPainter *p, const QRectF& /*e*/)
 {
 	if (!m_Doc->RePos)
 	{
