@@ -17,3 +17,25 @@ PDFOptions::VerifyResults PDFOptions::verify(QString* /*problemDescription*/)
 	// TODO: implement this method
 	return Verify_NoError;
 }
+
+bool PDFOptions::exportsLayers() const
+{
+	if (Version.supportsOCGs())
+		return useLayers;
+	return false;
+}
+
+bool PDFOptions::supportsEmbeddedOpenTypeFonts() const
+{
+	return Version.supportsEmbeddedOpenTypeFonts();
+}
+
+bool PDFOptions::supportsOCGs() const
+{
+	return Version.supportsOCGs();
+}
+
+bool PDFOptions::supportsTransparency() const
+{
+	return Version.supportsTransparency();
+}
\ No newline at end of file
