@@ -74,13 +74,13 @@ class BarcodeGenerator : public QDialog
 		//! \brief BC/BC type mapping. QMap keys are used as BC names.
 		BarcodeMap map;
 
-		QTimer *paintBarcodeTimer;
+		QTimer* paintBarcodeTimer { nullptr };
 
 		//! \brief List of available barcode encoders.
 		QList<QString> encoderlist;
 		//! \brief Descriptions of each encoder.
 		QHash<QString, QString> resdescs;
-		//! \brief Dependancies of each encoder.
+		//! \brief Dependencies of each encoder.
 		QHash<QString, QString> resreqs;
 		//! \brief Example data input for each encoder.
 		QHash<QString, QString> resexams;
