@@ -1186,7 +1186,7 @@ public:
 
 	void drawGlyphOutline(const GlyphCluster& gc, bool hasFill) override
 	{
-		if (gc.isControlGlyphs() | gc.isEmpty())
+		if (gc.isControlGlyphs() || gc.isEmpty())
 			return;
 
 		double current_x = 0.0;
@@ -1233,7 +1233,7 @@ public:
 		m_elem.appendChild(path);
 	}
 
-	void drawRect(QRectF rect) override
+	void drawRect(const QRectF& rect) override
 	{
 		QTransform transform = matrix();
 		transform.translate(x(), y());
