@@ -843,7 +843,7 @@ void DrwPlug::decodeCmd(quint8 cmd, int pos)
 			break;
 		case 32:
 			cmdText += "DRW Band";
-/* For this record the documentation is completly wrong
+/* For this record the documentation is completely wrong
 
 	offs	meaning
 	0		X-Offset
@@ -1863,8 +1863,7 @@ void DrwPlug::handleGradient(PageItem* currentItem, quint8 patternIndex, const Q
 					image = image.scaled(48, 48);
 				}
 				image = image.convertToFormat(QImage::Format_ARGB32);
-				ScPattern pat = ScPattern();
-				pat.setDoc(m_Doc);
+				ScPattern pat(m_Doc);
 				PageItem* newItem = new PageItem_ImageFrame(m_Doc, 0, 0, 1, 1, 0, CommonStrings::None, CommonStrings::None);
 				QTemporaryFile *tempFile = new QTemporaryFile(QDir::tempPath() + "/scribus_temp_drw_XXXXXX.png");
 				tempFile->setAutoRemove(false);
