@@ -2000,7 +2000,7 @@ void PctPlug::handleComment(QDataStream &ts, bool longComment)
 		case 170:			// picArrw1 Arrowhead on 2nd point of line
 //			qDebug() << "Comment type: picArrw1";
 			break;
-		case 171:			// picArrw2 Arrowhead on 1nd point of line
+		case 171:			// picArrw2 Arrowhead on 1st point of line
 //			qDebug() << "Comment type: picArrw2";
 			break;
 		case 172:			// picArrw3 Arrowhead on both endpoints
@@ -2179,8 +2179,7 @@ void PctPlug::setFillPattern(PageItem* ite)
 			*q = patternData[rr];
 		}
 		image = image.convertToFormat(QImage::Format_ARGB32);
-		ScPattern pat = ScPattern();
-		pat.setDoc(m_Doc);
+		ScPattern pat(m_Doc);
 		PageItem* newItem = new PageItem_ImageFrame(m_Doc, 0, 0, 1, 1, 0, CommonStrings::None, CommonStrings::None);
 		QTemporaryFile *tempFile = new QTemporaryFile(QDir::tempPath() + "/scribus_temp_pct_XXXXXX.png");
 		tempFile->setAutoRemove(false);
