@@ -289,7 +289,7 @@ PdfTextRegion::LineType PdfTextRegion::isRegionConcurrent(QPointF newPoint)
 *	Move the position of the cursor to a new point,
 *	test if that point is within the current textframe or within a new textframe.
 *	initialize the textregion and setup lines and segments
-*	TODO: iscloseto x and y may need to be different from addGlyph but use thge common isRegionbConcurrent for now
+*	TODO: iscloseto x and y may need to be different from addGlyph but use the common isRegionbConcurrent for now
 *		need to check to see if we are creating a new paragraph or not.
 *		basically if the cursor is returned to x origin before it reached x width.
 *		Also needs to have support for rotated text, but I expect I'll add this by removing the text rotation
@@ -353,8 +353,8 @@ PdfTextRegion::LineType PdfTextRegion::moveToPoint(QPointF newPoint)
 /*
 *	Add a new glyph to the current line segment, lines and segments should already have been setup by the
 *	moveto function which should generally be called prior to addGlyph to setup the lines and segments correctly.
-*	does some basic calculations to determine and save withs and heights and linespacings of texts etc...
-*	FIXME: these need to be changed to use the mode average of all glyps added to the text frame instead of just picking the first ones we come accross
+*	does some basic calculations to determine and save widths and heights and linespacings of texts etc...
+*	FIXME: these need to be changed to use the mode average of all glyps added to the text frame instead of just picking the first ones we come across
 *		the mode average can also be used to determine the base font style when fonts are added
 *		left and right hand margins however need to use the maximum and minimum, support for right hand justification
 *		and centered text needs to be added as we only support left and fully justified at the moment.
@@ -503,7 +503,6 @@ void PdfTextOutputDev::renderTextFrame()
 
 	qreal xCoor = m_doc->currentPage()->xOffset() + activePdfTextRegion->pdfTextRegionBasenOrigin.x();
 	qreal yCoor = m_doc->currentPage()->yOffset() + activePdfTextRegion->pdfTextRegionBasenOrigin.y() - activePdfTextRegion->lineSpacing; // don't know if y is top down or bottom up
-	qreal  lineWidth = 0.0;
 #ifdef DEBUG_TEXT_IMPORT
 	qDebug() << "rendering new frame at:" << xCoor << "," << yCoor << " With lineheight of: " << activePdfTextRegion->lineSpacing << "Height:" << activePdfTextRegion->maxHeight << " Width:" << activePdfTextRegion->maxWidth;
 #endif
@@ -519,6 +518,9 @@ void PdfTextOutputDev::renderTextFrame()
 	cStyle.setScaleV(1000.0);
 	cStyle.setHyphenChar(SpecialChars::BLANK.unicode());
 
+	// #16567: Override user prefs
+	textNode->setColumns(1);
+
 	Selection tempSelection(nullptr, false);
 	tempSelection.addItem(textNode);
 	m_doc->itemSelection_ApplyParagraphStyle(pStyle, &tempSelection);
@@ -533,7 +535,7 @@ void PdfTextOutputDev::renderTextFrame()
 	textNode->setLineTransparency(1.0);
 	textNode->setFillColor(CommonStrings::None);
 	textNode->setLineColor(CommonStrings::None);
-	textNode->setLineWidth(0);
+	textNode->setLineWidth(0.0);
 	textNode->setFillShade(m_currFillShade);
 
 
@@ -549,9 +551,9 @@ void PdfTextOutputDev::renderTextFrame()
 	g_free(transform);
 	*/
 
-	int shade = 100;
 	/*
 	* This code sets the font and style in a very simplistic way, it's been commented out as it needs to be updated to be used within PdfTextRecognition &co.
+	int shade = 100;
 	QString CurrColorText = getColor(state->getFillColorSpace(), state->getFillColor(), &shade);
 	applyTextStyleToCharStyle(pStyle.charStyle(), _glyphs[0].style->getFont().family(), CurrColorText, _glyphs[0].style->getFont().pointSizeF());// *_font_scaling);
 	*/
@@ -632,12 +634,13 @@ void PdfTextOutputDev::beginTextObject(GfxState* state)
 
 void PdfTextOutputDev::endTextObject(GfxState* state)
 {
-	if (!m_pdfTextRecognition.activePdfTextRegion->pdfTextRegionLines.empty())
+	auto* activePdfTextRegion = m_pdfTextRecognition.activePdfTextRegion;
+	if (!activePdfTextRegion->pdfTextRegionLines.empty() && activePdfTextRegion->glyphs.size() > 0)
 	{
 		// Add the last glyph to the textregion
-		QPointF glyphXY = m_pdfTextRecognition.activePdfTextRegion->lastXY;
-		m_pdfTextRecognition.activePdfTextRegion->lastXY.setX(m_pdfTextRecognition.activePdfTextRegion->lastXY.x() - m_pdfTextRecognition.activePdfTextRegion->glyphs.back().dx);
-		if (m_pdfTextRecognition.activePdfTextRegion->addGlyphAtPoint(glyphXY, m_pdfTextRecognition.activePdfTextRegion->glyphs.back()) == PdfTextRegion::LineType::FAIL)
+		QPointF glyphXY = activePdfTextRegion->lastXY;
+		activePdfTextRegion->lastXY.setX(activePdfTextRegion->lastXY.x() - activePdfTextRegion->glyphs.back().dx);
+		if (activePdfTextRegion->addGlyphAtPoint(glyphXY, activePdfTextRegion->glyphs.back()) == PdfTextRegion::LineType::FAIL)
 		{
 			qDebug("FIXME: Rogue glyph detected, this should never happen because the cursor should move before glyphs in new regions are added.");
 		}
@@ -646,7 +649,7 @@ void PdfTextOutputDev::endTextObject(GfxState* state)
 #endif
 		renderTextFrame();
 	}
-	else if (!m_pdfTextRecognition.activePdfTextRegion->pdfTextRegionLines.empty())
+	else if (!activePdfTextRegion->pdfTextRegionLines.empty())
 		qDebug("FIXME:Rogue textblock");
 
 	m_pdfTextRecognition.setCharMode(PdfTextRecognition::AddCharMode::ADDFIRSTCHAR);
