@@ -141,12 +141,12 @@ public:
 	void fill(GfxState *state) override;
 	void drawString(GfxState *state, POPPLER_CONST GooString *s) override;
 
-	QString CurrColorText;
-	QString CurrColorFill;
-	QString CurrColorStroke;
-	double m_fontSize {12};
-	GooString *m_fontName {nullptr};
-	GooString *m_itemText {nullptr};
+	QString currColorText;
+	QString currColorFill;
+	QString currColorStroke;
+	double  fontSize {12};
+	GooString *fontName {nullptr};
+	GooString *itemText {nullptr};
 
 private:
 	QString getColor(GfxColorSpace *color_space, POPPLER_CONST_070 GfxColor *color, int *shade);
@@ -155,6 +155,7 @@ private:
 };
 
 
+
 class SlaOutputDev : public OutputDev
 {
 public:
@@ -196,7 +197,11 @@ public:
 	void stroke(GfxState *state) override;
 	void fill(GfxState *state) override;
 	void eoFill(GfxState *state) override;
+#if POPPLER_ENCODED_VERSION >= POPPLER_VERSION_ENCODE(21, 3, 0)
+	bool tilingPatternFill(GfxState *state, Gfx *gfx, Catalog *cat, GfxTilingPattern *tPat, const double *mat, int x0, int y0, int x1, int y1, double xStep, double yStep) override;
+#else
 	GBool tilingPatternFill(GfxState *state, Gfx *gfx, Catalog *cat, Object *str, POPPLER_CONST_070 double *pmat, int paintType, int tilingType, Dict *resDict, POPPLER_CONST_070 double *mat, POPPLER_CONST_070 double *bbox, int x0, int y0, int x1, int y1, double xStep, double yStep) override;
+#endif
 	GBool functionShadedFill(GfxState * /*state*/, GfxFunctionShading * /*shading*/) override { qDebug() << "Function Shaded Fill";  return gFalse; }
 	GBool axialShadedFill(GfxState *state, GfxAxialShading *shading, double tMin, double tMax) override;
 	GBool axialShadedSupportExtend(GfxState *state, GfxAxialShading *shading)  override { return (shading->getExtend0() == shading->getExtend1()); }
@@ -263,7 +268,7 @@ public:
 
 	void updateFillColor(GfxState *state) override;
 	void updateStrokeColor(GfxState *state) override;
-	void updateFont(GfxState *state) override;
+	void updateFont(GfxState* state) override;
 
 	//----- text drawing
 	void  beginTextObject(GfxState *state) override;
@@ -280,10 +285,37 @@ public:
 	//----- links
 	void processLink(AnnotLink * /*link*/) override { qDebug() << "Draw Link"; }
 
-	bool layersSetByOCG;
-	double cropOffsetX {0.0};
-	double cropOffsetY {0.0};
-	int rotate;
+	bool layersSetByOCG { false };
+	double cropOffsetX { 0.0 };
+	double cropOffsetY { 0.0 };
+	int rotate { 0 };
+
+protected:
+	void setItemFillAndStroke(GfxState* state, PageItem* textNode);
+	void applyMask(PageItem* ite);
+	void pushGroup(const QString& maskName = "", GBool forSoftMask = gFalse, GBool alpha = gFalse, bool inverted = false);
+
+	ScribusDoc* m_doc;
+	Qt::PenCapStyle m_lineEnd { Qt::FlatCap };
+	Qt::PenJoinStyle m_lineJoin { Qt::MiterJoin };
+	QList<PageItem*>* m_Elements;
+
+	struct groupEntry
+	{
+		QList<PageItem*> Items;
+		GBool forSoftMask { gFalse };
+		GBool isolated { gFalse };
+		GBool alpha { gFalse };
+		QString maskName;
+		QPointF maskPos;
+		bool inverted { false };
+	};
+
+	QStack<groupEntry> m_groupStack;
+	QString m_currColorFill;
+	QString m_currColorStroke;
+	int m_currFillShade { 100 };
+	int m_currStrokeShade { 100 };
 
 private:
 	void getPenState(GfxState *state);
@@ -291,8 +323,6 @@ private:
 	QString getAnnotationColor(const AnnotColor *color);
 	QString convertPath(POPPLER_CONST_083 GfxPath *path);
 	int getBlendMode(GfxState *state);
-	void applyMask(PageItem *ite);
-	void pushGroup(const QString& maskName = "", GBool forSoftMask = gFalse, GBool alpha = gFalse, bool inverted = false);
 	QString UnicodeParsedString(POPPLER_CONST GooString *s1);
 	QString UnicodeParsedString(const std::string& s1);
 	bool checkClip();
@@ -307,15 +337,9 @@ private:
 
 	void createImageFrame(QImage& image, GfxState *state, int numColorComponents);
 
-	bool pathIsClosed {false};
-	QString CurrColorFill;
-	int CurrFillShade {100};
-	QString CurrColorStroke;
-	int CurrStrokeShade {100};
-	Qt::PenCapStyle PLineEnd {Qt::FlatCap};
-	Qt::PenJoinStyle PLineJoin {Qt::MiterJoin};
+	bool pathIsClosed { false };
 	QVector<double> DashValues;
-	double DashOffset {0.0};
+	double DashOffset { 0.0 };
 	QString Coords;
 	// The currently visible area. If it is empty, everything is visible.
 	// QPainterPath has the drawback that it sometimes approximates Bezier curves
@@ -328,22 +352,9 @@ private:
 	// Collect the paths of character glyphs for clipping of a whole text group.
 	QPainterPath  m_clipTextPath;
 
-	struct groupEntry
-	{
-		QList<PageItem*> Items;
-		GBool forSoftMask;
-		GBool isolated;
-		GBool alpha;
-		QString maskName;
-		QPointF maskPos;
-		bool inverted;
-	};
-	QStack<groupEntry> m_groupStack;
 	QString m_currentMask;
 	QPointF m_currentMaskPosition;
-	ScribusDoc* m_doc;
-	Selection* tmpSel;
-	QList<PageItem*> *m_Elements;
+	Selection* tmpSel { nullptr };
 	QStringList *m_importedColors;
 	QTransform m_ctm;
 	struct F3Entry
@@ -359,7 +370,7 @@ private:
 	QStack<mContent> m_mcStack;
 	int inPattern {0};
 	int layerNum {1};
-	int currentLayer;
+	int currentLayer { 0 };
 	bool firstLayer {true};
 	int importerFlags;
 	int updateGUICounter {0};
@@ -368,10 +379,13 @@ private:
 	Catalog *catalog {nullptr};
 	SplashFontEngine *m_fontEngine {nullptr};
 	SplashFont *m_font {nullptr};
+#if POPPLER_ENCODED_VERSION >= POPPLER_VERSION_ENCODE(21, 4, 0)
+	std::unique_ptr<FormPageWidgets> m_formWidgets;
+#else
 	FormPageWidgets *m_formWidgets {nullptr};
+#endif
 	QHash<QString, QList<int> > m_radioMap;
 	QHash<int, PageItem*> m_radioButtons;
-	int m_actPage;
+	int m_actPage { 1 };
 };
-
 #endif
