@@ -14,6 +14,7 @@ for which a new license (GPL+exception) is in place.
 #include <QMimeData>
 #include <QPainterPath>
 #include <QRegExp>
+#include <QStack>
 #include <QTemporaryFile>
 
 #include "svgplugin.h"
@@ -218,24 +219,24 @@ QImage SVGImportPlugin::readThumbnail(const QString& fileName)
 }
 
 SVGPlug::SVGPlug(ScribusDoc* doc, int flags)
+	   : m_Doc(doc),
+	     importerFlags(flags)
 {
 	tmpSel = new Selection(this, false);
-	m_Doc = doc;
-	unsupported = false;
-	importFailed = false;
-	importCanceled = true;
-	firstLayer = true;
+
 	importedColors.clear();
 	importedGradients.clear();
 	importedPatterns.clear();
-	docDesc = "";
-	docTitle = "";
-	groupLevel = 0;
-	importerFlags = flags;
+
 	interactive = (flags & LoadSavePlugin::lfInteractive);
 //	m_gc.setAutoDelete(true);
 }
 
+SVGPlug::~SVGPlug()
+{
+	delete tmpSel;
+}
+
 QImage SVGPlug::readThumbnail(const QString& fName)
 {
 	if (!loadData(fName))
@@ -282,9 +283,12 @@ QImage SVGPlug::readThumbnail(const QString& fName)
 			m_gc.top()->matrix = matrix;
 		}
 	}
+
+	m_nodeMap = buildNodeMap(docElem);
 	QList<PageItem*> Elements = parseGroup(docElem);
+
 	tmpSel->clear();
-	QImage tmpImage = QImage();
+	QImage tmpImage;
 	if (Elements.count() > 0)
 	{
 		m_Doc->groupObjectsList(Elements);
@@ -337,7 +341,7 @@ bool SVGPlug::loadData(const QString& fName)
 		if ((QChar(bb[0]) == QChar(0x1F)) && (QChar(bb[1]) == QChar(0x8B)))
 			isCompressed = true;
 	}
-	if ((fName.right(2) == "gz") || (isCompressed))
+	if ((fName.right(2) == "gz") || isCompressed)
 	{
 		QFile file(fName);
 		QtIOCompressor compressor(&file);
@@ -358,10 +362,39 @@ bool SVGPlug::loadData(const QString& fName)
 	return success;
 }
 
+QMap<QString, QDomElement> SVGPlug::buildNodeMap(const QDomElement &e)
+{
+	const QString idAttribute("id");
+	QMap<QString, QDomElement> nodeMap;
+
+	QStack<QDomElement> elementStack;
+	elementStack.push(e);
+
+	while (!elementStack.isEmpty())
+	{
+		QDomElement domElem = elementStack.pop();
+
+		for (QDomNode n = domElem.firstChild(); !n.isNull(); n = n.nextSibling())
+		{
+			QDomElement e = n.toElement();
+			if (e.isNull())
+				continue;
+
+			QString id = e.attribute(idAttribute);
+			if (!id.isEmpty())
+				nodeMap.insert(id, e);
+
+			if (e.hasChildNodes())
+				elementStack.push(e);
+		}
+	}
+
+	return nodeMap;
+}
+
 void SVGPlug::convert(const TransactionSettings& trSettings, int flags)
 {
 	bool ret = false;
-	SvgStyle *gc = new SvgStyle;
 	QDomElement docElem = inpdoc.documentElement();
 	QSizeF wh = parseWidthHeight(docElem);
 	double width = wh.width();
@@ -384,7 +417,7 @@ void SVGPlug::convert(const TransactionSettings& trSettings, int flags)
 			ret = true;
 		}
 	}
-	if ((ret) || (!interactive))
+	if (ret || !interactive)
 	{
 		if (width > height)
 			m_Doc->setPageOrientation(1);
@@ -400,10 +433,13 @@ void SVGPlug::convert(const TransactionSettings& trSettings, int flags)
 		m_Doc->view()->updatesOn(false);
 	m_Doc->scMW()->setScriptRunning(true);
 	qApp->setOverrideCursor(QCursor(Qt::WaitCursor));
+
+	SvgStyle *gc = new SvgStyle;
 	gc->FontFamily = m_Doc->itemToolPrefs().textFont;
 	if (!m_Doc->PageColors.contains("Black"))
 		m_Doc->PageColors.insert("Black", ScColor(0, 0, 0, 255));
 	m_gc.push(gc);
+
 	viewTransformX = 0;
 	viewTransformY = 0;
 	viewScaleX = 1;
@@ -428,7 +464,10 @@ void SVGPlug::convert(const TransactionSettings& trSettings, int flags)
 			m_gc.top()->matrix = matrix;
 		}
 	}
+
+	m_nodeMap = buildNodeMap(docElem);
 	Elements += parseDoc(docElem);
+
 	if (flags & LoadSavePlugin::lfCreateDoc)
 	{
 		m_Doc->documentInfo().setTitle(docTitle);
@@ -923,13 +962,13 @@ PageItem *SVGPlug::finishNode(const QDomNode &e, PageItem* item)
 	return item;
 }
 
-bool SVGPlug::isIgnorableNode(const QDomElement &e)
+bool SVGPlug::isIgnorableNode(const QDomElement &e) const
 {
 	QString nodeName(e.tagName());
 	return isIgnorableNodeName(nodeName);
 }
 
-bool SVGPlug::isIgnorableNodeName(const QString &n)
+bool SVGPlug::isIgnorableNodeName(const QString &n) const
 {
 	return n.startsWith("sodipodi") || n.startsWith("inkscape") || n == "metadata";
 }
@@ -1058,12 +1097,7 @@ void SVGPlug::parseDefs(const QDomElement &e)
 			continue;
 		QString STag2 = parseTagName(b);
 		if (STag2 == "g")
-		{
-			QString id = b.attribute("id", "");
-			if (!id.isEmpty())
-				m_nodeMap.insert(id, b);
 			parseDefs(b);
-		}
 		else if (STag2 == "linearGradient" || STag2 == "radialGradient")
 			parseGradient(b);
 		else if (STag2 == "clipPath")
@@ -1074,12 +1108,6 @@ void SVGPlug::parseDefs(const QDomElement &e)
 			parseMarker(b);
 		else if (STag2 == "filter")
 			parseFilter(b);
-		else if (b.hasAttribute("id"))
-		{
-			QString id = b.attribute("id");
-			if (!id.isEmpty())
-				m_nodeMap.insert(id, b);
-		}
 	}
 }
 
@@ -1382,8 +1410,7 @@ QList<PageItem*> SVGPlug::parseDoc(const QDomElement &e)
 QList<PageItem*> SVGPlug::parseElement(const QDomElement &e)
 {
 	QList<PageItem*> GElements;
-	if (e.hasAttribute("id"))
-		m_nodeMap.insert(e.attribute("id"), e);
+
 	QString STag = parseTagName(e);
 	if (STag.startsWith("svg:"))
 		STag = STag.mid(4, - 1);
@@ -1530,7 +1557,7 @@ QList<PageItem*> SVGPlug::parseCircle(const QDomElement &e)
 	SvgStyle *gc = m_gc.top();
 	int z = m_Doc->itemAdd(PageItem::Polygon, PageItem::Ellipse, baseX, baseY, r * 2.0, r * 2.0, gc->LWidth, gc->FillCol, gc->StrokeCol);
 	PageItem* ite = m_Doc->Items->at(z);
-	QTransform mm = QTransform();
+	QTransform mm;
 	mm.translate(x, y);
 	ite->PoLine.map(mm);
 	FPoint wh = getMaxClipF(&ite->PoLine);
@@ -1554,7 +1581,7 @@ QList<PageItem*> SVGPlug::parseEllipse(const QDomElement &e)
 	SvgStyle *gc = m_gc.top();
 	int z = m_Doc->itemAdd(PageItem::Polygon, PageItem::Ellipse, baseX, baseY, rx * 2.0, ry * 2.0, gc->LWidth, gc->FillCol, gc->StrokeCol);
 	PageItem* ite = m_Doc->Items->at(z);
-	QTransform mm = QTransform();
+	QTransform mm;
 	mm.translate(x, y);
 	ite->PoLine.map(mm);
 	FPoint wh = getMaxClipF(&ite->PoLine);
@@ -1779,7 +1806,7 @@ QList<PageItem*> SVGPlug::parseRect(const QDomElement &e)
 		ite->SetFrameRound();
 		m_Doc->setRedrawBounding(ite);
 	}
-	QTransform mm = QTransform();
+	QTransform mm;
 	mm.translate(x, y);
 	ite->PoLine.map(mm);
 	FPoint wh = getMaxClipF(&ite->PoLine);
@@ -2094,7 +2121,7 @@ bool SVGPlug::getTextChunkWidth(const QDomElement &e, double& width)
 {
 	bool doBreak = false;
 	setupNode(e);
-//	QDomNode c = e.firstChild();
+
 	for (QDomNode n = e.firstChild(); !n.isNull(); n = n.nextSibling())
 	{
 		if (n.isElement() && (parseTagName(n.toElement()) == "tspan"))
@@ -2900,8 +2927,7 @@ void SVGPlug::parseColorStops(GradientHelper *gradient, const QDomElement &e)
 
 void SVGPlug::parseFilter(const QDomElement &b)
 {
-	QString id = b.attribute("id", "");
-	QString origName = id;
+	QString id = b.attribute("id", QString());
 	if (id.isEmpty())
 		return;
 
@@ -2912,7 +2938,6 @@ void SVGPlug::parseFilter(const QDomElement &b)
 	if (child.isNull() || (child.tagName() != "feBlend"))
 	{
 		filters.insert(id, fspec);
-		m_nodeMap.insert(origName, b);
 		return;
 	}
 
@@ -2929,7 +2954,6 @@ void SVGPlug::parseFilter(const QDomElement &b)
 		fspec.blendMode = 4;
 
 	filters.insert(id, fspec);
-	m_nodeMap.insert(origName, b);
 }
 
 void SVGPlug::parseMarker(const QDomElement &b)
@@ -2955,8 +2979,7 @@ void SVGPlug::parseMarker(const QDomElement &b)
 	GElements = parseGroup(b);
 	if (GElements.count() > 0)
 	{
-		ScPattern pat = ScPattern();
-		pat.setDoc(m_Doc);
+		ScPattern pat(m_Doc);
 		PageItem* currItem = GElements.at(0);
 		m_Doc->DoDrawing = true;
 		double minx =  std::numeric_limits<double>::max();
@@ -2983,7 +3006,6 @@ void SVGPlug::parseMarker(const QDomElement &b)
 		importedPattTrans.insert(origName, id);
 		markers.insert(id, mark);
 	}
-	m_nodeMap.insert(origName, b);
 	delete (m_gc.pop());
 }
 
@@ -3003,7 +3025,7 @@ void SVGPlug::parsePattern(const QDomElement &b)
 		}
 		gradhelper.reference = href;
 	}
-	QString id = b.attribute("id", "");
+	QString id = b.attribute("id", QString());
 	QString origName = id;
 	if (!id.isEmpty())
 	{
@@ -3015,8 +3037,7 @@ void SVGPlug::parsePattern(const QDomElement &b)
 		GElements = parseGroup(b);
 		if (GElements.count() > 0)
 		{
-			ScPattern pat = ScPattern();
-			pat.setDoc(m_Doc);
+			ScPattern pat(m_Doc);
 			PageItem* currItem = GElements.at(0);
 			m_Doc->DoDrawing = true;
 			pat.pattern = currItem->DrawObj_toImage(qMin(qMax(wpat, hpat), 500.0));
@@ -3039,7 +3060,6 @@ void SVGPlug::parsePattern(const QDomElement &b)
 			importedPatterns.append(id);
 			importedPattTrans.insert(origName, id);
 		}
-		m_nodeMap.insert(origName, b);
 		QString transf = b.attribute("patternTransform");
 		if (!transf.isEmpty())
 		{
@@ -3205,8 +3225,3 @@ QString SVGPlug::parseTagName(const QDomElement& element)
 		return tagName.mid(4, -1);
 	return tagName;
 }
-
-SVGPlug::~SVGPlug()
-{
-	delete tmpSel;
-}
