@@ -163,7 +163,7 @@ QImage VivaPlug::readThumbnail(const QString& fName)
 	return tmp;
 }
 
-bool VivaPlug::readColors(const QString& fNameIn, ColorList & colors)
+bool VivaPlug::readColors(const QString& fileName, ColorList & colors)
 {
 	bool success = false;
 	m_Doc = new ScribusDoc();
@@ -173,7 +173,7 @@ bool VivaPlug::readColors(const QString& fNameIn, ColorList & colors)
 	m_Doc->setGUI(false, ScCore->primaryMainWindow(), nullptr);
 	importedColors.clear();
 	QByteArray f;
-	loadRawText(fNameIn, f);
+	loadRawText(fileName, f);
 	if (designMapDom.setContent(f))
 	{
 		QDomElement docElem = designMapDom.documentElement();
@@ -488,7 +488,7 @@ void VivaPlug::parseSettingsXML(const QDomElement& grNode)
 		}
 		m_Doc->setPage(docWidth, docHeight, topMargin, leftMargin, rightMargin, bottomMargin, pgCols, pgGap, false, facingPages);
 		m_Doc->setPageSize(papersize);
-		m_Doc->currentPage()->m_pageSize = papersize;
+		m_Doc->currentPage()->setSize(papersize);
 		m_Doc->currentPage()->setInitialHeight(docHeight);
 		m_Doc->currentPage()->setInitialWidth(docWidth);
 		m_Doc->currentPage()->setHeight(docHeight);
@@ -737,7 +737,7 @@ void VivaPlug::parseMasterSpreadXML(const QDomElement& spNode)
 					mspreadTypes.insert(pageNam, 0);
 				ScPage *addedPage = m_Doc->addMasterPage(mpagecount, pageNam);
 				m_Doc->setCurrentPage(addedPage);
-				addedPage->MPageNam = "";
+				addedPage->clearMasterPageName();
 				m_Doc->view()->addPage(mpagecount, true);
 				baseX = addedPage->xOffset();
 				baseY = addedPage->yOffset();
@@ -773,7 +773,7 @@ void VivaPlug::parseSpreadXML(const QDomElement& spNode)
 			if ((importerFlags & LoadSavePlugin::lfCreateDoc) && (!firstPage))
 			{
 				m_Doc->addPage(pagecount);
-				m_Doc->currentPage()->m_pageSize = papersize;
+				m_Doc->currentPage()->setSize(papersize);
 				m_Doc->currentPage()->setInitialHeight(docHeight);
 				m_Doc->currentPage()->setInitialWidth(docWidth);
 				m_Doc->currentPage()->setHeight(docHeight);
@@ -782,7 +782,7 @@ void VivaPlug::parseSpreadXML(const QDomElement& spNode)
 				m_Doc->currentPage()->initialMargins.setBottom(bottomMargin);
 				m_Doc->currentPage()->initialMargins.setLeft(leftMargin);
 				m_Doc->currentPage()->initialMargins.setRight(rightMargin);
-				m_Doc->currentPage()->MPageNam = CommonStrings::trMasterPageNormal;
+				m_Doc->currentPage()->setMasterPageNameNormal();
 				m_Doc->view()->addPage(pagecount, true);
 				pagecount++;
 			}
@@ -1568,7 +1568,7 @@ PageItem* VivaPlug::parseObjectDetailsXML(const QDomElement& obNode, int baseTyp
 					patch.TR = tR;
 					item->meshGradientPatches.append(patch);
 				}
-				item->GrType = 12;
+				item->GrType = Gradient_PatchMesh;
 			}
 			else
 			{
@@ -2122,9 +2122,9 @@ void VivaPlug::applyParagraphAttrs(ParagraphStyle &newStyle, AttributeSet &pAttr
 	if (pAttrs.justification.valid)
 	{
 		if (pAttrs.justification.value == "left")
-			newStyle.setAlignment(ParagraphStyle::Leftaligned);
+			newStyle.setAlignment(ParagraphStyle::LeftAligned);
 		else if (pAttrs.justification.value == "right")
-			newStyle.setAlignment(ParagraphStyle::Rightaligned);
+			newStyle.setAlignment(ParagraphStyle::RightAligned);
 		else if (pAttrs.justification.value == "center")
 			newStyle.setAlignment(ParagraphStyle::Centered);
 		else if (pAttrs.justification.value == "justified")
@@ -2367,13 +2367,13 @@ QPointF VivaPlug::intersectBoundingRect(PageItem *item, QLineF gradientVector)
 {
 	QPointF interPoint;
 	QPointF gradEnd;
-	if (gradientVector.intersect(QLineF(0, 0, item->width(), 0), &interPoint) == QLineF::BoundedIntersection)
+	if (gradientVector.intersects(QLineF(0, 0, item->width(), 0), &interPoint) == QLineF::BoundedIntersection)
 		gradEnd = interPoint;
-	else if (gradientVector.intersect(QLineF(item->width(), 0, item->width(), item->height()), &interPoint) == QLineF::BoundedIntersection)
+	else if (gradientVector.intersects(QLineF(item->width(), 0, item->width(), item->height()), &interPoint) == QLineF::BoundedIntersection)
 		gradEnd = interPoint;
-	else if (gradientVector.intersect(QLineF(item->width(), item->height(), 0, item->height()), &interPoint) == QLineF::BoundedIntersection)
+	else if (gradientVector.intersects(QLineF(item->width(), item->height(), 0, item->height()), &interPoint) == QLineF::BoundedIntersection)
 		gradEnd = interPoint;
-	else if (gradientVector.intersect(QLineF(0, item->height(), 0, 0), &interPoint) == QLineF::BoundedIntersection)
+	else if (gradientVector.intersects(QLineF(0, item->height(), 0, 0), &interPoint) == QLineF::BoundedIntersection)
 		gradEnd = interPoint;
 	return gradEnd;
 }
