@@ -4,6 +4,10 @@ to the COPYING file provided with the program. Following this notice may exist
 a copyright and/or license notice that predates the release of Scribus 1.3.2
 for which a new license (GPL+exception) is in place.
 */
+
+#ifndef MULTICOMBOBOXMODEL_H
+#define MULTICOMBOBOXMODEL_H
+
 #include <QComboBox>
 #include <QListView>
 #include <QStandardItemModel>
@@ -55,3 +59,5 @@ class multiCombobox : public QComboBox
 	signals:
 		void checkstateChanged ( int );
 };
+
+#endif
