@@ -197,6 +197,15 @@ points. If \"name\" is not given the currently selected item is used.\n\
 /*! Get line space */
 PyObject *scribus_getlinespacing(PyObject * /*self*/, PyObject* args);
 
+/*! docstring */
+PyDoc_STRVAR(scribus_getlinespacingmode__doc__,
+QT_TR_NOOP("getLineSpacingMode([\"name\"]) -> float\n\
+\n\
+Returns the line spacing mode of the text frame \"name\". If \"name\" is not given the currently selected item is used.\n\
+"));
+/*! Get line spacing mode*/
+PyObject *scribus_getlinespacingmode(PyObject * /*self*/, PyObject* args);
+
 /*! docstring */
 PyDoc_STRVAR(scribus_gettextdistances__doc__,
 QT_TR_NOOP("getTextDistances([\"name\"]) -> tuple\n\
@@ -651,7 +660,7 @@ PyObject *scribus_dehyphenatetext(PyObject *, PyObject* args);
 PyDoc_STRVAR(scribus_setpdfbookmark__doc__,
 QT_TR_NOOP("setPDFBookmark(\"toggle\", [\"name\"])\n\
 \n\
-Sets whether (toggle = 1) the text frame \"name\" is a bookmark nor not.\n\
+Sets whether (toggle = 1) the text frame \"name\" is a bookmark or not.\n\
 If \"name\" is not given the currently selected item is used.\n\
 \n\
 May raise WrongFrameTypeError if the target frame is not a text frame\n\
