@@ -154,14 +154,14 @@ static int Printer_init(Printer *self, PyObject * /*args*/, PyObject * /*kwds*/)
 	PyObject *tmp2 = PyUnicode_FromString("File");
 	PyList_Append(self->allPrinters, tmp2);
 	Py_DECREF(tmp2);
-// as defaut set to print into file
+// as default set to print into file
 	PyObject *printer = nullptr;
 	printer = PyUnicode_FromString("File");
 	if (printer) {
 		Py_DECREF(self->printer);
 		self->printer = printer;
 	}
-// set defaul name of file to print into
+// set default name of file to print into
 	QString tf(ScCore->primaryMainWindow()->doc->pdfOptions().fileName);
 	if (tf.isEmpty()) {
 		QFileInfo fi = QFileInfo(ScCore->primaryMainWindow()->doc->documentFileName());
@@ -588,3 +588,13 @@ PyTypeObject Printer_Type = {
 	//    struct _typeobject *tp_next;
 #endif
 };
+
+/*! HACK: this removes "warning: 'blah' defined but not used" compiler warnings
+with header files structure untouched (docstrings are kept near declarations)
+PV */
+void objprinterwarnings()
+{
+	QStringList s;
+	s << printer__doc__
+	  << printer_printnow__doc__;
+}
