@@ -58,6 +58,7 @@ for which a new license (GPL+exception) is in place.
 #include "ui/scmwmenumanager.h"
 #include "units.h"
 
+#include "api/api_application.h"
 
 #include <QApplication>
 #include <QMessageBox>
@@ -146,7 +147,6 @@ const ScActionPlugin::AboutData* ScriptPlugin::getAboutData() const
 			"Craig Ringer <craig@scribus.info>");
 	about->shortDescription = tr("Embedded Python scripting support for Python 3.x.");
 	// about->description = tr("Write me!")
-	// about->version
 	// about->releaseDate
 	// about->copyright
 	// about->license
@@ -252,7 +252,7 @@ char* tr(const char* docstringConstant)
 	// Alas, there's a lot of wasteful string copying going on
 	// here.
 	QString translated = QObject::tr(docstringConstant, "scripter docstring");
-	// pv - hack for ugly formating in console removing
+	// pv - hack for ugly formatting in console removing
 	translated.replace("\n\n", "<P>");
 	translated.replace('\n', " ");
 	translated.replace("<P>", "\n\n");
@@ -369,6 +369,7 @@ PyMethodDef scribus_methods[] = {
 	{const_cast<char*>("getImageFile"), scribus_getimagefile, METH_VARARGS, tr(scribus_getimagefile__doc__)},
 	{const_cast<char*>("getImageOffset"), scribus_getimageoffset, METH_VARARGS, tr(scribus_getimageoffset__doc__)},
 	{const_cast<char*>("getImageScale"), scribus_getimagescale, METH_VARARGS, tr(scribus_getimagescale__doc__)},
+	{const_cast<char*>("getInfo"), (PyCFunction)scribus_getinfo, METH_VARARGS, tr(scribus_getinfo__doc__)},
 	{const_cast<char*>("getLastLinkedFrame"), scribus_getlastlinkedframe, METH_VARARGS, tr(scribus_getlastlinkedframe__doc__)},
 	{const_cast<char*>("getLayerBlendmode"), scribus_getlayerblendmode, METH_VARARGS, tr(scribus_getlayerblendmode__doc__)},
 	{const_cast<char*>("getLayerTransparency"), scribus_getlayertransparency, METH_VARARGS, tr(scribus_getlayertransparency__doc__)},
@@ -379,6 +380,7 @@ PyMethodDef scribus_methods[] = {
 	{const_cast<char*>("getLineJoin"), scribus_getlinejoin, METH_VARARGS, tr(scribus_getlinejoin__doc__)},
 	{const_cast<char*>("getLineShade"), scribus_getlineshade, METH_VARARGS, tr(scribus_getlineshade__doc__)},
 	{const_cast<char*>("getLineSpacing"), scribus_getlinespacing, METH_VARARGS, tr(scribus_getlinespacing__doc__)},
+	{const_cast<char*>("getLineSpacingMode"), scribus_getlinespacingmode, METH_VARARGS, tr(scribus_getlinespacingmode__doc__)},
 	{const_cast<char*>("getLineStyle"), scribus_getlinestyle, METH_VARARGS, tr(scribus_getlinestyle__doc__)},
 	{const_cast<char*>("getLineStyles"), (PyCFunction)scribus_getlinestyles, METH_VARARGS, tr(scribus_getlinestyles__doc__)},
 	{const_cast<char*>("getLineTransparency"), scribus_getlinetransparency, METH_VARARGS, tr(scribus_getlinetransparency__doc__)},
@@ -935,28 +937,20 @@ PyObject* PyInit_scribus(void)
 	}
 
 	// Export the Scribus version into the module namespace so scripts know what they're running in
-	PyDict_SetItemString(d, const_cast<char*>("scribus_version"), PyUnicode_FromString(const_cast<char*>(VERSION)));
+	PyDict_SetItemString(d, const_cast<char*>("scribus_version"), PyUnicode_FromString(ScribusAPI::getVersion().toLatin1().constData()));
 	// Now build a version tuple like that provided by Python in sys.version_info
 	// The tuple is of the form (major, minor, patchlevel, extraversion, reserved)
-	QRegExp version_re("(\\d+)\\.(\\d+)\\.(\\d+)(.*)");
-	int pos = version_re.indexIn(QString(VERSION));
-	// We ignore errors, causing the scribus_version_info attribute to simply not be created.
-	// This will make acceses raise AttrbuteError.
-	if (pos > -1)
-	{
-		int majorVersion = version_re.cap(1).toInt();
-		int minorVersion = version_re.cap(2).toInt();
-		int patchVersion = version_re.cap(3).toInt();
-		QString extraVersion = version_re.cap(4);
-		PyObject* versionTuple = Py_BuildValue(const_cast<char*>("(iiisi)"),\
-				majorVersion, minorVersion, patchVersion, (const char*)extraVersion.toUtf8(), 0);
-		if (versionTuple != nullptr)
-			PyDict_SetItemString(d, const_cast<char*>("scribus_version_info"), versionTuple);
-		else
-			qDebug("Failed to build version tuple for version string '%s' in scripter", VERSION);
-	}
+	int majorVersion = ScribusAPI::getVersionMajor();
+	int minorVersion = ScribusAPI::getVersionMinor();
+	int patchVersion = ScribusAPI::getVersionPatch();
+	QString extraVersion = ScribusAPI::getVersionSuffix();
+
+	PyObject* versionTuple = Py_BuildValue(const_cast<char*>("(iiisi)"), majorVersion, minorVersion, patchVersion, (const char*)extraVersion.toUtf8(), 0);
+	if (versionTuple != nullptr)
+		PyDict_SetItemString(d, const_cast<char*>("scribus_version_info"), versionTuple);
 	else
-		qDebug("Couldn't parse version string '%s' in scripter", VERSION);
+		qDebug("Failed to build version tuple for version string '%s' in scripter", VERSION);
+
 
 	// Function aliases for compatibility
 	// We need to import the __builtins__, warnings and exceptions modules to be able to run
