@@ -16,15 +16,16 @@ class Prefs_ShortWords : public Prefs_Pane, Ui::Prefs_ShortWords
 	Q_OBJECT
 
 	public:
-		Prefs_ShortWords(QWidget* parent=0);
+		Prefs_ShortWords(QWidget* parent=nullptr);
 		~Prefs_ShortWords();
-		virtual void restoreDefaults(struct ApplicationPrefs *prefsData);
-		virtual void saveGuiToPrefs(struct ApplicationPrefs *prefsData) const;
+
+		void restoreDefaults(struct ApplicationPrefs *prefsData) override;
+		void saveGuiToPrefs(struct ApplicationPrefs *prefsData) const override;
 
 	public slots:
 		void languageChange();
 		//! \brief Apply changes to prefs. Auto connected.
-		void apply();
+		void apply() override;
 
 	protected slots:
 		/*! \brief Save the content into user file. */
