@@ -58,10 +58,10 @@ LensItem::LensItem(QRectF geom, LensDialog *parent) : QGraphicsRectItem(geom)
 
 }
 
-void LensItem::paint(QPainter *painter, const QStyleOptionGraphicsItem *option, QWidget *widget)
+void LensItem::paint(QPainter *painter, const QStyleOptionGraphicsItem *item, QWidget *widget)
 {
 	Q_UNUSED(widget);
-	painter->setPen(QPen(Qt::black, 1.0 / option->levelOfDetail));
+	painter->setPen(QPen(Qt::black, 1.0 / item->levelOfDetail));
 	QRadialGradient radialGrad(QPointF(0.5, 0.5), 1.0);
 	radialGrad.setColorAt(0.0, QColor(255, 0, 0, 127));
 	radialGrad.setColorAt(0.1, QColor(255, 0, 0, 127));
@@ -69,13 +69,13 @@ void LensItem::paint(QPainter *painter, const QStyleOptionGraphicsItem *option,
 	radialGrad.setCoordinateMode(QGradient::ObjectBoundingMode);
 	painter->setBrush(radialGrad);
 	painter->drawEllipse(rect().toRect());
-	if (option->state & QStyle::State_Selected)
+	if (item->state & QStyle::State_Selected)
 	{
-		scaling = option->levelOfDetail;
-		double siz = 6.0 / option->levelOfDetail;
+		scaling = item->levelOfDetail;
+		double siz = 6.0 / item->levelOfDetail;
 		QRectF br = boundingRect();
 		painter->setBrush(Qt::NoBrush);
-		painter->setPen(QPen(Qt::red, 1.0 / option->levelOfDetail, Qt::DotLine));
+		painter->setPen(QPen(Qt::red, 1.0 / item->levelOfDetail, Qt::DotLine));
 		painter->drawRect(br);
 		painter->setBrush(Qt::red);
 		painter->setPen(Qt::NoPen);
@@ -316,7 +316,7 @@ void LensDialog::addItemsToScene(Selection* itemSelection, ScribusDoc *doc, QGra
 		{
 			if (currItem->GrType != 0)
 			{
-				if (currItem->GrType != 8)
+				if (currItem->GrType != Gradient_Pattern)
 				{
 					QGradient pat;
 					double x1 = currItem->GrStartX;
@@ -353,7 +353,7 @@ void LensDialog::addItemsToScene(Selection* itemSelection, ScribusDoc *doc, QGra
 					}
 					pItem->setBrush(pat);
 				}
-				else if ((currItem->GrType == 8) && (!currItem->pattern().isEmpty()) && (doc->docPatterns.contains(currItem->pattern())))
+				else if ((currItem->GrType == Gradient_Pattern) && (!currItem->pattern().isEmpty()) && (doc->docPatterns.contains(currItem->pattern())))
 				{
 					double patternScaleX, patternScaleY, patternOffsetX, patternOffsetY, patternRotation, patternSkewX, patternSkewY;
 					currItem->patternTransform(patternScaleX, patternScaleY, patternOffsetX, patternOffsetY, patternRotation, patternSkewX, patternSkewY);
@@ -413,7 +413,7 @@ void LensDialog::addItemsToScene(Selection* itemSelection, ScribusDoc *doc, QGra
 				double y1 = currItem->GrStrokeStartY;
 				double x2 = currItem->GrStrokeEndX;
 				double y2 = currItem->GrStrokeEndY;
-				if (currItem->GrTypeStroke == 6)
+				if (currItem->GrTypeStroke == Gradient_Linear)
 					pat = QLinearGradient(x1, y1,  x2, y2);
 				else
 					pat = QRadialGradient(x1, y1, sqrt(pow(x2 - x1, 2) + pow(y2 - y1,2)), x1, y1);
