@@ -8,7 +8,9 @@ for which a new license (GPL+exception) is in place.
 #include <QDir>
 #include <QFileInfo>
 #include <QImage>
+#include <QScopedPointer>
 #include <QTemporaryFile>
+#include <QTransform>
 
 #include "commonstrings.h"
 #include "cmsettings.h"
@@ -33,7 +35,7 @@ PrintPreviewCreator_PS::PrintPreviewCreator_PS(ScribusDoc* doc) :
 	m_printOptions.prnLanguage = PrintLanguage::PostScript3;
 
 	// Generate a template name for temporary files
-	QTemporaryFile *tempFile = new QTemporaryFile(ScPaths::tempFileDir() + "/scpspreview_XXXXXX.png");
+	QScopedPointer<QTemporaryFile> tempFile(new QTemporaryFile(ScPaths::tempFileDir() + "/scpspreview_XXXXXX.png"));
 	if (tempFile->open())
 	{
 		QString tempFileBase = tempFile->fileName();
@@ -43,7 +45,6 @@ PrintPreviewCreator_PS::PrintPreviewCreator_PS(ScribusDoc* doc) :
 	}
 	if (m_tempBaseName.isEmpty())
 		m_tempBaseName = "scpspreview";
-	delete tempFile;
 }
 
 PrintPreviewCreator_PS::~PrintPreviewCreator_PS()
@@ -67,8 +68,9 @@ void PrintPreviewCreator_PS::cleanupTemporaryFiles()
 QPixmap PrintPreviewCreator_PS::createPreview(int pageIndex)
 {
 	int ret = -1;
-	double w = m_doc->Pages->at(pageIndex)->width() * m_previewResolution / 72.0;
-	double h = m_doc->Pages->at(pageIndex)->height() * m_previewResolution / 72.0;
+	int gsRes = qRound(m_previewResolution * m_devicePixelRatio);
+	int w = qRound(m_doc->Pages->at(pageIndex)->width() * gsRes / 72.0);
+	int h = qRound(m_doc->Pages->at(pageIndex)->height() * gsRes / 72.0);
 
 	QPixmap pixmap;
 	if (m_printOptionsChanged || (m_pageIndex != pageIndex))
@@ -84,9 +86,9 @@ QPixmap PrintPreviewCreator_PS::createPreview(int pageIndex)
 	if (m_printOptionsChanged || m_renderingOptionsChanged || (m_pageIndex != pageIndex))
 	{
 		if (m_sepPreviewEnabled && m_haveTiffSep)
-			ret = renderPreviewSep(pageIndex, m_previewResolution);
+			ret = renderPreviewSep(pageIndex, gsRes);
 		else
-			ret = renderPreview(pageIndex, m_previewResolution);
+			ret = renderPreview(pageIndex, gsRes);
 		if (ret > 0)
 		{
 			imageLoadError(pixmap, pageIndex);
@@ -102,8 +104,8 @@ QPixmap PrintPreviewCreator_PS::createPreview(int pageIndex)
 
 		ScImage im;
 		bool mode;
-		int w2 = qRound(w);
-		int h2 = qRound(h);
+		int w2 = w;
+		int h2 = h;
 		if (m_doc->Pages->at(pageIndex)->orientation() == 1)
 			std::swap(w2, h2);
 		image = QImage(w2, h2, QImage::Format_ARGB32);
@@ -303,10 +305,13 @@ QPixmap PrintPreviewCreator_PS::createPreview(int pageIndex)
 
 	const ScPage* page = m_doc->Pages->at(pageIndex);
 	if ((page->orientation() == 1) && (image.width() < image.height()))
-		image = image.transformed( QMatrix(0, 1, -1, 0, 0, 0) );
+		image = image.transformed( QTransform(0, 1, -1, 0, 0, 0) );
+
+	image.setDevicePixelRatio(m_devicePixelRatio);
 	if (m_showTransparency)
 	{
 		pixmap = QPixmap(image.width(), image.height());
+		pixmap.setDevicePixelRatio(m_devicePixelRatio);
 		QPainter p;
 		QBrush b(QColor(205,205,205), IconManager::instance().loadPixmap("testfill.png"));
 		p.begin(&pixmap);
@@ -316,6 +321,7 @@ QPixmap PrintPreviewCreator_PS::createPreview(int pageIndex)
 	}
 	else
 		pixmap = QPixmap::fromImage(image);
+	pixmap.setDevicePixelRatio(m_devicePixelRatio);
 
 	m_pageIndex = pageIndex;
 	m_printOptionsChanged = false;
@@ -384,8 +390,8 @@ int PrintPreviewCreator_PS::renderPreview(int pageIndex, int res)
 
 	QStringList args;
 	QString tmp, tmp2, tmp3;
-	double w = m_doc->Pages->at(pageIndex)->width() * res / 72.0;
-	double h = m_doc->Pages->at(pageIndex)->height() * res / 72.0;
+	int w = qRound(m_doc->Pages->at(pageIndex)->width() * res / 72.0);
+	int h = qRound(m_doc->Pages->at(pageIndex)->height() * res / 72.0);
 	if (m_doc->Pages->at(pageIndex)->orientation() == 1)
 		std::swap(w, h);
 
@@ -393,7 +399,7 @@ int PrintPreviewCreator_PS::renderPreview(int pageIndex, int res)
 	args.append( "-dNOPAUSE" );
 	args.append( "-dPARANOIDSAFER" );
 	args.append( QString("-r%1").arg(tmp.setNum(res)) );
-	args.append( QString("-g%1x%2").arg(tmp2.setNum(qRound(w)), tmp3.setNum(qRound(h))) );
+	args.append( QString("-g%1x%2").arg(tmp2.setNum(w), tmp3.setNum(h)) );
 	if (m_sepPreviewEnabled)
 	{
 		if (!m_haveTiffSep)
@@ -464,8 +470,8 @@ int PrintPreviewCreator_PS::renderPreviewSep(int pageIndex, int res)
 	QStringList args, args1, args2, args3;
 
 	QString tmp, tmp2, tmp3;
-	double w = m_doc->Pages->at(pageIndex)->width() * res / 72.0;
-	double h = m_doc->Pages->at(pageIndex)->height() * res / 72.0;
+	int w = qRound(m_doc->Pages->at(pageIndex)->width() * res / 72.0);
+	int h = qRound(m_doc->Pages->at(pageIndex)->height() * res / 72.0);
 	if (m_doc->Pages->at(pageIndex)->orientation() == 1)
 		std::swap(w, h);
 
@@ -473,7 +479,7 @@ int PrintPreviewCreator_PS::renderPreviewSep(int pageIndex, int res)
 	args1.append( "-dNOPAUSE" );
 	args1.append( "-dPARANOIDSAFER" );
 	args1.append( QString("-r%1").arg(tmp.setNum(res)) );
-	args1.append( QString("-g%1x%2").arg(tmp2.setNum(qRound(w)), tmp3.setNum(qRound(h))) );
+	args1.append( QString("-g%1x%2").arg(tmp2.setNum(w), tmp3.setNum(h)) );
 	if (m_useAntialiasing)
 	{
 		args1.append("-dTextAlphaBits=4");
