@@ -39,11 +39,11 @@ class SCRIBUS_API SampleItem : QObject
 		/*! \brief Use lorem ipsum generator as text source.
 		\param para count of the LI paragraphs */
 		void setLoremIpsum(int para);
-		/*! \brief Set backgroud color of the pixmap.
+		/*! \brief Set background color of the pixmap.
 		\param c a QColor */
 		void setBgColor(const QColor& c);
 		void setBgShade(int c);
-		/*! \brief Set color management for backgroud color of the pixmap.
+		/*! \brief Set color management for background color of the pixmap.
 		\param enable if color management should be enabled */
 		void setBgColorMgmt(bool enable);
 		/*! \brief Set Text color of the pixmap.
@@ -55,12 +55,12 @@ class SCRIBUS_API SampleItem : QObject
 		\param aStyle Paragraph style to set.*/
 		void setStyle(const ParagraphStyle& aStyle);
 		/*! \brief Following methods set only one style characteristic */
-		void setLineSpaMode(int lineSpaMode);
-		void setLineSpa(double lineSpa);
+		void setLineSpacingMode(int lineSpaMode);
+		void setLineSpacing(double lineSpa);
 		void setTextAlignment(int textAlignment);
-		void setIndent(double indent);
+		void setLeftMargin(double indent);
 		void setRightMargin(double indent);
-		void setFirst(double first);
+		void setFirstIndent(double first);
 		void setGapBefore(double gapBefore);
 		void setGapAfter(double gapAfter);
 		void setFont(const QString& font);
@@ -72,25 +72,25 @@ class SCRIBUS_API SampleItem : QObject
 		void setDrop(bool drop);
 		void setBullet(bool bul);
 		void setNum(bool num);
-		void setDropLin(int dropLin);
+		void setDropCapLines(int dropLin);
 		void setParEffectDist(double dropDist);
 		void setFontEffect(int fontEffect);
-		void setFColor(const QString& fColor);
-		void setFShade(int fShade);
-		void setSColor(const QString& sColor);
-		void setSShade(int sShade);
-		void setBaseAdj(bool baseAdj);
-		void setTxtShadowX(int txtShadowX);
-		void setTxtShadowY(int txtShadowY);
-		void setTxtOutline(int txtOutline);
-		void setTxtUnderPos(int txtUnderPos);
-		void setTxtUnderWidth(int txtUnderWidth);
-		void setTxtStrikePos(int txtStrikePos);
-		void setTxtStrikeWidth(int txtStrikeWidth);
-		void setScaleH(int scaleH);
-		void setScaleV(int scaleV);
-		void setBaseOff(int baseOff);
-		void setKernVal(int kernVal);
+		void setTxtFillColor(const QString& fColor);
+		void setTxtFillShade(double fShade);
+		void setTxtStrokeColor(const QString& sColor);
+		void setTxtStrokeShade(double sShade);
+		void setTxtShadowX(double txtShadowX);
+		void setTxtShadowY(double txtShadowY);
+		void setTxtOutlineWidth(double txtOutline);
+		void setTxtUnderlineOffset(double txtUnderPos);
+		void setTxtUnderlineWidth(double txtUnderWidth);
+		void setTxtStrikethruOffset(double txtStrikePos);
+		void setTxtStrikethruWidth(double txtStrikeWidth);
+		void setScaleH(double scaleH);
+		void setScaleV(double scaleV);
+		void setBaselineOffset(double baseOff);
+		void setKernVal(double kernVal);
+		void setWordTracking(double wordTracking);
 
 		/*! \brief Get the sample.
 		\param width W of the sample
@@ -106,9 +106,9 @@ class SCRIBUS_API SampleItem : QObject
 		ParagraphStyle m_tmpStyle;
 		/*! \brief Reference to a document.
 		Existing or created one */
-		ScribusDoc *m_Doc;
+		ScribusDoc* m_Doc { nullptr };
 		//! \brief Is the doc created used only? true = used
-		int m_bgShade;
+		int m_bgShade { 100 };
 		//! \brief Device pixel ratio
 		double m_devicePixelRatio { 1.0 };
 };
