@@ -97,16 +97,12 @@ for which a new license (GPL+exception) is in place.
 extern const char ARG_CONSOLE[] =  "--console";
 extern const char ARG_CONSOLE_SHORT[] = "-cl";
 
-bool ScribusQApp::useGUI=false;
+bool ScribusQApp::useGUI = false;
 
-ScribusQApp::ScribusQApp( int & argc, char ** argv ) : QApplication(argc, argv),
-	m_lang(""),
-	m_GUILang("en_GB")
+ScribusQApp::ScribusQApp( int & argc, char ** argv ) : QApplication(argc, argv)
 {
 	ScQApp = this;
 	ScCore = nullptr;
-	m_scDLMgr = nullptr;
-	m_ScCore = nullptr;
 	initDLMgr();
 	setAttribute(Qt::AA_UseHighDpiPixmaps, true);
 }
@@ -136,18 +132,18 @@ void ScribusQApp::parseCommandLine()
 {
 	m_showSplash=!neverSplashExists();
 	QString arg;
-	bool usage=false;
-	bool header=false;
-	bool availlangs=false;
-	bool version=false;
-	bool runUpgradeCheck=false;
+	bool usage = false;
+	bool header = false;
+	bool availlangs = false;
+	bool version = false;
+	bool runUpgradeCheck = false;
 #ifdef WITH_TESTS
 	bool runtests = false;
 	char** testargsv;
 	int testargsc;
 #endif
-	m_showFontInfo=false;
-	m_showProfileInfo=false;
+	m_showFontInfo = false;
+	m_showProfileInfo = false;
 	bool neversplash = false;
 
 	//Parse for command line options
@@ -162,7 +158,7 @@ void ScribusQApp::parseCommandLine()
 		arg = args[argi];
 		if (arg == ARG_PYTHONSCRIPT || arg == ARG_PYTHONSCRIPT_SHORT)
 		{
-			if (argi+1 == argsc)
+			if (argi + 1 == argsc)
 			{
 				std::cout << tr("Option %1 requires an argument.").arg(arg).toLocal8Bit().data() << std::endl;
 				std::exit(EXIT_FAILURE);
@@ -198,19 +194,19 @@ void ScribusQApp::parseCommandLine()
 		}
 		else if (arg == ARG_VERSION || arg == ARG_VERSION_SHORT)
 		{
-			header=true;
-			version=true;
+			header = true;
+			version = true;
 		}
 		else if (arg == ARG_HELP || arg == ARG_HELP_SHORT)
 		{
-			header=true;
-			usage=true;
+			header = true;
+			usage = true;
 		}
 #ifdef WITH_TESTS
 		else if (arg == ARG_TESTS || arg == ARG_TESTS_SHORT)
 		{
-			header=true;
-			runtests=true;
+			header = true;
+			runtests = true;
 			testargsc = argc() - argi;
 			testargsv = argv() + argi;
 			break;
@@ -218,18 +214,19 @@ void ScribusQApp::parseCommandLine()
 #endif
 		else if (arg == ARG_AVAILLANG || arg == ARG_AVAILLANG_SHORT)
 		{
-			header=true;
-			availlangs=true;
+			header = true;
+			availlangs = true;
 		}
 		else if (arg == ARG_UPGRADECHECK || arg == ARG_UPGRADECHECK_SHORT)
 		{
-			header=true;
-			runUpgradeCheck=true;
+			header = true;
+			runUpgradeCheck = true;
 		}
-		else if ( arg == ARG_CONSOLE || arg == ARG_CONSOLE_SHORT )
+		else if (arg == ARG_CONSOLE || arg == ARG_CONSOLE_SHORT)
 		{
 			continue;
-		} else if (arg == ARG_NOSPLASH || arg == ARG_NOSPLASH_SHORT)
+		}
+		else if (arg == ARG_NOSPLASH || arg == ARG_NOSPLASH_SHORT)
 		{
 			m_showSplash = false;
 		}
@@ -240,17 +237,17 @@ void ScribusQApp::parseCommandLine()
 		}
 		else if (arg == ARG_NOGUI || arg == ARG_NOGUI_SHORT)
 		{
-			useGUI=false;
+			useGUI = false;
 		}
 		else if (arg == ARG_FONTINFO || arg == ARG_FONTINFO_SHORT)
 		{
-			m_showFontInfo=true;
+			m_showFontInfo = true;
 		}
 		else if (arg == ARG_PROFILEINFO || arg == ARG_PROFILEINFO_SHORT)
 		{
-			m_showProfileInfo=true;
+			m_showProfileInfo = true;
 		}
-		else if ((arg == ARG_DISPLAY || arg==ARG_DISPLAY_SHORT || arg==ARG_DISPLAY_QT) && ++argi < argsc)
+		else if ((arg == ARG_DISPLAY || arg == ARG_DISPLAY_SHORT || arg == ARG_DISPLAY_QT) && ++argi < argsc)
 		{
 			// allow setting of display, QT expect the option -display <display_name> so we discard the
 			// last argument. FIXME: Qt only understands -display not --display and -d , we need to work
@@ -258,7 +255,7 @@ void ScribusQApp::parseCommandLine()
 		}
 		else if (arg == ARG_PREFS || arg == ARG_PREFS_SHORT)
 		{
-			if (argi+1 == argsc)
+			if (argi + 1 == argsc)
 			{
 				std::cout << tr("Option %1 requires an argument.").arg(arg).toLocal8Bit().data() << std::endl;
 				std::exit(EXIT_FAILURE);
@@ -274,7 +271,7 @@ void ScribusQApp::parseCommandLine()
 				++argi;
 			}
 		}
-		else if (strncmp(arg.toLocal8Bit().data(),"-psn_",4) == 0)
+		else if (strncmp(arg.toLocal8Bit().data(), "-psn_", 4) == 0)
 		{
 			// Andreas Vox: Qt/Mac has -psn_blah flags that must be accepted.
 		}
@@ -285,7 +282,7 @@ void ScribusQApp::parseCommandLine()
 		}
 		else
 		{ //argument is not a known option, but either positional parameter or invalid.
-			if (arg.left(1) == "-")
+			if (arg.at(0) == "-")
 			{
 				std::cout << tr("Invalid argument: %1").arg(arg).toLocal8Bit().data() << std::endl;
 				std::exit(EXIT_FAILURE);
@@ -344,29 +341,28 @@ void ScribusQApp::parseCommandLine()
 	if (header)
 		std::exit(EXIT_SUCCESS);
 	//proceed
-	if(neversplash)
+	if (neversplash)
 		neverSplash(true);
 	
 }
 
 int ScribusQApp::init()
 {
-	m_ScCore=new ScribusCore();
+	m_ScCore = new ScribusCore();
 	Q_CHECK_PTR(m_ScCore);
 	if (!m_ScCore)
 		return EXIT_FAILURE;
-	ScCore=m_ScCore;
-	processEvents();
+	ScCore = m_ScCore;
+	processEvents(QEventLoop::ExcludeUserInputEvents|QEventLoop::ExcludeSocketNotifiers, 1000);
 	ScCore->init(useGUI, m_filesToLoad);
-	int retVal=EXIT_SUCCESS;
+	processEvents();
 	/* TODO:
 	 * When Scribus is truly able to run without GUI
 	 * we should uncomment if (useGUI)
 	 * and delete if (true)
 	 */
 	// if (useGUI)
-	retVal=ScCore->startGUI(m_showSplash, m_showFontInfo, m_showProfileInfo, m_lang);
-
+	int retVal = ScCore->startGUI(m_showSplash, m_showFontInfo, m_showProfileInfo, m_lang);
 	// A hook for plugins and scripts to trigger on. Some plugins and scripts
 	// require the app to be fully set up (in particular, the main window to be
 	// built and shown) before running their setup.
@@ -393,7 +389,7 @@ QStringList ScribusQApp::getLang(QString lang)
 			PrefsPfad = Pff;
 		else
 			PrefsPfad = ScPaths::preferencesDir();
-		QString prefsXMLFile=QDir::toNativeSeparators(PrefsPfad + "prefs150.xml");
+		QString prefsXMLFile = QDir::toNativeSeparators(PrefsPfad + "prefs150.xml");
 		QFileInfo infoPrefsFile(prefsXMLFile);
 		if (infoPrefsFile.exists())
 		{
@@ -403,7 +399,7 @@ QStringList ScribusQApp::getLang(QString lang)
 				PrefsContext* userprefsContext = prefsFile->getContext("user_preferences");
 				if (userprefsContext)
 				{
-					QString prefslang(cleanupLang(userprefsContext->get("gui_language","")));
+					QString prefslang(cleanupLang(userprefsContext->get("gui_language", "")));
 					if (!prefslang.isEmpty())
 						langs.append(prefslang);
 				}
@@ -415,24 +411,24 @@ QStringList ScribusQApp::getLang(QString lang)
 	if (!(lang = ::getenv("LANG")).isEmpty())
 	{
 		lang = cleanupLang(lang);
-		if (lang=="C")
-			lang="en";
+		if (lang == "C")
+			lang = "en";
 		if (!lang.isEmpty())
 			langs.append(lang);
 	}
 	if (!(lang = ::getenv("LC_MESSAGES")).isEmpty())
 	{
 		lang = cleanupLang(lang);
-		if (lang=="C")
-			lang="en";
+		if (lang == "C")
+			lang = "en";
 		if (!lang.isEmpty())
 			langs.append(lang);
 	}
 	if (!(lang = ::getenv("LC_ALL")).isEmpty())
 	{
 		lang = cleanupLang(lang);
-		if (lang=="C")
-			lang="en";
+		if (lang == "C")
+			lang = "en";
 		if (!lang.isEmpty())
 			langs.append(lang);
 	}
@@ -444,14 +440,14 @@ QStringList ScribusQApp::getLang(QString lang)
 	WORD sortId = SORTIDFROMLCID(lcIdo);
 	LANGID langId = GetUserDefaultUILanguage();
 	LCID lcIdn = MAKELCID(langId, sortId);
-	if ( GetLocaleInfoW(lcIdn, LOCALE_SISO639LANGNAME , out, 255) )
+	if (GetLocaleInfoW(lcIdn, LOCALE_SISO639LANGNAME , out, 255))
 	{
 		language = QString::fromUtf16( (ushort*)out );
-		if ( GetLocaleInfoW(lcIdn, LOCALE_SISO3166CTRYNAME, out, 255) )
+		if (GetLocaleInfoW(lcIdn, LOCALE_SISO3166CTRYNAME, out, 255))
 		{
 			sublanguage = QString::fromUtf16( (ushort*)out ).toLower();
 			lang = language;
-			if ( sublanguage != language && !sublanguage.isEmpty() )
+			if (sublanguage != language && !sublanguage.isEmpty() )
 				lang += "_" + sublanguage.toUpper();
 			langs.append(lang);
 		}
@@ -480,13 +476,13 @@ void ScribusQApp::installTranslators(const QStringList & langs)
 	{
 		removeTranslator( transQt );
 		delete transQt;
-		transQt=nullptr;
+		transQt = nullptr;
 	}
 	if (trans)
 	{
 		removeTranslator( trans );
 		delete trans;
-		trans=nullptr;
+		trans = nullptr;
 	}
 
 	transQt = new QTranslator(nullptr);
@@ -523,10 +519,10 @@ void ScribusQApp::installTranslators(const QStringList & langs)
 	if (loadedScribus)
 	{
 		installTranslator(trans);
-		m_GUILang=lang;
+		m_GUILang = lang;
 	}
 	else if (lang == "en")
-		m_GUILang=lang;
+		m_GUILang = lang;
 	/* CB TODO, currently disabled, because its broken broken broken
 	path = ScPaths::instance().pluginDir();
 	QDir dir(path , "*.*", QDir::Name, QDir::Files | QDir::NoSymLinks);
@@ -560,12 +556,26 @@ void ScribusQApp::changeGUILanguage(const QString & newGUILang)
 		installTranslators(newLangs);
 }
 
+void ScribusQApp::changeIconSet(const QString& newIconSet)
+{
+	IconManager& iconManager = IconManager::instance();
+	iconManager.clearCache();
+	iconManager.setActiveFromPrefs(newIconSet);
+	emit iconSetChanged();
+}
+
+void ScribusQApp::setLocale()
+{
+	QLocale::setDefault(LocaleManager::instance().userPreferredLocale());
+	emit localeChanged();
+}
+
 /*! \brief Format an arguments line for printing
 Helper procedure */
 static void printArgLine(QTextStream & ts, const char * smallArg, const char* fullArg, const QString& desc)
 {
 	ts << QString("     %1 %2 %3").arg(QString("%1,").arg(smallArg), -5).arg(fullArg, -32).arg(desc);
-	endl(ts);
+	Qt::endl(ts);
 }
 
 void ScribusQApp::showUsage()
@@ -573,8 +583,8 @@ void ScribusQApp::showUsage()
 	QFile f;
 	f.open(stderr, QIODevice::WriteOnly);
 	QTextStream ts(&f);
-	ts << tr("Usage: scribus [options] [files]") ; endl(ts); endl(ts);
-	ts << tr("Options:") ; endl(ts);
+	ts << tr("Usage: scribus [options] [files]") ; Qt::endl(ts); Qt::endl(ts);
+	ts << tr("Options:") ; Qt::endl(ts);
 	printArgLine(ts, ARG_FONTINFO_SHORT, ARG_FONTINFO, tr("Show information on the console when fonts are being loaded") );
 	printArgLine(ts, ARG_HELP_SHORT, ARG_HELP, tr("Print help (this message) and exit") );
 	printArgLine(ts, ARG_LANG_SHORT, ARG_LANG, tr("Uses xx as shortcut for a language, eg `en' or `de'") );
@@ -585,9 +595,9 @@ void ScribusQApp::showUsage()
 	printArgLine(ts, ARG_PROFILEINFO_SHORT, ARG_PROFILEINFO, tr("Show location of ICC profile information on console while starting") );
 	printArgLine(ts, ARG_UPGRADECHECK_SHORT, ARG_UPGRADECHECK, tr("Download a file from the Scribus website and show the latest available version") );
 	printArgLine(ts, ARG_VERSION_SHORT, ARG_VERSION, tr("Output version information and exit") );
-	printArgLine(ts, ARG_PYTHONSCRIPT_SHORT, qPrintable(QString("%1 <%2> [%3] ").arg(ARG_PYTHONSCRIPT).arg(tr("script"), tr("arguments ..."))), tr("Run script in Python [with optional arguments]. This option must be last option used") );
+	printArgLine(ts, ARG_PYTHONSCRIPT_SHORT, qPrintable(QString("%1 <%2> [%3] ").arg(ARG_PYTHONSCRIPT, tr("script"), tr("arguments ..."))), tr("Run script in Python [with optional arguments]. This option must be last option used") );
 	printArgLine(ts, ARG_NOGUI_SHORT, ARG_NOGUI, tr("Do not start GUI") );
-	ts << (QString("     %1").arg(CMD_OPTIONS_END,-39)) << tr("Explicit end of command line options"); endl(ts);
+	ts << (QString("     %1").arg(CMD_OPTIONS_END,-39)) << tr("Explicit end of command line options"); Qt::endl(ts);
  	
 	
 #if defined(_WIN32) && !defined(_CONSOLE)
@@ -603,23 +613,25 @@ void ScribusQApp::showUsage()
 	std::cout << "name          Open file 'name', the file name must not begin with '-'" ; endl(ts);
 	std::cout << "QT specific options as -display ..." ; endl(ts);
 */
-	endl(ts);
+	Qt::endl(ts);
 	f.close();
 }
 
 void ScribusQApp::showAvailLangs()
 {
 	QFile f;
-	f.open(stderr, QIODevice::WriteOnly);
+	if (!f.open(stderr, QIODevice::WriteOnly))
+		return;
+
 	QTextStream ts(&f);
-	ts << tr("Installed interface languages for Scribus are as follows:"); endl(ts);
-	endl(ts);
+	ts << tr("Installed interface languages for Scribus are as follows:") << Qt::endl;
+	Qt::endl(ts);
 
 	LanguageManager::instance()->printInstalledList();
+	Qt::endl(ts);
 
-	endl(ts);
-	ts << tr("To override the default language choice:"); endl(ts);
-	ts << tr("scribus -l xx or scribus --lang xx, where xx is the language of choice."); endl(ts);
+	ts << tr("To override the default language choice:") << Qt::endl;
+	ts << tr("scribus -l xx or scribus --lang xx, where xx is the language of choice.") << Qt::endl;
 }
 
 void ScribusQApp::showVersion()
@@ -632,20 +644,20 @@ void ScribusQApp::showHeader()
 	QFile f;
 	f.open(stderr, QIODevice::WriteOnly);
 	QTextStream ts(&f);
-	endl(ts);
+	ts << Qt::endl;
 	QString heading( tr("Scribus, Open Source Desktop Publishing") );
 	// Build a separator of ----s the same width as the heading
 	QString separator = QString("").rightJustified(heading.length(),'-');
 	// Then output the heading, separator, and docs/www/etc info in an aligned table
 	const int urlwidth = 23;
 	const int descwidth = -(heading.length() - urlwidth - 1);
-	ts << heading; endl(ts);
-	ts << separator; endl(ts);
-	ts << QString("%1 %2").arg( tr("Homepage")+":",      descwidth).arg("http://www.scribus.net" ); endl(ts);
-	ts << QString("%1 %2").arg( tr("Documentation")+":", descwidth).arg("http://docs.scribus.net"); endl(ts);
-	ts << QString("%1 %2").arg( tr("Wiki")+":",          descwidth).arg("http://wiki.scribus.net"); endl(ts);
-	ts << QString("%1 %2").arg( tr("Issues")+":",        descwidth).arg("http://bugs.scribus.net"); endl(ts);
-	endl(ts);
+	ts << heading << Qt::endl;
+	ts << separator << Qt::endl;
+	ts << QString("%1 %2").arg( tr("Homepage") + ":",      descwidth).arg("http://www.scribus.net" ) << Qt::endl;
+	ts << QString("%1 %2").arg( tr("Documentation") + ":", descwidth).arg("http://docs.scribus.net") << Qt::endl;
+	ts << QString("%1 %2").arg( tr("Wiki") + ":",          descwidth).arg("http://wiki.scribus.net") << Qt::endl;
+	ts << QString("%1 %2").arg( tr("Issues") + ":",        descwidth).arg("http://bugs.scribus.net") << Qt::endl;
+	ts << Qt::endl;
 }
 
 void ScribusQApp::neverSplash(bool splashOff)
@@ -671,6 +683,7 @@ bool ScribusQApp::neverSplashExists()
 
 void ScribusQApp::downloadComplete(const QString &t)
 {
+	Q_UNUSED(t)
 	//qDebug()<<"ScribusQApp: download finished:"<<t;
 }
 
