@@ -23,10 +23,12 @@ for which a new license (GPL+exception) is in place.
 
 #include <cassert>
 #include <iostream>
+
 #include <QByteArray>
 #include <QDebug>
 #include <QGlobalStatic>
 #include <QMessageBox>
+#include <QScreen>
 
 #include "colormgmt/sccolormgmtenginefactory.h"
 #include "commonstrings.h"
@@ -103,15 +105,15 @@ int ScribusCore::startGUI(bool showSplash, bool showFontInfo, bool showProfileIn
 		return(EXIT_FAILURE);
 	
 	closeSplash();
-	m_scribusInitialized=true;
+	m_scribusInitialized = true;
 	connect(ScQApp, SIGNAL(lastWindowClosed()), ScQApp, SLOT(quit()));
 
 	scribus->show();
 	scribus->setupMainWindow();
 
 	QStringList recoverFiles = scribus->findRecoverableFile();
-	int subsRet=scribus->ShowSubs();
-	if (subsRet==0)
+	int subsRet = scribus->ShowSubs();
+	if (subsRet == 0)
 	{
 		if (!m_Files.isEmpty())
 		{
@@ -168,7 +170,7 @@ int ScribusCore::initScribusCore(bool showSplash, bool showFontInfo, bool showPr
 	setSplashStatus( tr("Initializing Keyboard Shortcuts") );
 	m_prefsManager.initDefaultActionKeys();
 	setSplashStatus( tr("Reading Preferences") );
-	m_prefsManager.ReadPrefs();
+	m_prefsManager.readPrefs();
 	LocaleManager::instance().setUserPreferredLocale(m_prefsManager.appPrefs.uiPrefs.userPreferredLocale);
 	m_prefsManager.appPrefs.uiPrefs.showSplashOnStartup=showSplash;
 	if (!m_iconManager.setActiveFromPrefs(m_prefsManager.appPrefs.uiPrefs.iconSet))
@@ -208,7 +210,20 @@ void ScribusCore::initSplash(bool showSplash)
 	m_SplashScreen = nullptr;
 	if (!showSplash)
 		return;
+
+	QScreen* primaryScreeen = qApp->primaryScreen();
+	double pixelRatio = primaryScreeen ? primaryScreeen->devicePixelRatio() : 1.0;
 	QPixmap pix = IconManager::instance().loadPixmap("scribus_splash.png", true);
+	if (pixelRatio != 1.0)
+	{
+		int w = qRound(pix.width() * pixelRatio);
+		int h = qRound(pix.height() * pixelRatio);
+		double integralPart = 0;
+		bool isIntegerRatio = (modf(pixelRatio, &integralPart) == 0.0);
+		pix = pix.scaled(w, h, Qt::IgnoreAspectRatio, isIntegerRatio ? Qt::FastTransformation : Qt::SmoothTransformation);
+		pix.setDevicePixelRatio(pixelRatio);
+	}
+
 	m_SplashScreen = new ScSplashScreen(pix, Qt::WindowStaysOnTopHint);
 	if (m_SplashScreen != nullptr)
 	{
@@ -310,10 +325,7 @@ void ScribusCore::getCMSProfiles(bool showInfo)
 			getCMSProfilesDir(profDir, showInfo, true);
 		}
 	}
-	if ((!PrinterProfiles.isEmpty()) && (!InputProfiles.isEmpty()) && (!MonitorProfiles.isEmpty()))
-		m_haveCMS = true;
-	else
-		m_haveCMS = false;
+	m_haveCMS = (!PrinterProfiles.isEmpty()) && (!InputProfiles.isEmpty()) && (!MonitorProfiles.isEmpty());
 }
 
 void ScribusCore::getCMSProfilesDir(const QString& pfad, bool showInfo, bool recursive)
