@@ -100,7 +100,7 @@ public:
 	void init();
 	bool inAnEditMode() const;
 	bool inASpecialEditMode() const;
-	QList<PageItem*> getAllItems(QList<PageItem*> &items);
+	QList<PageItem*> getAllItems(QList<PageItem*> &items) const;
 	QList<PageItem*> *parentGroup(PageItem* item, QList<PageItem*> *list);
 	void setup(int, int, int, int, int, const QString&, const QString&);
 	void setLoading(bool);
@@ -171,6 +171,8 @@ public:
 	PDFOptions& pdfOptions() { return m_docPrefsData.pdfPrefs; }
 
 	ObjAttrVector& itemAttributes() { return m_docPrefsData.itemAttrPrefs.defaultItemAttributes; }
+	const ObjAttrVector& itemAttributes() const { return m_docPrefsData.itemAttrPrefs.defaultItemAttributes; }
+
 	void setItemAttributes(ObjAttrVector& oav) { m_docPrefsData.itemAttrPrefs.defaultItemAttributes=oav;}
 	void clearItemAttributes() { m_docPrefsData.itemAttrPrefs.defaultItemAttributes.clear(); }
 	void appendToItemAttributes(const ObjectAttribute& oa) { m_docPrefsData.itemAttrPrefs.defaultItemAttributes.append(oa); }
@@ -617,10 +619,10 @@ public:
 	bool styleExists(const QString& styleName) const;
 	bool charStyleExists(const QString& styleName) const;
 	
-	QList<int> getSortedStyleList();
-	QList<int> getSortedCharStyleList();
-	QList<int> getSortedTableStyleList();
-	QList<int> getSortedCellStyleList();
+	QList<int> getSortedStyleList() const;
+	QList<int> getSortedCharStyleList() const;
+	QList<int> getSortedTableStyleList() const;
+	QList<int> getSortedCellStyleList() const;
 	
 	void redefineStyles(const StyleSet<ParagraphStyle>& newStyles, bool removeUnused=false);
 	/**
@@ -675,7 +677,7 @@ public:
 	/*!
 	 * @brief Returns a stringlist of the item attributes within the document
 	 */
-	QStringList getItemAttributeNames();
+	QStringList getItemAttributeNames() const;
 
 	bool AddFont(const QString& name, int fsize = 10);
 	/*!
@@ -863,16 +865,20 @@ public:
 	 */
 	void itemAddDetails(const PageItem::ItemType itemType, const PageItem::ItemFrameType frameType, PageItem* newItem);
 
-	int getItemNrFromUniqueID(uint unique);
-	//return pointer to item
+	/**
+	 * @brief Get index of item in items list
+	 */
+	int getItemNrFromUniqueID(uint unique) const;
+
+	/**
+	 * @brief Return pointer to item
+	 */
 	PageItem* getItemFromName(const QString& name) const;
-	//itemDelete
-	//itemBlah...
 
 	/**
 	 * @brief Rebuild item lists taking into account layer order.
 	 * Utility function used in various places, basically handles keeping items numbered in the way
-	 * they are layered. When layer is a property and not a fuction of storage, this should be removed.
+	 * they are layered. When layer is a property and not a function of storage, this should be removed.
 	 * @sa updateFrameItems();
 	 */
 	void rebuildItemLists();
@@ -938,11 +944,11 @@ public:
 	 * @retval double containing the offset. Returns -1.0 if page not in Pages list (as -ve is not possible).
 	 * Mostly saves bringing in extra includes into files that already have scribusdoc.h
 	 */
-	double getXOffsetForPage(int);
-	double getYOffsetForPage(int);
-	void getBleeds(int pageNumber, MarginStruct& bleedData);
-	void getBleeds(const ScPage* page, MarginStruct& bleedData);
-	void getBleeds(const ScPage* page, const MarginStruct& baseValues, MarginStruct& bleedData);
+	double getXOffsetForPage(int) const;
+	double getYOffsetForPage(int) const;
+	void getBleeds(int pageNumber, MarginStruct& bleedData) const;
+	void getBleeds(const ScPage* page, MarginStruct& bleedData) const;
+	void getBleeds(const ScPage* page, const MarginStruct& baseValues, MarginStruct& bleedData) const;
 	
 	/**
 	 * @brief Item type conversion functions
@@ -960,7 +966,7 @@ public:
 	 * @author Craig Ringer
 	 ** CB Moved from PageItem
 	 */
-	bool itemNameExists(const QString& itemName);
+	bool itemNameExists(const QString& itemName) const;
 	
 	/**
 	 * @brief Set the doc into Master page mode
@@ -1108,6 +1114,8 @@ public:
 	void itemSelection_SetNamedParagraphStyle(const QString & name, Selection* customSelection = nullptr);
 	void itemSelection_SetNamedCharStyle(const QString & name, Selection* customSelection = nullptr);
 	void itemSelection_SetNamedLineStyle(const QString & name, Selection* customSelection = nullptr);
+	void itemSelection_SetNamedCellStyle(const QString & name, Selection* customSelection = nullptr);
+	void itemSelection_SetNamedTableStyle(const QString & name, Selection* customSelection = nullptr);
 	void itemSelection_SetSoftShadow(bool has, QString color, double dx, double dy, double radius, int shade, double opac, int blend, bool erase, bool objopa);
 	void itemSelection_SetLineWidth(double w, Selection* customSelection = nullptr);
 	void itemSelection_SetLineArt(Qt::PenStyle w, Selection* customSelection = nullptr);
@@ -1243,7 +1251,7 @@ public:
 	void rotateItem(double win, PageItem *currItem);
 	void moveRotated(PageItem *currItem, const FPoint& npv);
 	bool sizeItem(double newX, double newY, PageItem *pi, bool fromMP = false, bool DoUpdateClip = true, bool redraw = true);
-	bool moveSizeItem(const FPoint& newX, const FPoint& newY, PageItem* currItem, bool fromMP = false, bool constrainRotation = false);
+	bool moveSizeItem(const FPoint& newX, const FPoint& newY, PageItem* currItem, bool fromMP = false);
 	void adjustItemSize(PageItem *currItem, bool includeGroup = false);
 	void moveGroup(double x, double y, Selection* customSelection = nullptr);
 	void rotateGroup(double angle, Selection* customSelection = nullptr);
@@ -1264,8 +1272,8 @@ public:
 	//! \brief Set rotation mode
 	void setRotationMode(int val);
 
-	//! \brief Fonctions which avoid doc updater and update manager to send too much
-	// unncessary signals when doing updates on multiple items
+	//! \brief Functions which avoid doc updater and update manager to send too much
+	// unnecessary signals when doing updates on multiple items
 	void beginUpdate();
 	void endUpdate();
 
@@ -1448,9 +1456,9 @@ public:
 	int previewVisual {0};
 	struct OpenNodesList
 	{
-		int type;
-		ScPage *page;
-		PageItem *item;
+		int type { -1 };
+		ScPage* page { nullptr };
+		PageItem *item { nullptr };
 	};
 	QList<OpenNodesList> OpenNodes;
 	QTimer *CurTimer {nullptr};
@@ -1695,7 +1703,7 @@ public slots:
 	/**
 	 * Distributes rows in a table evenly.
 	 *
-	 * If in table edit mode and there is a cell selection, each contigous range of selected rows
+	 * If in table edit mode and there is a cell selection, each contiguous range of selected rows
 	 * is distributed. If there is no cell selection, all rows in the table are distributed.
 	 *
 	 * If there is no table selected, then this slot does nothing.
@@ -1705,7 +1713,7 @@ public slots:
 	/**
 	 * Distributes columns in a table evenly.
 	 *
-	 * If in table edit mode and there is a cell selection, each contigous range of selected columns
+	 * If in table edit mode and there is a cell selection, each contiguous range of selected columns
 	 * is distributed. If there is no cell selection, all columns in the table are distributed.
 	 *
 	 * If there is no table selected, then this slot does nothing.
@@ -1788,7 +1796,7 @@ public:
 	bool eraseMark(Mark* mrk, bool fromText=false, PageItem* item = nullptr, bool force = false); //force is used only for deleting non-unique marks by MarksManager
 	void setUndoDelMark(Mark* mrk);
 	//invalidate all text frames where given mark will found
-	//useful spacially for varaible text marks after changing its text definition
+	//useful spacially for variable text marks after changing its text definition
 	//if forceUpdate then found master frames are relayouted
 	bool invalidateVariableTextFrames(Mark* mrk, bool forceUpdate = false); //returns if any text was changed
 
@@ -1805,13 +1813,13 @@ public:
 	PageItem_NoteFrame* createNoteFrame(PageItem_TextFrame* inFrame, NotesStyle *nStyle, int index = -1);
 	PageItem_NoteFrame* createNoteFrame(NotesStyle *nStyle, double x, double y, double w, double h, double w2, const QString& fill, const QString& outline);
 	//delete noteframe
-	void delNoteFrame(PageItem_NoteFrame *nF, bool removeMarks=true, bool forceDeletion = true);
+	void delNoteFrame(PageItem_NoteFrame *noteFrame, bool removeMarks=true, bool forceDeletion = true);
 	//renumber notes for given notes style
 	//return true if doc needs update after changing numbers of notes
 	bool updateNotesNums(NotesStyle* nStyle);
 	//set new text styles for notes marks
 	void updateNotesFramesStyles(NotesStyle* nStyle);
-	//check conflicts beetween notes styles
+	//check conflicts between notes styles
 	bool validateNSet(const NotesStyle& NS, QString newName = "");
 	//update layout remove empty notesframes
 	bool notesFramesUpdate();
@@ -1878,7 +1886,7 @@ protected slots:
 //auto-numerations
 public:
 	QMap<QString, NumStruct*> numerations;
-	QStringList orgNumNames; //orgNumerations keeps original settings read from paragraph styles for reset settings overrided localy
+	QStringList orgNumNames; //orgNumerations keeps original settings read from paragraph styles for reset settings overridden localy
 	void setupNumerations(); //read styles for used auto-numerations, initialize numCounters
 	QString getNumberStr(const QString& numName, int level, bool reset, const ParagraphStyle &style);
 	void setNumerationCounter(const QString& numName, int level, int number);
