@@ -27,8 +27,7 @@ Selection::Selection(QObject* parent) :
 	QObject(parent),
 	m_isGUISelection(false),
 	m_delaySignals(0),
-	m_sigSelectionChanged(false),
-	m_sigSelectionIsMultiple(false)
+	m_sigSelectionChanged(false)
 {
 	m_groupX   = m_groupY   = m_groupW   = m_groupH   = 0;
 	m_visualGX = m_visualGY = m_visualGW = m_visualGH = 0;
@@ -38,8 +37,7 @@ Selection::Selection(QObject* parent, bool guiSelection) :
 	QObject(parent),
 	m_isGUISelection(guiSelection),
 	m_delaySignals(0),
-	m_sigSelectionChanged(false),
-	m_sigSelectionIsMultiple(false)
+	m_sigSelectionChanged(false)
 {
 	m_groupX   = m_groupY   = m_groupW   = m_groupH   = 0;
 	m_visualGX = m_visualGY = m_visualGW = m_visualGH = 0;
@@ -55,15 +53,14 @@ Selection::Selection(const Selection& other) :
 	// We do not copy m_delaySignals as that can potentially
 	// cause much trouble balancing delaySignalOff/On right
 	m_delaySignals(0), 
-	m_sigSelectionChanged(other.m_sigSelectionChanged),
-	m_sigSelectionIsMultiple(other.m_sigSelectionIsMultiple)
+	m_sigSelectionChanged(other.m_sigSelectionChanged)
 {
 	if (m_isGUISelection && !m_SelList.isEmpty())
 	{
 		m_SelList[0]->connectToGUI();
 		m_SelList[0]->emitAllToGUI();
 		m_SelList[0]->setSelected(true);
-		emit selectionIsMultiple(m_SelList.count() > 1);
+		emit selectionChanged();
 	}
 	m_groupX = other.m_groupX;
 	m_groupY = other.m_groupY;
@@ -85,19 +82,18 @@ Selection& Selection::operator=(const Selection &other)
 		for (SelectionList::Iterator it = m_SelList.begin(); it != itend; ++it)
 			(*it)->setSelected(false);
 	}
-	m_SelList=other.m_SelList;
+	m_SelList = other.m_SelList;
 	// Do not copy m_isGUISelection for consistency with cpy ctor
 	/* m_isGUISelection = other.m_isGUISelection; */
 	// We do not copy m_delaySignals as that can potentially
 	// cause much trouble balancing delaySignalOff/On right
 	m_sigSelectionChanged = other.m_sigSelectionChanged;
-	m_sigSelectionIsMultiple = other.m_sigSelectionIsMultiple;
 	if (m_isGUISelection && !m_SelList.isEmpty())
 	{
 		m_SelList[0]->connectToGUI();
 		m_SelList[0]->emitAllToGUI();
 		m_SelList[0]->setSelected(true);
-		emit selectionIsMultiple(m_SelList.count() > 1);
+		emit selectionChanged();
 	}
 	return *this;
 }
@@ -113,8 +109,8 @@ void Selection::copy(Selection& other, bool emptyOther)
 			(*it)->setSelected(false);
 	}
 	m_SelList = other.m_SelList;
-	if (m_isGUISelection && !m_SelList.isEmpty())
-		m_sigSelectionIsMultiple = true;
+	if (m_isGUISelection)
+		m_sigSelectionChanged = true;
 	if (emptyOther)
 		other.clear();
 	sendSignals();
@@ -128,9 +124,9 @@ bool Selection::clear()
 {
 	if (!m_SelList.isEmpty())
 	{
-		SelectionList::Iterator itend=m_SelList.end();
-		SelectionList::Iterator it=m_SelList.begin();
-		while (it!=itend)
+		SelectionList::Iterator itend = m_SelList.end();
+		SelectionList::Iterator it = m_SelList.begin();
+		while (it != itend)
 		{
 			(*it)->isSingleSel=false;
 			if (m_isGUISelection)
@@ -149,29 +145,26 @@ bool Selection::clear()
 
 bool Selection::connectItemToGUI()
 {
-	bool ret = false;
 	if (!m_isGUISelection || m_SelList.isEmpty())
-		return ret;
-	if (m_SelList.count() == 1)
+		return false;
+
+	QPointer<PageItem> pi = m_SelList.first();
+	//Quick check to see if the pointer is nullptr, if its nullptr, we should remove it from the list now
+	while (pi.isNull())
 	{
-		QPointer<PageItem> pi=m_SelList.first();
-		//Quick check to see if the pointer is nullptr, if its nullptr, we should remove it from the list now
-		if (pi.isNull())
-		{
-			m_SelList.removeAll(pi);
-			return ret;
-		}
-		ret = pi->connectToGUI();
-		pi->emitAllToGUI();
-		m_sigSelectionChanged = true;
-	}
-	else
-	{
-		ret = m_SelList.first()->connectToGUI();
-		m_SelList.first()->emitAllToGUI();
-		m_sigSelectionChanged  = true;
-		m_sigSelectionIsMultiple = true;
+		m_SelList.removeAll(pi);
+		if (m_SelList.isEmpty())
+			break;
+		pi = m_SelList.first();
 	}
+
+	if (pi.isNull())
+		return false;
+
+	bool ret = pi->connectToGUI();
+	pi->emitAllToGUI();
+	m_sigSelectionChanged = true;
+
 	sendSignals(false);
 	return ret;
 }
@@ -202,7 +195,6 @@ bool Selection::addItem(PageItem *item, bool /*ignoreGUI*/)
 		{
 			item->setSelected(true);
 			m_sigSelectionChanged = true;
-			m_sigSelectionIsMultiple = true;
 		}
 		sendSignals();
 		return true;
@@ -210,36 +202,59 @@ bool Selection::addItem(PageItem *item, bool /*ignoreGUI*/)
 	return false;
 }
 
-bool Selection::prependItem(PageItem *item, bool /*doEmit*/)
+bool Selection::addItems(const QList<PageItem *> items)
+{
+	if (items.isEmpty())
+		return false;
+
+	QList< QPointer<PageItem> > toAdd;
+	toAdd.reserve(items.count());
+	for (int i = 0; i < items.count(); ++i)
+	{
+		PageItem* item = items.at(i);
+		if (m_SelList.contains(item))
+			continue;
+		toAdd.append(item);
+		item->setSelected(true);
+	}
+
+	if (toAdd.count() <= 0)
+		return false;
+
+	m_SelList.append(toAdd);
+	if (m_isGUISelection)
+		m_sigSelectionChanged = true;
+	sendSignals();
+	return true;
+}
+
+bool Selection::prependItem(PageItem *item)
 {
 	if (item == nullptr)
 		return false;
-	if (!m_SelList.contains(item))
+	if (m_SelList.contains(item))
+		return false;
+
+	if (m_isGUISelection && !m_SelList.isEmpty())
+		m_SelList[0]->disconnectFromGUI();
+	m_SelList.prepend(item);
+	if (m_isGUISelection)
 	{
-		if (m_isGUISelection && !m_SelList.isEmpty())
-			m_SelList[0]->disconnectFromGUI();
-		m_SelList.prepend(item);
-		if (m_isGUISelection /*&& doEmit*/)
-		{
-			item->setSelected(true);
-			m_sigSelectionChanged = true;
-			m_sigSelectionIsMultiple = true;
-		}	
-		sendSignals();
-		return true;
-	}
-	return false;
+		item->setSelected(true);
+		m_sigSelectionChanged = true;
+	}	
+	sendSignals();
+	return true;
 }
 
 PageItem *Selection::itemAt_(int index)
 {
-	if (!m_SelList.isEmpty() && index<m_SelList.count())
+	if (!m_SelList.isEmpty() && index < m_SelList.count())
 	{
-		QPointer<PageItem> pi=m_SelList[index];
+		QPointer<PageItem> pi = m_SelList[index];
 		//If not nullptr return it, otherwise remove from the list and return nullptr
 		if (!pi.isNull())
 			return pi;
-//		SelectionList::Iterator it=m_SelList.at(index);
 		m_SelList.removeAt(index);
 	}
 	return nullptr;
@@ -276,49 +291,92 @@ bool Selection::removeFirst()
 
 bool Selection::removeItem(PageItem *item)
 {
-    bool removeOk(false);
-	if (!m_SelList.isEmpty() && m_SelList.contains(item))
-	{
-		removeOk = (m_SelList.removeAll(item)==1);
-		if (removeOk)
-		{
-			if (m_isGUISelection)
-			{
-				item->setSelected(false);
-				item->disconnectFromGUI();
-			}
-			item->isSingleSel = false;
-		}
+	if (m_SelList.isEmpty() || !m_SelList.contains(item))
+		return false;
 
+	bool removeOk = (m_SelList.removeAll(item) == 1);
+	if (removeOk)
+	{
 		if (m_isGUISelection)
 		{
-			m_sigSelectionChanged = true;
-			sendSignals();
+			item->setSelected(false);
+			item->disconnectFromGUI();
 		}
-		return removeOk;
+		item->isSingleSel = false;
+	}
+
+	if (m_isGUISelection)
+	{
+		m_sigSelectionChanged = true;
+		sendSignals();
 	}
 	return removeOk;
 }
 
+bool Selection::removeItemsOfLayer(int layedID)
+{
+	if (m_SelList.isEmpty())
+		return false;
+
+	int oldSelCount = m_SelList.count();
+
+	delaySignalsOn();
+	
+	int selIndex = 0;
+	while (selIndex < m_SelList.count())
+	{
+		QPointer<PageItem> pi = m_SelList.at(selIndex);
+		if (pi.isNull())
+		{
+			removeItem(itemAt(selIndex));
+			continue;
+		}
+
+		if (pi->m_layerID != layedID)
+		{
+			++selIndex;
+			continue;
+		}
+
+		removeItem(itemAt(selIndex));
+	}
+
+	delaySignalsOff();
+
+	bool itemsRemoved = (oldSelCount != m_SelList.count());
+	return itemsRemoved;
+}
+
+void Selection::replaceItem(PageItem* oldItem, PageItem* newItem)
+{
+	delaySignalsOn();
+
+	int itemIndex = findItem(oldItem);
+	if (itemIndex >= 0)
+		m_SelList.replace(itemIndex, newItem);
+
+	delaySignalsOff();
+}
+
 PageItem* Selection::takeItem(int itemIndex)
 {
-	if (!m_SelList.isEmpty() && itemIndex<m_SelList.count())
+	if (m_SelList.isEmpty() || itemIndex >= m_SelList.count())
+		return nullptr;
+
+	PageItem *item =  m_SelList[itemIndex];
+	bool removeOk = (m_SelList.removeAll(item) == 1);
+	if (removeOk)
 	{
-		PageItem *item =  m_SelList[itemIndex];
-		bool removeOk = (m_SelList.removeAll(item) == 1);
-		if (removeOk)
+		item->isSingleSel = false;
+		if (m_isGUISelection)
 		{
-			item->isSingleSel = false;
-			if (m_isGUISelection)
-			{
-				item->setSelected(false);
-				m_sigSelectionChanged = true;
-				if (itemIndex == 0)
-					item->disconnectFromGUI();
-			}
-			sendSignals();
-			return item;
+			item->setSelected(false);
+			m_sigSelectionChanged = true;
+			if (itemIndex == 0)
+				item->disconnectFromGUI();
 		}
+		sendSignals();
+		return item;
 	}
 	return nullptr;
 }
@@ -326,9 +384,8 @@ PageItem* Selection::takeItem(int itemIndex)
 QStringList Selection::getSelectedItemsByName() const
 {
 	QStringList names;
-	SelectionList::ConstIterator it=m_SelList.begin();
-	SelectionList::ConstIterator itend=m_SelList.end();
-	for ( ; it!=itend ; ++it)
+	SelectionList::ConstIterator itend = m_SelList.end();
+	for (auto it = m_SelList.begin(); it != itend ; ++it)
 		names.append((*it)->itemName());
 	return names;
 }
@@ -339,10 +396,10 @@ double Selection::width() const
 		return 0.0;
 	double minX =  std::numeric_limits<double>::max();
 	double maxX = -std::numeric_limits<double>::max();
-	SelectionList::ConstIterator it=m_SelList.begin();
-	SelectionList::ConstIterator itend=m_SelList.end();
 	double x1 = 0.0, x2 = 0.0, y1 = 0.0, y2 = 0.0;
-	for ( ; it != itend ; ++it)
+
+	SelectionList::ConstIterator itend = m_SelList.end();
+	for (auto it = m_SelList.begin(); it != itend ; ++it)
 	{
 		(*it)->getBoundingRect(&x1, &y1, &x2, &y2);
 		if (x1 < minX)
@@ -350,7 +407,7 @@ double Selection::width() const
 		if (x2 > maxX)
 			maxX = x2;
 	}
-	return maxX-minX;
+	return maxX - minX;
 }
 
 double Selection::height() const
@@ -359,10 +416,10 @@ double Selection::height() const
 		return 0.0;
 	double minY =  std::numeric_limits<double>::max();
 	double maxY = -std::numeric_limits<double>::max();
-	SelectionList::ConstIterator it=m_SelList.begin();
-	SelectionList::ConstIterator itend=m_SelList.end();
 	double x1 = 0.0, x2 = 0.0, y1 = 0.0, y2 = 0.0;
-	for ( ; it != itend ; ++it)
+
+	SelectionList::ConstIterator itend = m_SelList.end();
+	for (auto it = m_SelList.begin(); it != itend ; ++it)
 	{
 		(*it)->getBoundingRect(&x1, &y1, &x2, &y2);
 		if (y1 < minY)
@@ -370,7 +427,7 @@ double Selection::height() const
 		if (y2 > maxY)
 			maxY = y2;
 	}
-	return maxY-minY;
+	return maxY - minY;
 }
 
 void Selection::setGroupRect()
@@ -447,7 +504,7 @@ QRectF Selection::getGroupRect()
 {
 	double x, y, w, h;
 	getGroupRect(&x, &y, &w, &h);
-	return QRectF(x,y,w,h);
+	return QRectF(x, y, w, h);
 }
 
 void Selection::getVisualGroupRect(double * x, double * y, double * w, double * h)
@@ -463,7 +520,7 @@ QRectF Selection::getVisualGroupRect()
 {
 	double x, y, w, h;
 	getGroupRect(&x, &y, &w, &h);
-	return QRectF(x,y,w,h);
+	return QRectF(x, y, w, h);
 }
 
 bool Selection::containsItemType(PageItem::ItemType type) const
@@ -490,7 +547,7 @@ bool Selection::itemsAreSameType() const
 	SelectionList::ConstIterator it = m_SelList.begin();
 	SelectionList::ConstIterator itend = m_SelList.end();
 	PageItem::ItemType itemType = (*it)->itemType();
-	for ( ; it!=itend ; ++it)
+	for ( ; it != itend ; ++it)
 	{
 		if ((*it)->isGroup())		// ignore GroupControl items
 			continue;
@@ -500,6 +557,24 @@ bool Selection::itemsAreSameType() const
 	return true;
 }
 
+bool Selection::itemsAreOnSamePage() const
+{
+	//CB Putting count=1 before isempty test as its probably the most likely, given our view code.
+	if (m_SelList.count() == 1)
+		return true;
+	if (m_SelList.isEmpty())
+		return false;
+	auto it = m_SelList.begin();
+	auto itend = m_SelList.end();
+	auto ownPage = (*it)->OwnPage;
+	for ( ; it != itend ; ++it)
+	{
+		if ((*it)->OwnPage != ownPage)
+			return false;
+	}
+	return true;
+}
+
 int Selection::objectsLayer() const
 {
 	if (m_SelList.isEmpty())
@@ -524,9 +599,9 @@ bool Selection::objectsHaveSameParent() const
 
 	bool haveSameParent = true;
 	const PageItem *firstItem = itemAt(0);
-	for (int a = 1; a < selectedItemCount; ++a)
+	for (int i = 1; i < selectedItemCount; ++i)
 	{
-		if (itemAt(a)->Parent != firstItem->Parent)
+		if (itemAt(i)->Parent != firstItem->Parent)
 		{
 			haveSameParent = false;
 			break;
@@ -564,10 +639,7 @@ void Selection::sendSignals(bool guiConnect)
 			connectItemToGUI();
 		if (m_sigSelectionChanged)
 			emit selectionChanged();
-		if (m_sigSelectionIsMultiple)
-			emit selectionIsMultiple(m_SelList.count() > 1);
 		m_sigSelectionChanged = false;
-		m_sigSelectionIsMultiple = false;
 	}
 }
 
