@@ -16,9 +16,7 @@ for which a new license (GPL+exception) is in place.
 #ifndef STYLEOPTIONS_H
 #define STYLEOPTIONS_H
 
-#define OPTION_USE_QTOOLBUTTON 1
-#define OPTION_FLAT_BUTTON 1
-#ifdef Q_WS_MAC
+#ifdef Q_OS_MAC
 #define AQUA_EXTRA 20
 #else
 #define AQUA_EXTRA 0
