@@ -107,7 +107,12 @@ void ScreenPainter::drawGlyph(const GlyphCluster& gc)
 		if (gid >= ScFace::CONTROL_GLYPHS)
 			gid -= ScFace::CONTROL_GLYPHS;
 		else if (gid != 0)
-			gid = 32;
+		{
+			gid = gc.getText().at(0).unicode();
+			QChar chr(gid);
+			if (chr != SpecialChars::NBSPACE && chr != SpecialChars::NNBSPACE)
+				gid = 32;
+		}
 		QTransform chma, chma4;
 		FPointArray outline;
 		if (gid == 0)
@@ -162,6 +167,12 @@ void ScreenPainter::drawGlyph(const GlyphCluster& gc)
 			outline = m_item->doc()->symNonBreak.copy();
 			chma4.translate(gc.xoffset, -fontSize() * gc.scaleV() * 0.4);
 		}
+		else if (gid == SpecialChars::NNBSPACE.unicode())
+		{
+			stroke = false;
+			outline = m_item->doc()->symNonBreak.copy();
+			chma4.translate(gc.xoffset, -fontSize() * gc.scaleV() * 0.4);
+		}
 		else if (gid == SpecialChars::NBHYPHEN.unicode())
 		{
 			outline = font().glyphOutline(font().hyphenGlyph(), fontSize());
@@ -198,7 +209,7 @@ void ScreenPainter::drawGlyph(const GlyphCluster& gc)
 		if (stroke)
 		{
 			QColor tmp = m_painter->pen();
-			m_painter->setStrokeMode(1);
+			m_painter->setStrokeMode(ScPainter::Solid);
 			m_painter->setPen(m_painter->brush(), 1, Qt::SolidLine, Qt::FlatCap, Qt::MiterJoin);
 			m_painter->setLineWidth(fontSize() * gc.scaleV() / 20.0);
 			m_painter->strokePath();
@@ -206,7 +217,7 @@ void ScreenPainter::drawGlyph(const GlyphCluster& gc)
 		}
 		else
 		{
-			m_painter->setFillMode(1);
+			m_painter->setFillMode(ScPainter::Solid);
 			m_painter->fillPath();
 		}
 		m_painter->setBrush(oldBrush);
@@ -279,7 +290,7 @@ void ScreenPainter::drawLine(QPointF start, QPointF end)
 	m_painter->restore();
 }
 
-void ScreenPainter::drawRect(QRectF rect)
+void ScreenPainter::drawRect(const QRectF& rect)
 {
 	m_painter->save();
 	setupState(true);
