@@ -17,8 +17,7 @@ for which a new license (GPL+exception) is in place.
 #include "util.h"
 
 ScText_Shared::ScText_Shared(const StyleContext* pstyles) :
-	pstyleContext(nullptr),
-	refs(1), len(0), cursorPosition(0)
+	pstyleContext(nullptr)
 {
 	pstyleContext.setDefaultStyle( & defaultStyle );
 	defaultStyle.setContext( pstyles );
@@ -32,7 +31,9 @@ ScText_Shared::ScText_Shared(const StyleContext* pstyles) :
 ScText_Shared::ScText_Shared(const ScText_Shared& other) :
 	defaultStyle(other.defaultStyle), 
 	pstyleContext(other.pstyleContext),
-	refs(1), len(0), cursorPosition(other.cursorPosition),
+	cursorPosition(other.cursorPosition),
+	selFirst(other.selFirst), selLast(other.selLast),
+	marksCount(other.marksCount), marksCountChanged(other.marksCountChanged),
 	trailingStyle(other.trailingStyle)
 {
 	pstyleContext.setDefaultStyle( &defaultStyle );
@@ -41,14 +42,16 @@ ScText_Shared::ScText_Shared(const ScText_Shared& other) :
 
 	QListIterator<ScText*> it( other );
 	ScText* elem;
-	while ( it.hasNext() ) {
+	while ( it.hasNext() )
+	{
 		elem = it.next();
 		ScText* elem2 = new ScText(*elem);
 		append(elem2);
-		if (elem2->parstyle) {
+		if (elem2->parstyle)
+		{
 			elem2->parstyle->setContext( & pstyleContext);
 //				elem2->parstyle->charStyle().setContext( defaultStyle.charStyleContext() );
-			replaceCharStyleContextInParagraph(count()-1, elem2->parstyle->charStyleContext());
+			replaceCharStyleContextInParagraph(count() - 1, elem2->parstyle->charStyleContext());
 		}
 	}
 	len = count();
@@ -62,6 +65,11 @@ void ScText_Shared::clear()
 		delete this->takeFirst(); 
 	QList<ScText*>::clear();
 	cursorPosition = 0;
+	selFirst = 0;
+	selLast = -1;
+	if (marksCount > 0)
+		marksCountChanged = true;
+	marksCount = 0;
 }
 
 ScText_Shared& ScText_Shared::operator= (const ScText_Shared& other) 
@@ -78,11 +86,13 @@ ScText_Shared& ScText_Shared::operator= (const ScText_Shared& other)
 		clear();
 		QListIterator<ScText*> it( other );
 		ScText* elem;
-		while ( it.hasNext() ) {
+		while ( it.hasNext() )
+		{
 			elem = it.next();
 			ScText* elem2 = new ScText(*elem);
 			append(elem2);
-			if (elem2->parstyle) {
+			if (elem2->parstyle)
+			{
 				elem2->parstyle->setContext( & pstyleContext );
 //					qDebug() << QString("StoryText::copy: * %1 align=%2").arg(elem2->parstyle->parent())
 //						   .arg(elem2->parstyle->alignment())
@@ -93,6 +103,10 @@ ScText_Shared& ScText_Shared::operator= (const ScText_Shared& other)
 		}
 		len = count();
 		cursorPosition = other.cursorPosition;
+		selFirst = other.selFirst;
+		selLast = other.selLast;
+		marksCount = other.marksCount;
+		marksCountChanged = other.marksCountChanged;
 		pstyleContext.invalidate();
 //			qDebug() << QString("StoryText::copy: %1 align=%2 %3").arg(trailingStyle.parentStyle()->name())
 //				   .arg(trailingStyle.alignment()).arg((uint)trailingStyle.context());
@@ -132,7 +146,8 @@ void ScText_Shared::replaceCharStyleContextInParagraph(int pos, const StyleConte
 	// assert that all chars point to the following parstyle
 	QListIterator<ScText*> it( *this );
 	const StyleContext* lastContext = nullptr;
-	while ( it.hasNext() ) {
+	while ( it.hasNext() )
+	{
 		ScText* elem = it.next();
 		assert( elem );
 		if ( elem->ch.isNull() ) 
