@@ -27,6 +27,7 @@ pageitem.cpp  -  description
 //FIXME: this include must go to sctextstruct.h !
 #include <QList>
 #include <cassert>  //added to make Fedora-5 happy
+
 #include "fpoint.h"
 #include "notesstyles.h"
 #include "scfonts.h"
@@ -34,6 +35,7 @@ pageitem.cpp  -  description
 #include "sctext_shared.h"
 #include "selection.h"
 #include "storytext.h"
+#include "textnote.h"
 //
 #include "util.h"
 #include "resourcecollection.h"
@@ -579,7 +581,8 @@ void StoryText::insertParSep(int pos)
 void StoryText::removeParSep(int pos)
 {
 	ScText* it = item(pos);
-	if (it->parstyle) {
+	if (it->parstyle)
+	{
 //		const CharStyle* oldP = & it->parstyle->charStyle();
 //		const CharStyle* newP = & that->paragraphStyle(pos+1).charStyle();
 //		d->replaceParentStyle(pos, oldP, newP);
@@ -588,7 +591,7 @@ void StoryText::removeParSep(int pos)
 	}
 	// demote this parsep so the assert code in replaceCharStyleContextInParagraph()
 	// doesn't choke:
-	it->ch = 0;
+	it->ch = QChar();
 	d->replaceCharStyleContextInParagraph(pos, paragraphStyle(pos+1).charStyleContext());
 }
 
@@ -1142,6 +1145,26 @@ int StoryText::findMark(const Mark* mrk, int startPos) const
 	return -1;
 }
 
+int StoryText::findNote(const TextNote* textNote) const
+{
+	if (d->len <= 0)
+		return -1;
+
+	int len = d->len;
+	for (int i = 0; i < len; ++i)
+	{
+		const ScText* textItem = d->at(i);
+		if (textItem->ch != SpecialChars::OBJECT || textItem->mark == nullptr)
+			continue;
+		if (textItem->mark->getType() != MARKNoteFrameType)
+			continue;
+		if (textItem->mark->getNotePtr() == textNote)
+			return i;
+	}
+
+	return -1;
+}
+
 bool StoryText::hasMark(int pos, const Mark* mrk) const
 {
 	if (pos < 0)
@@ -1150,12 +1173,25 @@ bool StoryText::hasMark(int pos, const Mark* mrk) const
 	assert(pos >= 0);
 	assert(pos < length());
 
-	StoryText* that = const_cast<StoryText *>(this);
-	if (that->d->at(pos)->ch == SpecialChars::OBJECT)
-		return that->d->at(pos)->hasMark(mrk);
+	if (d->at(pos)->ch == SpecialChars::OBJECT)
+		return d->at(pos)->hasMark(mrk);
 	return false;
 }
 
+bool StoryText::hasMark(int pos, MarkType markType) const
+{
+	if (pos < 0)
+		pos += length();
+
+	assert(pos >= 0);
+	assert(pos < length());
+
+	const ScText* textItem = d->at(pos);
+	if (textItem->ch != SpecialChars::OBJECT)
+		return false;
+	return (textItem->mark && textItem->mark->isType(markType));
+}
+
 Mark* StoryText::mark(int pos) const
 {
 	if (pos < 0)
@@ -1164,8 +1200,7 @@ Mark* StoryText::mark(int pos) const
 	assert(pos >= 0);
 	assert(pos < length());
 
-	StoryText* that = const_cast<StoryText *>(this);
-	return that->d->at(pos)->mark;
+	return d->at(pos)->mark;
 }
 
 
@@ -1205,7 +1240,6 @@ void StoryText::applyMarkCharstyle(Mark* mrk, CharStyle& currStyle) const
 		currStyle.setFeatures(s.featureList());
 }
 
-
 void StoryText::replaceMark(int pos, Mark* mrk)
 {
 	if (pos < 0)
@@ -1221,7 +1255,7 @@ void StoryText::replaceMark(int pos, Mark* mrk)
 	if (textItem->mark)
 		this->d->marksCount++;
 
-	// Set marksCountChanged unconditionnaly to force text relayout
+	// Set marksCountChanged unconditionally to force text relayout
 	d->marksCountChanged = true;
 }
 
@@ -1236,7 +1270,6 @@ bool StoryText::isLowSurrogate(int pos) const
 	return pos >= 0 && pos < length() && text(pos).isLowSurrogate();
 }
 
-
 LayoutFlags StoryText::flags(int pos) const
 {
 	if (pos < 0)
@@ -2171,13 +2204,13 @@ void StoryText::validate()
 }
 */
 
-ScText*  StoryText::item(int index)
+ScText* StoryText::item(int index)
 {
 	assert( index < length() );
 	return const_cast<StoryText *>(this)->d->at(index);
 }
 
-const ScText*  StoryText::item(int index) const
+const ScText* StoryText::item(int index) const
 {
 	assert( index < length() );
 	return const_cast<StoryText *>(this)->d->at(index);
@@ -2278,10 +2311,9 @@ void StoryText::saxx(SaxHandler& handler, const Xml_string& elemtag) const
 				mark_attr.insert("item", mrk->getItemPtr()->itemName());
 			else if (mrk->isType(MARK2MarkType))
 			{
-				QString l;
-				MarkType t;
-				mrk->getMark(l, t);
-				if (m_doc->getMark(l,t) != nullptr)
+				QString l = mrk->getDestMarkName();
+				MarkType t = mrk->getDestMarkType();
+				if (m_doc->getMark(l, t) != nullptr)
 				{
 					mark_attr.insert("mark_l", l);
 					mark_attr.insert("mark_t", QString::number((int) t));
@@ -2560,7 +2592,7 @@ public:
 					if (mrk->isType(MARK2MarkType) && (m_lIt != attr.end()) && (m_tIt != attr.end()))
 					{
 						Mark* targetMark = doc->getMark(Xml_data(m_lIt), (MarkType) parseInt(Xml_data(m_tIt)));
-						mrk->setMark(targetMark);
+						mrk->setDestMark(targetMark);
 						if (targetMark == nullptr)
 							mrk->setString("0");
 						else
