@@ -26,11 +26,12 @@ for which a new license (GPL+exception) is in place.
 #include "bookmarkpalette.h"
 
 BookPalette::BookPalette(QWidget* parent) : ScDockPalette( parent, "Books" )
-{
+{;
 	setObjectName(QString::fromLocal8Bit("Books"));
+	setContentsMargins(3, 3, 3, 3);
+	setMinimumSize( QSize(220, 240) );
 	setSizePolicy( QSizePolicy(QSizePolicy::Minimum, QSizePolicy::Minimum));
 	BView = new BookmarkView(this);
-	BView->setMinimumSize(QSize(100,150));
 	setWidget( BView );
 	languageChange();
 }
