@@ -36,7 +36,7 @@ CharZoom::CharZoom(QWidget* parent, uint currentChar, const ScFace& face)
 		gly.map(chma);
 		p->translate(ww / 2, 1);
 		p->setBrush(Qt::black);
-		p->setFillMode(1);
+		p->setFillMode(ScPainter::Solid);
 		p->setupPolygon(&gly);
 		p->fillPath();
 		p->end();
