@@ -43,13 +43,14 @@ public:
 		fancyPixmaps
 	};
 
-	ColorCombo( QWidget* parent=0 );
-	ColorCombo( ColorCombo::PixmapType type, QWidget* parent=0 );
-	ColorCombo( bool rw, QWidget* parent=0 );
+	ColorCombo( QWidget* parent=nullptr );
+	ColorCombo( ColorCombo::PixmapType type, QWidget* parent=nullptr );
+	ColorCombo( bool rw, QWidget* parent=nullptr );
 
 	QString currentColor() const;
 
 	void setColors(ColorList& list, bool insertNone = true);
+	void setCurrentColor(QString colorName);
 	void setPixmapType(ColorCombo::PixmapType type);
 
 	void initColorList(ColorList* colorList, ScribusDoc* doc, const QString& colorValue);
