@@ -25,6 +25,7 @@ for which a new license (GPL+exception) is in place.
 #include <QApplication>
 #include <QCheckBox>
 #include <QComboBox>
+#include <QDesktopWidget>
 #include <QDir>
 #include <QFileInfo>
 #include <QFrame>
@@ -35,6 +36,7 @@ for which a new license (GPL+exception) is in place.
 #include <QPainter>
 #include <QPixmap>
 #include <QPushButton>
+#include <QScreen>
 #include <QTextCodec>
 #include <QVBoxLayout>
 
@@ -46,6 +48,8 @@ for which a new license (GPL+exception) is in place.
 #include "fileloader.h"
 #include "iconmanager.h"
 #include "loadsaveplugin.h"
+#include "prefscontext.h"
+#include "prefsfile.h"
 #include "prefsmanager.h"
 #include "scfilewidget.h"
 #include "scimage.h"
@@ -57,9 +61,6 @@ for which a new license (GPL+exception) is in place.
 #include "util_color.h"
 #include "util_formats.h"
 
-
-
-
 extern QString DocDir;
 
 ImIconProvider::ImIconProvider()
@@ -69,7 +70,7 @@ ImIconProvider::ImIconProvider()
 	fmts.reserve(arraySize);
 	for (size_t i = 0; i < arraySize; ++i)
 		fmts.append(tmp[i]);
-	IconManager& im=IconManager::instance();
+	IconManager& im = IconManager::instance();
 	imagepm = im.loadIcon("16/image-x-generic.png");
 	pspm = im.loadIcon("postscript.png");
 	txtpm = im.loadIcon("txt.png");
@@ -134,7 +135,7 @@ void FDialogPreview::genPreview(const QString& name)
 	updatePix();
 	if (name.isEmpty())
 		return;
-	QFileInfo fi = QFileInfo(name);
+	QFileInfo fi(name);
 	if (fi.isDir())
 		return;
 	int w = pixmap()->width();
@@ -174,22 +175,22 @@ void FDialogPreview::genPreview(const QString& name)
 		QString tmp2;
 		QImage im2 = im.scaled(w - 5, h - 44, Qt::KeepAspectRatio, Qt::SmoothTransformation);
 		QPainter p;
-		QBrush b(QColor(205,205,205), IconManager::instance().loadPixmap("testfill.png"));
+		QBrush b(QColor(205, 205, 205), IconManager::instance().loadPixmap("testfill.png"));
 		// Qt4 FIXME imho should be better
 		pm = *pixmap();
 		p.begin(&pm);
-		p.fillRect(0, 0, w, h-44, b);
-		p.fillRect(0, h-44, w, 44, QColor(255, 255, 255));
+		p.fillRect(0, 0, w, h - 44, b);
+		p.fillRect(0, h - 44, w, 44, QColor(255, 255, 255));
 		p.drawImage((w - im2.width()) / 2, (h - 44 - im2.height()) / 2, im2);
-		p.drawText(2, h-29, tr("Size:")+" "+tmp.setNum(ix)+" x "+tmp2.setNum(iy));
+		p.drawText(2, h - 29, tr("Size:") + " " + tmp.setNum(ix) + " x " + tmp2.setNum(iy));
 		if (!(extensionIndicatesPDF(ext) || extensionIndicatesEPSorPS(ext)))
-			p.drawText(2, h-17, tr("Resolution:")+" "+tmp.setNum(xres)+" x "+tmp2.setNum(yres)+" "+ tr("DPI"));
+			p.drawText(2, h - 17, tr("Resolution:") + " " + tmp.setNum(xres) + " x " + tmp2.setNum(yres) + " " + tr("DPI"));
 		QString cSpace;
 		if ((extensionIndicatesPDF(ext) || extensionIndicatesEPSorPS(ext)) && (im.imgInfo.type != ImageType7))
 			cSpace = tr("Unknown");
 		else
-			cSpace=colorSpaceText(im.imgInfo.colorspace);
-		p.drawText(2, h-5, tr("Colorspace:")+" "+cSpace);
+			cSpace = colorSpaceText(im.imgInfo.colorspace);
+		p.drawText(2, h - 5, tr("Colorspace:") + " " + cSpace);
 		p.end();
 		setPixmap(pm);
 		repaint();
@@ -213,13 +214,13 @@ void FDialogPreview::genPreview(const QString& name)
 		desc += value2String(im.text("YSize").toDouble(), PrefsManager::instance().appPrefs.docSetupPrefs.docUnitIndex, true, true);
 		im = im.scaled(w - 5, h - 21, Qt::KeepAspectRatio, Qt::SmoothTransformation);
 		QPainter p;
-		QBrush b(QColor(205,205,205), IconManager::instance().loadPixmap("testfill.png"));
+		QBrush b(QColor(205, 205, 205), IconManager::instance().loadPixmap("testfill.png"));
 		pm = *pixmap();
 		p.begin(&pm);
-		p.fillRect(0, 0, w, h-21, b);
-		p.fillRect(0, h-21, w, 21, QColor(255, 255, 255));
+		p.fillRect(0, 0, w, h - 21, b);
+		p.fillRect(0, h - 21, w, 21, QColor(255, 255, 255));
 		p.drawImage((w - im.width()) / 2, (h - 21 - im.height()) / 2, im);
-		p.drawText(2, h-5, desc);
+		p.drawText(2, h - 5, desc);
 		p.end();
 		setPixmap(pm);
 		repaint();
@@ -238,14 +239,14 @@ void FDialogPreview::genPreview(const QString& name)
 		QImage im = pre->createPreview(f);
 		im = im.scaled(w - 5, h - 21, Qt::KeepAspectRatio, Qt::SmoothTransformation);
 		QPainter p;
-		QBrush b(QColor(205,205,205), IconManager::instance().loadPixmap("testfill.png"));
+		QBrush b(QColor(205, 205, 205), IconManager::instance().loadPixmap("testfill.png"));
 		pm = *pixmap();
 		p.begin(&pm);
-		p.fillRect(0, 0, w, h-21, b);
-		p.fillRect(0, h-21, w, 21, QColor(255, 255, 255));
+		p.fillRect(0, 0, w, h - 21, b);
+		p.fillRect(0, h - 21, w, 21, QColor(255, 255, 255));
 		p.drawImage((w - im.width()) / 2, (h - 21 - im.height()) / 2, im);
-		QString desc = tr("Size:")+QString(" %1 x %2").arg(im.width()).arg(im.height());
-		p.drawText(2, h-5, desc);
+		QString desc = tr("Size:") + QString(" %1 x %2").arg(im.width()).arg(im.height());
+		p.drawText(2, h - 5, desc);
 		p.end();
 		setPixmap(pm);
 		repaint();
@@ -260,18 +261,18 @@ void FDialogPreview::genPreview(const QString& name)
 			QString ti2 = slaInfos.title();
 			if (ti2.isEmpty())
 				ti2= tr("No Title");
-			Title += ti2+"\n";
+			Title += ti2 + "\n";
 			QString Author = tr("Author:")+" ";
 			QString au2 = slaInfos.author();
 			if (au2.isEmpty())
 				au2 = tr("Unknown");
-			Author += au2+"\n";
+			Author += au2 + "\n";
 			QString Format =  tr("File Format:")+" ";
 			QString fm2 = slaInfos.format();
 			if (fm2.isEmpty())
 				fm2 = tr("Unknown");
 			Format += fm2;
-			setText( tr("Scribus Document")+"\n\n"+Title+Author+Format);
+			setText( tr("Scribus Document") + "\n\n" + Title + Author + Format);
 		}
 		else  if ((ext == "txt") || (ext == "html") || (ext == "xml"))
 		{
@@ -282,8 +283,12 @@ void FDialogPreview::genPreview(const QString& name)
 }
 
 CustomFDialog::CustomFDialog(QWidget *parent, const QString& wDir, const QString& caption, const QString& filter, int flags)
-			: QDialog(parent), m_optionFlags(flags)
+			: QDialog(parent),
+	          m_optionFlags(flags),
+	          m_previewIsShown(true)
 {
+	m_fileDialogPrefs = PrefsManager::instance().prefsFile->getContext("customfdialog", false);
+
 	setModal(true);
 	setWindowTitle(caption);
 	setWindowIcon(IconManager::instance().loadIcon("AppIcon.png"));
@@ -316,7 +321,6 @@ CustomFDialog::CustomFDialog(QWidget *parent, const QString& wDir, const QString
 	showPreview->setText( tr("Show Preview"));
 	showPreview->setToolTip( tr("Show a preview and information for the selected file"));
 	showPreview->setChecked(true);
-	m_previewIsShown = true;
 	hboxLayout1->addWidget(showPreview);
 	QSpacerItem *spacerItem = new QSpacerItem(2, 2, QSizePolicy::Expanding, QSizePolicy::Minimum);
 	hboxLayout1->addItem(spacerItem);
@@ -487,8 +491,46 @@ CustomFDialog::CustomFDialog(QWidget *parent, const QString& wDir, const QString
 	resize(minimumSizeHint());
 }
 
-CustomFDialog::~CustomFDialog()
+void CustomFDialog::closeEvent(QCloseEvent *closeEvent)
 {
+	storeSize();
+	QDialog::closeEvent(closeEvent);
+}
+
+void CustomFDialog::hideEvent(QHideEvent* hideEvent)
+{
+	storeSize();
+	QDialog::hideEvent(hideEvent);
+}
+
+void CustomFDialog::showEvent(QShowEvent *showEvent)
+{
+	const QScreen* dialogScreen = this->screen();
+	if (m_fileDialogPrefs && dialogScreen && !showEvent->spontaneous())
+	{
+		if (m_fileDialogPrefs->contains("width"))
+		{
+			QRect scr = dialogScreen->availableGeometry();
+			int fdWidth  = qMax(0, qMin(m_fileDialogPrefs->getInt("width"), scr.width()));
+			int fdHeight = qMax(0, qMin(m_fileDialogPrefs->getInt("height"), scr.height()));
+			if (fdWidth > 0 && fdHeight > 0)
+			{
+				int newWidth = qMax(0, qMin(this->width() + fdWidth - fileDialog->width(), scr.width()));
+				int newHeight = qMax(0, qMin(this->height() + fdHeight - fileDialog->height(), scr.height()));
+				if (newWidth > 0 && newHeight > 0)
+					resize(newWidth, newHeight);
+			}
+		}
+	}
+	QDialog::showEvent(showEvent);
+}
+
+void CustomFDialog::storeSize()
+{
+	if (!m_fileDialogPrefs)
+		return;
+	m_fileDialogPrefs->set("width",  fileDialog->width());
+	m_fileDialogPrefs->set("height", fileDialog->height());
 }
 
 void CustomFDialog::fileClicked(const QString &path)
@@ -523,12 +565,12 @@ void CustomFDialog::togglePreview()
 			filePreview->genPreview(QDir::fromNativeSeparators(sel[0]));
 	}
 	// #11856: Hack to avoid file dialog widget turning black with Qt5
-	qApp->processEvents();
+	QCoreApplication::processEvents();
 	filePreview->setVisible(!m_previewIsShown);
-	qApp->processEvents();
+	QCoreApplication::processEvents();
 	filePreview->setVisible(m_previewIsShown);
 	fileDialog->repaint();
-	qApp->processEvents();
+	QCoreApplication::processEvents();
 	repaint();
 }
 
