@@ -20,32 +20,35 @@ class QEvent;
 class SCRIBUS_API DirectionSelect : public QWidget
 {
 	Q_OBJECT
-public:
-        DirectionSelect(QWidget* parent);
-        ~DirectionSelect() {};
-        void setStyle(int s);
-        int getStyle();
-        int selectedId();
 
-        virtual void changeEvent(QEvent *e);
+	public:
+		DirectionSelect(QWidget* parent);
+		~DirectionSelect() {};
 
-        QButtonGroup* buttonGroup;
-        int selected;
-        QToolButton* RTL;
-        QToolButton* LTR;
+		void setStyle(int s);
+		int getStyle();
+		int selectedId();
 
+		QButtonGroup* buttonGroup { nullptr };
+		QToolButton* RTL { nullptr };
+		QToolButton* LTR { nullptr };
 
-public slots:
-        void languageChange();
+	public slots:
+		void iconSetChange();
+		void languageChange();
 
-private slots:
-        void setTypeStyle(int a);
+	protected:
+		QHBoxLayout* groupSelectLayout { nullptr };
 
-signals:
-        void State(int);
+		int m_selected { 0 };
 
-protected:
-        QHBoxLayout* GroupSelectLayout;
+		void changeEvent(QEvent *e) override;
+
+	private slots:
+		void setTypeStyle(int a);
+
+	signals:
+		void State(int);
 };
 
 #endif // DIRECTIONSELECT_H
