@@ -90,7 +90,7 @@ void GradientPreview::paintEvent(QPaintEvent *e)
 	ScPainter *p = new ScPainter(&pixm, width() - 20, 37);
 //	p->clear(Qt::white);
 	p->setPen(Qt::black, 1, Qt::SolidLine, Qt::FlatCap, Qt::MiterJoin);
-	p->setFillMode(2);
+	p->setFillMode(ScPainter::Gradient);
 	p->fill_gradient = fill_gradient;
 	p->setGradient(VGradient::linear, FPoint(0, 20), FPoint(width() - 20, 20), FPoint(0, 0), 1.0, 0.0);
 	p->drawRect(0, 0, width() - 20, 37);
