@@ -54,7 +54,7 @@ for which a new license (GPL+exception) is in place.
 #include <QTextEdit>
 #include <QTreeView>
 #include <QVector>
-#include <QXmlDefaultHandler>
+#include <QXmlStreamReader>
 
 #include "prefsmanager.h"
 #include "scribuscore.h"
@@ -62,75 +62,97 @@ for which a new license (GPL+exception) is in place.
 #include "iconmanager.h"
 #include "util.h"
 
-/*! \brief XML parsef for documantation history.
+/*! \brief XML parsed for documentation history.
 This is small helper class which reads saved bookmarks configuration
 from ~/.scribus/doc/history.xml file.
 The reference to historyBrowser is a reference to the dialog.
 \author Petr Vanek <petr@yarpen.cz>
 */
-class HistoryParser2 : public QXmlDefaultHandler
+class HistoryParser2
 {
 	public:
-		HelpBrowser *helpBrowser;
+		HelpBrowser *helpBrowser { nullptr };
 
-		bool startDocument()
+		bool parse(const QString& fileName)
 		{
-			return true;
-		}
+			QFile qFile(fileName);
+			if (!qFile.open(QFile::ReadOnly))
+				return false;
 
-		bool startElement(const QString&, const QString&, const QString& qName, const QXmlAttributes& attrs)
-		{
-			if (qName == "item")
+			QXmlStreamReader sReader(&qFile);
+			QXmlStreamReader::TokenType tagType;
+			QStringRef tagName;
+
+			while (!sReader.atEnd() && !sReader.hasError())
 			{
+				tagType = sReader.readNext();
+				if (tagType != QXmlStreamReader::StartElement)
+					continue;
+
+				tagName = sReader.name();
+				if (tagName != "item")
+					continue;
+
 				struct histd2 his;
-				his.title = attrs.value(0);
-				his.url = attrs.value(1);
+				QXmlStreamAttributes attrs = sReader.attributes();
+				his.title = attrs.value(QLatin1String("title")).toString();
+				his.url = attrs.value(QLatin1String("url")).toString();
 				helpBrowser->addHistoryItem(his);
 			}
-			return true;
-		}
+			qFile.close();
 
-		bool endElement(const QString&, const QString&, const QString&)
-		{
-			return true;
+			return (!sReader.hasError());
 		}
 };
 
-/*! \brief XML parsef for documantation bookmarks.
+/*! \brief XML parsed for documentation bookmarks.
 This is small helper class which reads saved bookmarks configuration
 from ~/.scribus/doc/bookmarks.xml file.
 The reference to QListView *view is a reference to the list view with bookmarks
 \author Petr Vanek <petr@yarpen.cz>
 */
-class BookmarkParser2 : public QXmlDefaultHandler
+class BookmarkParser2
 {
 	public:
-		QTreeWidget* view;
-		QMap<QString, QString>* quickHelpIndex;
-		QMap<QString, QPair<QString, QString> >* bookmarkIndex;
+		QTreeWidget* view { nullptr };
+		QMap<QString, QString>* quickHelpIndex { nullptr };
+		QMap<QString, QPair<QString, QString> >* bookmarkIndex { nullptr };
 
-		bool startDocument()
+		bool parse(const QString& fileName)
 		{
-			return true;
-		}
+			QFile qFile(fileName);
+			if (!qFile.open(QFile::ReadOnly))
+				return false;
 
-		bool startElement(const QString&, const QString&, const QString& qName, const QXmlAttributes& attrs)
-		{
-			if (qName == "item")
+			QXmlStreamReader sReader(&qFile);
+			QXmlStreamReader::TokenType tagType;
+			QStringRef tagName;
+
+			while (!sReader.atEnd() && !sReader.hasError())
 			{
+				tagType = sReader.readNext();
+				if (tagType != QXmlStreamReader::StartElement)
+					continue;
+
+				tagName = sReader.name();
+				if (tagName != "item")
+					continue;
+
+				QXmlStreamAttributes attrs = sReader.attributes();
+				QString title = attrs.value(QLatin1String("title")).toString();
+				QString pageTitle = attrs.value(QLatin1String("pagetitle")).toString();
+				QString pageUrl = attrs.value(QLatin1String("url")).toString();
+
 				//TODO : This will dump items if bookmarks get loaded into a different GUI language
-				if (quickHelpIndex->contains(attrs.value(1)))
+				if (quickHelpIndex->contains(pageTitle))
 				{
-					bookmarkIndex->insert(attrs.value(0), qMakePair(attrs.value(1), attrs.value(2)));
-					view->addTopLevelItem(new QTreeWidgetItem(view, QStringList() << attrs.value(0)));
+					bookmarkIndex->insert(title, qMakePair(pageTitle, pageUrl));
+					view->addTopLevelItem(new QTreeWidgetItem(view, QStringList() << title));
 				}
 			}
-			return true;
-		}
+			qFile.close();
 
-		bool endElement(const QString&, const QString&, const QString&)
-		{
-			return true;
+			return (!sReader.hasError());
 		}
 };
 
@@ -213,7 +235,7 @@ void HelpBrowser::closeEvent(QCloseEvent * event)
 		stream.setCodec("UTF-8");
 		stream << "<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n";
 		stream << "<history>\n";
-		for (QMap<QAction*,histd2>::Iterator it = m_history.begin() ; it != m_history.end(); ++it)
+		for (auto it = m_history.cbegin() ; it != m_history.cend(); ++it)
 			stream << "\t<item title=\"" << it.value().title << "\" url=\"" << it.value().url << "\" />\n";
 		stream << "</history>\n";
 		histFile.close();
@@ -227,7 +249,9 @@ void HelpBrowser::closeEvent(QCloseEvent * event)
 
 void HelpBrowser::setupLocalUI()
 {
-	setWindowIcon(IconManager::instance().loadIcon("AppIcon.png"));
+	IconManager& iconManager = IconManager::instance();
+
+	setWindowIcon(iconManager.loadIcon("AppIcon.png"));
 	//Add Menus
 	fileMenu = menuBar()->addMenu("");
 	editMenu = menuBar()->addMenu("");
@@ -235,10 +259,10 @@ void HelpBrowser::setupLocalUI()
 	histMenu = new QMenu(this);
 
 	//Add Menu items
-	filePrint = fileMenu->addAction(IconManager::instance().loadIcon("16/document-print.png"), "", this, SLOT(print()), Qt::CTRL+Qt::Key_P);
+	filePrint = fileMenu->addAction(iconManager.loadIcon("16/document-print.png"), "", this, SLOT(print()), Qt::CTRL+Qt::Key_P);
 	fileMenu->addSeparator();
-	fileExit = fileMenu->addAction(IconManager::instance().loadIcon("exit.png"), "", this, SLOT(close()), Qt::CTRL+Qt::Key_W);
-	editFind = editMenu->addAction(IconManager::instance().loadIcon("find.png"), "", this, SLOT(find()), Qt::CTRL+Qt::Key_F);
+	fileExit = fileMenu->addAction(iconManager.loadIcon("exit.png"), "", this, SLOT(close()), Qt::CTRL+Qt::Key_W);
+	editFind = editMenu->addAction(iconManager.loadIcon("find.png"), "", this, SLOT(find()), Qt::CTRL+Qt::Key_F);
 	editFindNext = editMenu->addAction( "", this, SLOT(findNext()), Qt::Key_F3);
 	editFindPrev = editMenu->addAction( "", this, SLOT(findPrevious()), Qt::SHIFT+Qt::Key_F3);
 	bookAdd = bookMenu->addAction( "", this, SLOT(bookmarkButton_clicked()), Qt::CTRL+Qt::Key_D);
@@ -246,9 +270,9 @@ void HelpBrowser::setupLocalUI()
 	bookDelAll = bookMenu->addAction( "", this, SLOT(deleteAllBookmarkButton_clicked()));
 
 	//Add Toolbar items
-	goHome = toolBar->addAction(IconManager::instance().loadIcon("16/go-home.png"), "", textBrowser, SLOT(home()));
-	goBack = toolBar->addAction(IconManager::instance().loadIcon("16/go-previous.png"), "", textBrowser, SLOT(backward()));
-	goFwd = toolBar->addAction(IconManager::instance().loadIcon("16/go-next.png"), "", textBrowser, SLOT(forward()));
+	goHome = toolBar->addAction(iconManager.loadIcon("16/go-home.png"), "", textBrowser, SLOT(home()));
+	goBack = toolBar->addAction(iconManager.loadIcon("16/go-previous.png"), "", textBrowser, SLOT(backward()));
+	goFwd = toolBar->addAction(iconManager.loadIcon("16/go-next.png"), "", textBrowser, SLOT(forward()));
 	goBack->setMenu(histMenu);
 	
 	helpNav->listView->header()->hide();
@@ -367,8 +391,8 @@ void HelpBrowser::searchingInDirectory(const QString& aDir)
 	QDir dir(QDir::toNativeSeparators(aDir + "/"));
 	QStringList in;
 	in.append("*.html");
-	QStringList lst = dir.entryList(in);
-	for (QStringList::Iterator it = lst.begin(); it != lst.end(); ++it)
+	QStringList dirEntries = dir.entryList(in);
+	for (auto it = dirEntries.cbegin(); it != dirEntries.cend(); ++it)
 	{
 		QString fname(aDir + "/" + (*it));
 		QFile f(fname);
@@ -395,9 +419,12 @@ void HelpBrowser::searchingInDirectory(const QString& aDir)
 	in.clear();
 	in.append("*");
 	QStringList dst = dir.entryList(in, QDir::Dirs);
-	for (QStringList::Iterator it = dst.begin(); it != dst.end(); ++it)
-		if ((*it)!="." && (*it)!="..")
-			searchingInDirectory(QDir::toNativeSeparators(aDir + QString((*it)) + "/"));
+	for (auto it = dst.cbegin(); it != dst.cend(); ++it)
+	{
+		if ((*it) == "." || (*it) == "..")
+			continue;
+		searchingInDirectory(QDir::toNativeSeparators(aDir + QString((*it)) + "/"));
+	}
 }
 
 void HelpBrowser::find()
@@ -580,7 +607,7 @@ void HelpBrowser::loadMenu()
 	helpMenuFiles.append(qMakePair(installHelpDir, m_language));
 	if (!m_language.isEmpty())
 	{
-		QStringList langDecomp = m_language.split(QChar('_'), QString::SkipEmptyParts);
+		QStringList langDecomp = m_language.split(QChar('_'), Qt::SkipEmptyParts);
 		QString altLanguage = langDecomp.first();
 		helpMenuFiles.append(qMakePair(baseHelpDir, altLanguage));
 		helpMenuFiles.append(qMakePair(installHelpDir, altLanguage));
@@ -589,7 +616,7 @@ void HelpBrowser::loadMenu()
 	helpMenuFiles.append(qMakePair(baseHelpDir, enLanguage));
 	helpMenuFiles.append(qMakePair(installHelpDir, enLanguage));
 
-	QString toLoad;;
+	QString toLoad;
 	for (int i = 0; i < helpMenuFiles.count(); ++i)
 	{
 		auto helpPair = helpMenuFiles.at(i);
@@ -613,7 +640,8 @@ void HelpBrowser::loadMenu()
 	QFileInfo baseFi = QFileInfo(toLoad);
 	m_finalBaseDir = baseFi.path();
 	QStringList searchPaths;
-	searchPaths << m_finalBaseDir << m_defaultBaseDir;
+	searchPaths << m_finalBaseDir;
+	searchPaths << m_defaultBaseDir;
 	textBrowser->setSearchPaths(searchPaths);
 
 	delete m_menuModel;
@@ -635,26 +663,18 @@ void HelpBrowser::loadMenu()
 
 void HelpBrowser::readBookmarks()
 {
-	BookmarkParser2 handler;
-	handler.view = helpNav->bookmarksView;
-	handler.quickHelpIndex = &m_quickHelpIndex;
-	handler.bookmarkIndex = &m_bookmarkIndex;
-	QFile xmlFile(bookmarkFile());
-	QXmlInputSource source(&xmlFile);
-	QXmlSimpleReader reader;
-	reader.setContentHandler(&handler);
-	reader.parse(source);
+	BookmarkParser2 bookmarkParser;
+	bookmarkParser.view = helpNav->bookmarksView;
+	bookmarkParser.quickHelpIndex = &m_quickHelpIndex;
+	bookmarkParser.bookmarkIndex = &m_bookmarkIndex;
+	bookmarkParser.parse(bookmarkFile());
 }
 
 void HelpBrowser::readHistory()
 {
- 	HistoryParser2 handler;
- 	handler.helpBrowser = this;
- 	QFile xmlFile(historyFile());
- 	QXmlInputSource source(&xmlFile);
- 	QXmlSimpleReader reader;
- 	reader.setContentHandler(&handler);
- 	reader.parse(source);
+ 	HistoryParser2 historyParser;
+ 	historyParser.helpBrowser = this;
+	historyParser.parse(historyFile());
 }
 
 void HelpBrowser::itemSelected(const QItemSelection & selected, const QItemSelection & deselected)
