@@ -21,6 +21,11 @@ for which a new license (GPL+exception) is in place.
 
 #include "scribusapi.h"
 
+#include <QDialog>
+#include <QMap>
+#include <QString>
+#include <QStringList>
+class QCheckBox;
 class QEvent;
 class QGridLayout;
 class QHBoxLayout;
@@ -28,9 +33,6 @@ class QLabel;
 class QPushButton;
 class QSpacerItem;
 class QSpinBox;
-class QCheckBox;
-class QString;
-class QStringList;
 class QTreeWidget;
 class QVBoxLayout;
 
@@ -69,7 +71,7 @@ public:
 
 /*! \brief This module provides simple interface to the various Lorem Ipsum variants.
 Scribus LI are stored in the set of XML files.
-The file has followind structure:
+The file has the following structure:
 \<?xml version="1.0" encoding="utf8"?\>
 \<lorem\>
 \<name\>name to display\</name\>
