@@ -265,8 +265,9 @@ void OutputPreview_PDF::cleanupTemporaryFiles()
 QPixmap OutputPreview_PDF::createPreview(int pageIndex, int res)
 {
 	int ret = -1;
-	double w = m_doc->Pages->at(pageIndex)->width() * res / 72.0;
-	double h = m_doc->Pages->at(pageIndex)->height() * res / 72.0;
+	int gsRes = qRound(res * devicePixelRatioF());
+	int w = qRound(m_doc->Pages->at(pageIndex)->width() * gsRes / 72.0);
+	int h = qRound(m_doc->Pages->at(pageIndex)->height() * gsRes / 72.0);
 
 	qApp->setOverrideCursor(QCursor(Qt::WaitCursor));
 
@@ -284,9 +285,9 @@ QPixmap OutputPreview_PDF::createPreview(int pageIndex, int res)
 	if (optionsHaveChanged(pageIndex))
 	{
 		if (m_optionsUi->enableCMYK->isChecked() && m_haveTiffSep)
-			ret = renderPreviewSep(pageIndex, res);
+			ret = renderPreviewSep(pageIndex, gsRes);
 		else
-			ret = renderPreview(pageIndex, res);
+			ret = renderPreview(pageIndex, gsRes);
 		if (ret > 0)
 		{
 			imageLoadError(pixmap);
@@ -302,8 +303,8 @@ QPixmap OutputPreview_PDF::createPreview(int pageIndex, int res)
 
 		ScImage im;
 		bool mode;
-		int w2 = qRound(w);
-		int h2 = qRound(h);
+		int w2 = w;
+		int h2 = h;
 		image = QImage(w2, h2, QImage::Format_ARGB32);
 		image.fill(qRgba(0, 0, 0, 0));
 		
@@ -499,9 +500,11 @@ QPixmap OutputPreview_PDF::createPreview(int pageIndex, int res)
 		}
 	}
 
+	image.setDevicePixelRatio(devicePixelRatioF());
 	if (m_optionsUi->showTransparency->isChecked())
 	{
 		pixmap = QPixmap(image.width(), image.height());
+		pixmap.setDevicePixelRatio(devicePixelRatioF());
 		QPainter p;
 		QBrush b(QColor(205,205,205), IconManager::instance().loadPixmap("testfill.png"));
 		p.begin(&pixmap);
@@ -511,6 +514,7 @@ QPixmap OutputPreview_PDF::createPreview(int pageIndex, int res)
 	}
 	else
 		pixmap = QPixmap::fromImage(image);
+	pixmap.setDevicePixelRatio(devicePixelRatioF());
 
 	qApp->restoreOverrideCursor();
 	updateOptionsFromUI();
@@ -576,13 +580,14 @@ int OutputPreview_PDF::renderPreview(int pageIndex, int res)
 
 	QStringList args;
 	QString tmp, tmp2, tmp3;
-	double w = m_doc->Pages->at(pageIndex)->width() * res / 72.0;
-	double h = m_doc->Pages->at(pageIndex)->height() * res / 72.0;
+	int w = qRound(m_doc->Pages->at(pageIndex)->width() * res / 72.0);
+	int h = qRound(m_doc->Pages->at(pageIndex)->height() * res / 72.0);
+	
 	args.append( "-q" );
 	args.append( "-dNOPAUSE" );
 	args.append( "-dPARANOIDSAFER" );
 	args.append( QString("-r%1").arg(tmp.setNum(res)) );
-	args.append( QString("-g%1x%2").arg(tmp2.setNum(qRound(w)), tmp3.setNum(qRound(h))) );
+	args.append( QString("-g%1x%2").arg(tmp2.setNum(w), tmp3.setNum(h)) );
 	if (m_optionsUi->enableCMYK->isChecked())
 	{
 		if (!m_haveTiffSep)
@@ -653,14 +658,14 @@ int OutputPreview_PDF::renderPreviewSep(int pageIndex, int res)
 	QStringList args, args1, args2, args3;
 
 	QString tmp, tmp2, tmp3;
-	double w = m_doc->Pages->at(pageIndex)->width() * res / 72.0;
-	double h = m_doc->Pages->at(pageIndex)->height() * res / 72.0;
+	int w = qRound(m_doc->Pages->at(pageIndex)->width() * res / 72.0);
+	int h = qRound(m_doc->Pages->at(pageIndex)->height() * res / 72.0);
 
 	args1.append( "-q" );
 	args1.append( "-dNOPAUSE" );
 	args1.append( "-dPARANOIDSAFER" );
 	args1.append( QString("-r%1").arg(tmp.setNum(res)) );
-	args1.append( QString("-g%1x%2").arg(tmp2.setNum(qRound(w)), tmp3.setNum(qRound(h))) );
+	args1.append( QString("-g%1x%2").arg(tmp2.setNum(w), tmp3.setNum(h)) );
 	if (m_optionsUi->antiAliasing->isChecked())
 	{
 		args1.append("-dTextAlphaBits=4");
@@ -884,7 +889,7 @@ bool OutputPreview_PDF::optionsHaveChanged(int pageIndex) const
 {
 	if (m_currentPage != pageIndex)
 		return true;
-	if (m_scaleFactor != m_uiBase->scaleBox->currentIndex())
+	if (m_scaleMode != m_uiBase->scaleBox->currentIndex())
 		return true;
 	if (m_cmykPreviewMode != m_optionsUi->enableCMYK->isChecked())
 		return true;
@@ -1050,7 +1055,7 @@ void OutputPreview_PDF::updateOptionsFromUI()
 	m_convertSpots = m_optionsUi->convertSpots->isChecked();
 
 	m_currentPage = m_uiBase->pageSelector->getCurrentPage() - 1;
-	m_scaleFactor = m_uiBase->scaleBox->currentIndex();
+	m_scaleMode = m_uiBase->scaleBox->currentIndex();
 	m_cmykPreviewMode = m_optionsUi->enableCMYK->isChecked();
 	m_useAntialiasing = m_optionsUi->antiAliasing->isChecked();
 	m_showTransparency = m_optionsUi->showTransparency->isChecked();
