@@ -20,7 +20,7 @@ class SCRIBUS_API Prefs_Display : public Prefs_Pane, Ui::Prefs_Display
 
 	public:
 		Prefs_Display(QWidget* parent, ScribusDoc* doc=nullptr);
-		~Prefs_Display();
+		~Prefs_Display() = default;
 
 		void restoreDefaults(struct ApplicationPrefs *prefsData) override;
 		void saveGuiToPrefs(struct ApplicationPrefs *prefsData) const override;
