@@ -24,7 +24,7 @@ for which a new license (GPL+exception) is in place.
 
 Prefs_DocumentSetup::Prefs_DocumentSetup(QWidget* parent, ScribusDoc* doc)
 	: Prefs_Pane(parent),
-	m_doc(doc)
+	  m_doc(doc)
 {
 	setupUi(this);
 	
@@ -34,9 +34,6 @@ Prefs_DocumentSetup::Prefs_DocumentSetup(QWidget* parent, ScribusDoc* doc)
 	m_caption = tr("Document Setup");
 	m_icon = "scribusdoc16.png";
 
-	unitRatio = 1.0;
-	pageW = pageH = 1.0;
-
 	if (!m_doc)
 	{
 		applySizesToAllPagesCheckBox->hide();
@@ -81,10 +78,6 @@ Prefs_DocumentSetup::Prefs_DocumentSetup(QWidget* parent, ScribusDoc* doc)
 	connect(changeAutoDir, SIGNAL(clicked()), this, SLOT(changeAutoDocDir()));
 }
 
-Prefs_DocumentSetup::~Prefs_DocumentSetup()
-{
-}
-
 void Prefs_DocumentSetup::unitChange()
 {
 	pageWidthSpinBox->blockSignals(true);
@@ -132,7 +125,7 @@ void Prefs_DocumentSetup::languageChange()
 	pageSizeLinkToolButton->setToolTip( "<qt>" + tr( "Enable or disable more page sizes by jumping to Page Size preferences" ) + "</qt>" );
 	pageOrientationComboBox->setToolTip( "<qt>" + tr( "Default orientation of document pages" ) + "</qt>" );
 	pageUnitsComboBox->setToolTip( "<qt>" + tr( "Default unit of measurement for document editing" ) + "</qt>" );
-	autosaveCheckBox->setToolTip( "<qt>" + tr( "When enabled, Scribus saves backup copys of your file each time the time period elapses" ) + "</qt>" );
+	autosaveCheckBox->setToolTip( "<qt>" + tr( "When enabled, Scribus saves backup copies of your file each time the time period elapses" ) + "</qt>" );
 	autosaveIntervalSpinBox->setToolTip( "<qt>" + tr( "Time period between saving automatically" ) + "</qt>" );
 	undoLengthSpinBox->setToolTip( "<qt>" + tr("Set the length of the action history in steps. If set to 0 infinite amount of actions will be stored.") + "</qt>");
 	applySizesToAllPagesCheckBox->setToolTip( "<qt>" + tr( "Apply the page size changes to all existing pages in the document" ) + "</qt>" );
@@ -321,7 +314,7 @@ void Prefs_DocumentSetup::setupPageSizes(struct ApplicationPrefs *prefsData)
 void Prefs_DocumentSetup::pageLayoutChanged(int i)
 {
 	setupPageSets();
-	marginsWidget->setFacingPages(!(i == singlePage));
+	marginsWidget->setFacingPages(i != singlePage);
 	//layoutFirstPageIsComboBox->setCurrentIndex(pageSets[pageLayoutButtonGroup->checkedId()].FirstPage);
 }
 
@@ -383,16 +376,17 @@ void Prefs_DocumentSetup::setSize(const QString &newSize)
 {
 	pageW = pageWidthSpinBox->value() / unitRatio;
 	pageH = pageHeightSpinBox->value() / unitRatio;
-	PageSize *ps2=new PageSize(newSize);
 
-	prefsPageSizeName=ps2->name();
+	PageSize ps2(newSize);
+	prefsPageSizeName = ps2.name();
 	if (newSize != CommonStrings::trCustomPageSize)
 	{
-		pageW = ps2->width();
-		pageH = ps2->height();
+		pageW = ps2.width();
+		pageH = ps2.height();
 	}
 	else
 		prefsPageSizeName = CommonStrings::customPageSize;
+
 	pageWidthSpinBox->blockSignals(true);
 	pageHeightSpinBox->blockSignals(true);
 	pageWidthSpinBox->setValue(pageW * unitRatio);
@@ -402,7 +396,6 @@ void Prefs_DocumentSetup::setSize(const QString &newSize)
 	marginsWidget->setPageSize(newSize);
 	pageWidthSpinBox->blockSignals(false);
 	pageHeightSpinBox->blockSignals(false);
-	delete ps2;
 }
 
 void Prefs_DocumentSetup::slotUndo(bool isEnabled)
