@@ -12,7 +12,7 @@ for which a new license (GPL+exception) is in place.
 #include "prefsstructs.h"
 #include "scribusdoc.h"
 
-Prefs_ImageCache::Prefs_ImageCache(QWidget* parent, ScribusDoc* doc)
+Prefs_ImageCache::Prefs_ImageCache(QWidget* parent, ScribusDoc* /*doc*/)
 	: Prefs_Pane(parent)
 {
 	setupUi(this);
@@ -22,8 +22,6 @@ Prefs_ImageCache::Prefs_ImageCache(QWidget* parent, ScribusDoc* doc)
 	m_icon = "16/image-x-generic.png";
 }
 
-Prefs_ImageCache::~Prefs_ImageCache() = default;
-
 void Prefs_ImageCache::languageChange()
 {
 	enableImageCacheCheckBox->setToolTip( "<qt>" + tr( "Enabling the image cache will significantly speed up the loading of images. Enable the cache if you are often working on large documents with lots of images and if you have plenty of disk space in your application data directory." ) + "</qt>" );
