@@ -12,7 +12,7 @@ for which a new license (GPL+exception) is in place.
 #include "prefsstructs.h"
 #include "scribusdoc.h"
 
-Prefs_Paths::Prefs_Paths(QWidget* parent, ScribusDoc* doc)
+Prefs_Paths::Prefs_Paths(QWidget* parent, ScribusDoc* /*doc*/)
 	: Prefs_Pane(parent)
 {
 	setupUi(this);
