@@ -19,8 +19,10 @@ class SCRIBUS_API Prefs_Printer : public Prefs_Pane, Ui::Prefs_Printer
 	public:
 		Prefs_Printer(QWidget* parent, ScribusDoc* doc=nullptr);
 		~Prefs_Printer();
-		virtual void restoreDefaults(struct ApplicationPrefs *prefsData);
-		virtual void saveGuiToPrefs(struct ApplicationPrefs *prefsData) const;
+
+		void restoreDefaults(struct ApplicationPrefs *prefsData) override;
+		void saveGuiToPrefs(struct ApplicationPrefs *prefsData) const override;
+
 	public slots:
 		void languageChange();
 		void unitChange(int newIndex);
