@@ -17,15 +17,14 @@ class ScribusDoc;
 
 class SCRIBUS_API Prefs_Spelling : public Prefs_Pane, Ui::Prefs_Spelling
 {
-
-
 	Q_OBJECT
 
 	public:
 		Prefs_Spelling(QWidget* parent, ScribusDoc* doc=nullptr);
 		~Prefs_Spelling();
-		virtual void restoreDefaults(struct ApplicationPrefs *prefsData);
-		virtual void saveGuiToPrefs(struct ApplicationPrefs *prefsData) const;
+
+		void restoreDefaults(struct ApplicationPrefs *prefsData) override;
+		void saveGuiToPrefs(struct ApplicationPrefs *prefsData) const override;
 
 	public slots:
 		void languageChange();
@@ -39,9 +38,10 @@ class SCRIBUS_API Prefs_Spelling : public Prefs_Pane, Ui::Prefs_Spelling
 		void updateProgressBar();
 
 	protected:
-		QString affixFileName(const QStringList& files);
-		QString dictFileName(const QStringList& files);
+		QString affixFileName(const QStringList& files) const;
+		QString dictFileName(const QStringList& files) const;
 		void setAvailDictsXMLFile(const QString& availDictsXMLDataFile);
+
 		QMap<QString, QString> dictionaryMap;
 		QStringList dictionaryPaths;
 		QString downloadLocation;
