@@ -10,6 +10,7 @@ for which a new license (GPL+exception) is in place.
 #include "ui_propertywidget_pathtextbase.h"
 
 #include "propertywidgetbase.h"
+#include "units.h"
 
 class ScribusDoc;
 class ScribusMainWindow;
@@ -24,11 +25,10 @@ public:
 	~PropertyWidget_PathText() {};
 
 protected:
-	PageItem *         m_item;
-	ScribusMainWindow* m_ScMW;
-
-	double m_unitRatio;
-	int    m_unitIndex;
+	double m_unitRatio {1.0};
+	int m_unitIndex {SC_PT};
+	PageItem *m_item {nullptr};
+	ScribusMainWindow* m_ScMW {nullptr};
 
 	void connectSignals();
 	void disconnectSignals();
@@ -36,7 +36,7 @@ protected:
 	void configureWidgets(void);
 	void setCurrentItem(PageItem *item);
 
-	virtual void changeEvent(QEvent *e);
+	void changeEvent(QEvent *e) override;
 
 public slots:
 	void setMainWindow(ScribusMainWindow *mw);
@@ -47,6 +47,7 @@ public slots:
 
 	void languageChange();
 	void unitChange();
+	void localeChange();
 
 private slots:
 	void handlePathType();
