@@ -938,9 +938,9 @@ void ResourceManager::updateDownloadLists()
 	dataReceivedLabel->setVisible(true);
 	downloadProgressBar->setRange(0, m_dataFiles.count());
 	for (const QString& f : qAsConst(m_dataFiles))
-		ScQApp->dlManager()->addURL("http://services.scribus.net/" + f, true, ScPaths::downloadDir(), ScPaths::downloadDir());
+		ScQApp->dlManager()->addURL("https://services.scribus.net/" + f, true, ScPaths::downloadDir(), ScPaths::downloadDir());
 	for (const QString& f : qAsConst(m_dataFiles))
-		ScQApp->dlManager()->addURL("http://services.scribus.net/" + f + ".sha256", true, ScPaths::downloadDir(), ScPaths::downloadDir());
+		ScQApp->dlManager()->addURL("https://services.scribus.net/" + f + ".sha256", true, ScPaths::downloadDir(), ScPaths::downloadDir());
 	connect(ScQApp->dlManager(), SIGNAL(finished()), this, SLOT(downloadListFinished()));
 	connect(ScQApp->dlManager(), SIGNAL(fileReceived(const QString&)), this, SLOT(updateProgressBar()));
 	connect(ScQApp->dlManager(), SIGNAL(fileFailed(const QString&)), this, SLOT(updateProgressBar()));
@@ -1050,7 +1050,7 @@ void ResourceManager::downloadFilesFinished()
 				}
 				if (d.filetype=="plain")
 				{
-					//do nothing as the file is alread in place from dl mgr
+					//do nothing as the file is already in place from dl mgr
 				}
 			}
 			break;
@@ -1090,7 +1090,7 @@ void ResourceManager::downloadFilesFinished()
 					}
 					if (d.filetype=="plain")
 					{
-						//do nothing as the file is alread in place from dl mgr
+						//do nothing as the file is already in place from dl mgr
 					}
 				}
 			}
@@ -1140,7 +1140,7 @@ void ResourceManager::downloadFilesFinished()
 				}
 				if (d.filetype=="plain")
 				{
-					//do nothing as the file is alread in place from dl mgr
+					//do nothing as the file is already in place from dl mgr
 				}
 			}
 			break;
