@@ -13,6 +13,7 @@ for which a new license (GPL+exception) is in place.
 #include "smcellstylewidget.h"
 
 SMCellStyleWidget::SMCellStyleWidget(QWidget *parent)
+                 : QWidget(parent)
 {
 	setupUi(this);
 
@@ -24,10 +25,6 @@ SMCellStyleWidget::SMCellStyleWidget(QWidget *parent)
 	connect(ScQApp, SIGNAL(iconSetChanged()), this, SLOT(iconSetChange()));
 }
 
-SMCellStyleWidget::~SMCellStyleWidget()
-{
-}
-
 void SMCellStyleWidget::changeEvent(QEvent *e)
 {
 	if (e->type() == QEvent::LanguageChange)
@@ -152,12 +149,11 @@ void SMCellStyleWidget::showColors(const QList<CellStyle*> &cellStyles)
 	else
 		fillShade->setValue(qRound(d));
 	QString s;
-	QString emptyString;
 	for (int i = 0; i < cellStyles.count(); ++i)
 	{
-		if (!s.isNull() && s != cellStyles[i]->fillColor())
+		if (!s.isEmpty() && s != cellStyles[i]->fillColor())
 		{
-			s = emptyString;
+			s.clear();
 			break;
 		}
 		s = cellStyles[i]->fillColor();
