@@ -18,6 +18,7 @@ for which a new license (GPL+exception) is in place.
 
 
 SMCStyleWidget::SMCStyleWidget(QWidget *parent)
+              : QWidget(parent)
 {
 	setupUi(this);
 
@@ -203,7 +204,7 @@ void SMCStyleWidget::setDoc(ScribusDoc *doc)
 	connect(m_Doc->scMW(), SIGNAL(UpdateRequest(int)), this , SLOT(handleUpdateRequest(int)));
 }
 
-void SMCStyleWidget::show(CharStyle *cstyle, QList<CharStyle> &cstyles, const QString &defLang, int unitIndex)
+void SMCStyleWidget::show(const CharStyle *cstyle, const QList<CharStyle> &cstyles, const QString &defLang, int /*unitIndex*/)
 {
 	disconnect(effects_, SIGNAL(State(int)), this, SLOT(slotColorChange()));
 	parentCombo->setEnabled(!cstyle->isDefaultStyle());
@@ -375,11 +376,8 @@ void SMCStyleWidget::show(CharStyle *cstyle, QList<CharStyle> &cstyles, const QS
 	connect(effects_, SIGNAL(State(int)), this, SLOT(slotColorChange()));
 }
 
-void SMCStyleWidget::show(QList<CharStyle*> &cstyles, QList<CharStyle> &cstylesAll, const QString &defLang, int unitIndex)
+void SMCStyleWidget::show(const QList<CharStyle*> &cstyles, const QList<CharStyle> &cstylesAll, const QString &defLang, int unitIndex)
 {
-// 	int decimals = unitGetDecimalsFromIndex(unitIndex);
-// 	QString suffix = unitGetSuffixFromIndex(unitIndex);
-
 	if (cstyles.count() == 1)
 		show(cstyles[0], cstylesAll, defLang, unitIndex);
 	else if (cstyles.count() > 1)
@@ -572,12 +570,11 @@ void SMCStyleWidget::showColors(const QList<CharStyle*> &cstyles)
 		backShade_->setValue(qRound(d));
 
 	QString s;
-	QString emptyString;
 	for (int i = 0; i < cstyles.count(); ++i)
 	{
-		if (!s.isNull() && s != cstyles[i]->fillColor())
+		if (!s.isEmpty() && s != cstyles[i]->fillColor())
 		{
-			s = emptyString;
+			s.clear();
 			break;
 		}
 		s = cstyles[i]->fillColor();
@@ -591,12 +588,12 @@ void SMCStyleWidget::showColors(const QList<CharStyle*> &cstyles)
 	else
 		fillColor_->setCurrentText(s);
 
-	s = emptyString;
+	s.clear();
 	for (int i = 0; i < cstyles.count(); ++i)
 	{
-		if (!s.isNull() && s != cstyles[i]->strokeColor())
+		if (!s.isEmpty() && s != cstyles[i]->strokeColor())
 		{
-			s = emptyString;
+			s.clear();
 			break;
 		}
 		s = cstyles[i]->strokeColor();
@@ -610,12 +607,12 @@ void SMCStyleWidget::showColors(const QList<CharStyle*> &cstyles)
 	else
 		strokeColor_->setCurrentText(s);
 
-	s = emptyString;
+	s.clear();
 	for (int i = 0; i < cstyles.count(); ++i)
 	{
-		if (!s.isNull() && s != cstyles[i]->backColor())
+		if (!s.isEmpty() && s != cstyles[i]->backColor())
 		{
-			s = emptyString;
+			s.clear();
 			break;
 		}
 		s = cstyles[i]->backColor();
@@ -630,15 +627,14 @@ void SMCStyleWidget::showColors(const QList<CharStyle*> &cstyles)
 		backColor_->setCurrentText(s);
 }
 
-void SMCStyleWidget::showLanguage(const QList<CharStyle*> &cstyles, const QString &defLang)
+void SMCStyleWidget::showLanguage(const QList<CharStyle*> &cstyles, const QString& /*defLang*/)
 {
-	QString emptyString;
 	QString s(cstyles[0]->language());
 	for (int i = 0; i < cstyles.count(); ++i)
 	{
 		if (s != cstyles[i]->language())
 		{
-			s = emptyString;
+			s.clear();
 			break;
 		}
 		s = cstyles[i]->language();
@@ -689,7 +685,7 @@ void SMCStyleWidget::showHyphenChar(const QList<CharStyle *> &cstyles)
 	hyphenCharLineEdit->setValue(hyphenText);
 }
 
-void SMCStyleWidget::showParent(const QList<CharStyle*> &cstyles)
+void SMCStyleWidget::showParent(const QList<CharStyle*>& /*cstyles*/)
 {
 	parentCombo->setEnabled(false);
 }
@@ -727,9 +723,3 @@ void SMCStyleWidget::slotColorChange()
 	strokeShade_->setEnabled(enabled);
 	strokeColor_->setEnabled(enabled);
 }
-
-
-SMCStyleWidget::~SMCStyleWidget()
-{
-	
-}
