@@ -21,16 +21,17 @@ class ScrSpinBox;
 class SMLineStyleWidget : public QWidget, Ui::SMLineStyleWidget
 {
 	Q_OBJECT
+
 public:
 	SMLineStyleWidget();
-	~SMLineStyleWidget();
-	
-	virtual void changeEvent(QEvent *e);
+	~SMLineStyleWidget() = default;
 	
 	void showStyle(const multiLine &lineStyle, ColorList &colorList, int subLine = 0);
-	void languageChange();
 	void unitChange(int unitIndex);
 
+protected:
+	void changeEvent(QEvent *e) override;
+
 private:
 	multiLine  m_currentStyle;
 	ColorList  m_colors;
@@ -44,6 +45,8 @@ private:
 	friend class SMLineStyle;
 
 protected slots:
+	void iconSetChange();
+	void languageChange();
 	void slotEditNewLine(int i);
 
 };
