@@ -164,7 +164,7 @@ void SMParagraphStyle::selected(const QStringList &styleNames)
 	setupConnections();
 }
 
-QList<CharStyle> SMParagraphStyle::getCharStyles()
+QList<CharStyle> SMParagraphStyle::getCharStyles() const
 {
 	QList<CharStyle> charStyles;
 	if (!m_doc)
@@ -184,7 +184,7 @@ QString SMParagraphStyle::fromSelection() const
 
 	for (int i = 0; i < m_doc->m_Selection->count(); ++i)
 	{
-		// wth is going on here
+		// FIXME: wth is going on here
 		PageItem *item = m_doc->m_Selection->itemAt(i);
 
 		QString tmpName = item->itemText.defaultStyle().parent();
@@ -425,6 +425,7 @@ void SMParagraphStyle::nameChanged(const QString &newName)
 		}
 	}
 
+	//When a parent style is renamed, also set the parent style name of the children
 	for (int j = 0; j < m_tmpStyles.count(); ++j)
 	{
 		if (m_tmpStyles[j].parent() == oldName)
@@ -1871,7 +1872,6 @@ SMCharacterStyle::SMCharacterStyle()
 	m_widget->setContentsMargins(5, 5, 5, 5);//CB the SMCStylePage parent has a 0 value to fit properly onto the pstyle page, so add it here
 	m_page = new SMCStyleWidget();
 	Q_CHECK_PTR(m_page);
-//	m_widget->addTab(m_page, tr("Properties"));
 }
 
 QTabWidget* SMCharacterStyle::widget()
@@ -1978,7 +1978,7 @@ QString SMCharacterStyle::fromSelection() const
 
 	for (int i = 0; i < m_doc->m_Selection->count(); ++i)
 	{
-		// wth is going on here
+		// FIXME: wth is going on here
 		PageItem *item = m_doc->m_Selection->itemAt(i);
 
 		QString tmpName = item->itemText.defaultStyle().charStyle().parent();
@@ -2075,8 +2075,6 @@ void SMCharacterStyle::apply()
 	m_deleted.clear(); // deletion done at this point
 
 	m_doc->scMW()->requestUpdate(reqTextStylesUpdate);
-	// Better not call DrawNew() here, as this will cause several unnecessary calls
-	// m_doc->view()->DrawNew();
 	m_doc->changed();
 }
 
