@@ -36,8 +36,7 @@ for which a new license (GPL+exception) is in place.
 const QString StyleManager::SEPARATOR = "$$$$"; // dumb but it works
 
 StyleManager::StyleManager(QWidget *parent, const char *name)
-	: ScrPaletteBase(parent, name), m_item(nullptr), m_widget(nullptr),
-	m_shortcutWidget(nullptr), m_isEditMode(true), m_doc(nullptr)
+	: ScrPaletteBase(parent, name)
 {
 	setupUi(this);
 	styleView->hideColumn(SHORTCUT_COL);
@@ -55,8 +54,6 @@ StyleManager::StyleManager(QWidget *parent, const char *name)
 	if (pname.isEmpty())
 		pname = "styleManager";
 	m_prefs = PrefsManager::instance().prefsFile->getContext(pname);
-	m_isEditMode = true;
-	m_isStoryEditMode = false;
 	m_editPosition.setX(m_prefs->getInt("eX", x()));
 	m_editPosition.setY(m_prefs->getInt("eY", y()));
 
@@ -66,8 +63,6 @@ StyleManager::StyleManager(QWidget *parent, const char *name)
 	deleteButton->setEnabled(false);
 	m_rightClickPopup->setEnabled(false);
 	m_newPopup->setEnabled(false);
-	
-	m_selectedStyleAction = nullptr;
 
 	connect(m_newPopup, SIGNAL(triggered(QAction*)), this, SLOT(slotNewPopup(QAction*)));
 	connect(okButton, SIGNAL(clicked()), this, SLOT(slotOk()));
@@ -1154,7 +1149,7 @@ void StyleManager::slotApplyStyle(const QString& keyString)
 	if (m_isEditMode)
 		return;
 
-	QStringList slist = keyString.split(SEPARATOR, QString::SkipEmptyParts);
+	QStringList slist = keyString.split(SEPARATOR, Qt::SkipEmptyParts);
 	Q_ASSERT(slist.count() == 2);
 
 	loadType(slist[0]);
@@ -1221,8 +1216,7 @@ void StyleManager::slotSetupWidget()
 		nameEdit->setEnabled(false);
 	}
 
-	connect(nameEdit, SIGNAL(textChanged(const QString&)),
-	        this, SLOT(slotNameChanged(const QString&)));
+	connect(nameEdit, SIGNAL(textChanged(const QString&)), this, SLOT(slotNameChanged(const QString&)));
 
 }
 
@@ -1371,6 +1365,7 @@ void StyleManager::loadType(const QString &name)
 	//insertShortcutPage(m_widget);
 	//>>
 	m_widget->setParent(mainFrame);
+	m_layout->setContentsMargins(0, 0, 0, 0);
 	m_layout->addWidget(m_widget, 0, 0);
 	layout()->activate();
 	m_widget->resize(m_widget->minimumSizeHint());
