@@ -14,8 +14,8 @@ for which a new license (GPL+exception) is in place.
 StrikeValues::StrikeValues( QWidget* parent ) : QFrame( parent )
 {
 	group1Layout = new QGridLayout( this );
-	group1Layout->setSpacing( 3 );
-	group1Layout->setMargin( 2 );
+	group1Layout->setSpacing(3);
+	group1Layout->setContentsMargins(3, 3, 3, 3);
 	group1Layout->setAlignment( Qt::AlignTop );
 	LPos = new ScrSpinBox( -0.1, 100, this, 0 );
 	LPos->setValue( -0.1 );
@@ -47,8 +47,8 @@ void StrikeValues::languageChange()
 UnderlineValues::UnderlineValues( QWidget* parent ) : QFrame( parent )
 {
 	group1Layout = new QGridLayout(this);
-	group1Layout->setSpacing( 3 );
-	group1Layout->setMargin( 2 );
+	group1Layout->setSpacing(3);
+	group1Layout->setContentsMargins(3, 3, 3, 3);
 	group1Layout->setAlignment( Qt::AlignTop );
 	LPos = new ScrSpinBox( -0.1, 100, this, 0 );
 	LPos->setValue( -0.1 );
@@ -80,8 +80,8 @@ void UnderlineValues::languageChange()
 OutlineValues::OutlineValues( QWidget* parent ) : QFrame( parent )
 {
 	group1Layout = new QGridLayout( this );
-	group1Layout->setSpacing( 3 );
-	group1Layout->setMargin( 2 );
+	group1Layout->setSpacing(3);
+	group1Layout->setContentsMargins(3, 3, 3, 3);
 	group1Layout->setAlignment( Qt::AlignTop );
 	LWidth = new ScrSpinBox( 0, 100, this, 0 );
 	LWidth->setValue( 1 );
@@ -101,8 +101,8 @@ void OutlineValues::languageChange()
 ShadowValues::ShadowValues( QWidget* parent ) : QFrame( parent )
 {
 	group1Layout = new QGridLayout( this );
-	group1Layout->setSpacing( 3 );
-	group1Layout->setMargin( 2 );
+	group1Layout->setSpacing(3);
+	group1Layout->setContentsMargins(3, 3, 3, 3);
 	group1Layout->setAlignment( Qt::AlignTop );
 	Xoffset = new ScrSpinBox( -100, 100, this, 0 );
 	Xoffset->setValue( 5 );
@@ -131,8 +131,8 @@ StyleSelect::StyleSelect(QWidget* parent) : QWidget(parent)
 {
 	IconManager& im = IconManager::instance();
 	ssLayout = new QHBoxLayout(this);
-	ssLayout->setSpacing( 0 );
-	ssLayout->setMargin( 0 );
+	ssLayout->setSpacing(3);
+	ssLayout->setContentsMargins(0, 0, 0, 0);
 
 	UnderlineVal = new UnderlineValues( nullptr );
 	UnderlinePop = new QMenu();
