@@ -34,18 +34,17 @@ for which a new license (GPL+exception) is in place.
 #include <QToolButton>
 #include <QVBoxLayout>
 
-
-#include "ui/createrange.h"
+#include "iconmanager.h"
+#include "pageitemiterator.h"
 #include "pdfoptions.h"
 #include "prefsmanager.h"
+#include "scconfig.h"
 #include "scribuscore.h"
 #include "scribusview.h"
-#include "scconfig.h"
+#include "ui/createrange.h"
+#include "ui/scrspinbox.h"
 #include "units.h"
 #include "usertaskstructs.h"
-#include "ui/scrspinbox.h"
-#include "iconmanager.h"
-#include "scribuscore.h"
 #include "util.h"
 
 TabPDFOptions::TabPDFOptions(QWidget* parent, PDFOptions & Optionen,
@@ -58,8 +57,7 @@ TabPDFOptions::TabPDFOptions(QWidget* parent, PDFOptions & Optionen,
 	unitRatio(unitGetRatioFromIndex(doc->unitIndex())),
 	m_Doc(doc),
 	AllFonts(AllFonts),
-	Opts(Optionen),
-	cms(false)
+	Opts(Optionen)
 {
 	setupUi(this);
 
@@ -205,7 +203,7 @@ TabPDFOptions::TabPDFOptions(QWidget* parent, PDFOptions & Optionen,
 	ClipMarg->setToolTip( "<qt>" + tr( "Do not show objects outside the margins in the exported file" ) + "</qt>" );
 	MirrorH->setToolTip( "<qt>" + tr( "Mirror Page(s) horizontally" ) + "</qt>" );
 	MirrorV->setToolTip( "<qt>" + tr( "Mirror Page(s) vertically" ) + "</qt>" );
-	PDFVersionCombo->setToolTip( "<qt>" + tr( "Determines the PDF compatibility.<br/>The default is <b>PDF 1.3</b> which gives the widest compatibility.<br/>Choose <b>PDF 1.4</b> if your file uses features such as transparency or you require 128 bit encryption.<br/><b>PDF 1.5</b> is necessary when you wish to preserve objects in separate layers within the PDF.<br/><b>PDF/X-1a</b> is for blind exchange with colors strictly specified in CMYK or spot colors.<br/><b>PDF/X-3</b> is for exporting the PDF when you want color managed RGB for commercial printing and is selectable when you have activated color management. Use only when advised by your printer or in some cases printing to a 4 color digital color laser printer.<br/><b>PDF/X-4</b> is an extension of PDF/X-3 to support transparency and layering." ) + "</qt>");
+	PDFVersionCombo->setToolTip( "<qt>" + tr( "Determines the PDF compatibility.<br/><b>PDF 1.3</b>, which is the earliest supported version, gives the widest compatibility with printers' RIPS.<br/><b>PDF 1.4</b>, which is the default version, supports features such as transparency and 128 bit encryption.<br/><b>PDF 1.5</b> is necessary when you wish to preserve objects in separate layers within the PDF.<br/><b>PDF/X-1a</b> is for blind exchange with colors strictly specified in CMYK or spot colors.<br/><b>PDF/X-3</b> is for exporting the PDF when you want color managed RGB for commercial printing and is selectable when you have activated color management. Use only when advised by your printer or in some cases printing to a 4 color digital color laser printer.<br/><b>PDF/X-4</b> is an extension of PDF/X-3 to support transparency and layering." ) + "</qt>");
 	ComboBind->setToolTip( "<qt>" + tr( "Determines the binding of pages in the PDF. Unless you know you need to change it leave the default choice - Left." ) + "</qt>" );
 	CheckBox1->setToolTip( "<qt>" + tr( "Generates thumbnails of each page in the PDF. Some viewers can use the thumbnails for navigation." ) + "</qt>" );
 	Article->setToolTip( "<qt>" + tr( "Generate PDF Articles, which is useful for navigating linked articles in a PDF" ) + "</qt>" );
@@ -348,17 +346,14 @@ void TabPDFOptions::restoreDefaults(PDFOptions & Optionen,
 	ClipMarg->setChecked(Opts.doClip);
 	bool cmsUse = (ScCore->haveCMS() && m_Doc->HasCMS);
 	if (!cmsUse)
-		PDFVersionCombo->setVersion(PDFOptions::PDFVersion_14);
+		PDFVersionCombo->setVersion(PDFVersion::PDF_14);
 	PDFVersionCombo->setVersion(Opts.Version);
 	ComboBind->setCurrentIndex(Opts.Binding);
 	CheckBox1->setChecked(Opts.Thumbnails);
 	Article->setChecked(Opts.Articles);
 	CheckBM->setChecked(Opts.Bookmarks);
 	useLayers->setChecked(Opts.useLayers);
-	if (Opts.Version == PDFOptions::PDFVersion_15 || Opts.Version == PDFOptions::PDFVersion_X4)
-		useLayers->setEnabled(true);
-	else
-		useLayers->setEnabled(false);
+	useLayers->setEnabled(Opts.Version.supportsOCGs());
 	Resolution->setValue(Opts.Resolution);
 	EmbedPDF->setChecked(Opts.embedPDF);
 	Compression->setChecked( Opts.Compress );
@@ -371,9 +366,9 @@ void TabPDFOptions::restoreDefaults(PDFOptions & Optionen,
 	ValC->setEnabled(DSColor->isChecked());
 
 	m_docFonts = DocFonts.keys();
-	if (Opts.Version == PDFOptions::PDFVersion_X1a ||
-		Opts.Version == PDFOptions::PDFVersion_X3  ||
-		Opts.Version == PDFOptions::PDFVersion_X4 )
+	if (Opts.Version == PDFVersion::PDF_X1a ||
+		Opts.Version == PDFVersion::PDF_X3  ||
+		Opts.Version == PDFVersion::PDF_X4 )
 	{
 		if (Opts.FontEmbedding != PDFOptions::EmbedFonts &&
 			Opts.FontEmbedding != PDFOptions::OutlineFonts)
@@ -393,67 +388,17 @@ void TabPDFOptions::restoreDefaults(PDFOptions & Optionen,
 	FromSubset->setEnabled(false); // Will be enabled when user select a font in appropriate list
 
 //	Build a list of all Fonts used in Annotations;
-	PageItem *pgit;
-	QList<PageItem*> allItems;
-	for (QHash<int, PageItem*>::iterator it = m_Doc->FrameItems.begin(); it != m_Doc->FrameItems.end(); ++it)
+	int pageItOptions = PageItemIterator::IterateInGroups | PageItemIterator::IterateInDocItems | PageItemIterator::IterateInMasterItems | PageItemIterator::IterateInFrameItems;
+	for (PageItemIterator it(m_Doc, pageItOptions); *it; ++it)
 	{
-		PageItem *currItem = it.value();
-		if (currItem->isGroup())
-			allItems = currItem->getAllChildren();
-		else
-			allItems.append(currItem);
-		for (int ii = 0; ii < allItems.count(); ii++)
+		PageItem *currItem = *it;
+		if (((currItem->itemType() == PageItem::TextFrame) || (currItem->itemType() == PageItem::PathText)) && (currItem->isAnnotation()))
 		{
-			pgit = allItems.at(ii);
-			if (((pgit->itemType() == PageItem::TextFrame) || (pgit->itemType() == PageItem::PathText)) && (pgit->isAnnotation()))
-			{
-				int annotType  = pgit->annotation().Type();
-				bool mustEmbed = ((annotType >= Annotation::Button) && (annotType <= Annotation::Listbox) && (annotType != Annotation::Checkbox));
-				if (pgit->itemText.length() > 0 || mustEmbed)
-					m_annotationFonts.insert(pgit->itemText.defaultStyle().charStyle().font().replacementName(), "");
-			}
+			int annotType  = currItem->annotation().Type();
+			bool mustEmbed = ((annotType >= Annotation::Button) && (annotType <= Annotation::Listbox) && (annotType != Annotation::Checkbox));
+			if (currItem->itemText.length() > 0 || mustEmbed)
+				m_annotationFonts.insert(currItem->itemText.defaultStyle().charStyle().font().replacementName(), QString());
 		}
-		allItems.clear();
-	}
-	for (int a = 0; a < m_Doc->MasterItems.count(); ++a)
-	{
-		PageItem *currItem = m_Doc->MasterItems.at(a);
-		if (currItem->isGroup())
-			allItems = currItem->getAllChildren();
-		else
-			allItems.append(currItem);
-		for (int ii = 0; ii < allItems.count(); ii++)
-		{
-			pgit = allItems.at(ii);
-			if (((pgit->itemType() == PageItem::TextFrame) || (pgit->itemType() == PageItem::PathText)) && (pgit->isAnnotation()))
-			{
-				int annotType  = pgit->annotation().Type();
-				bool mustEmbed = ((annotType >= Annotation::Button) && (annotType <= Annotation::Listbox) && (annotType != Annotation::Checkbox));
-				if (pgit->itemText.length() > 0 || mustEmbed)
-					m_annotationFonts.insert(pgit->itemText.defaultStyle().charStyle().font().replacementName(), "");
-			}
-		}
-		allItems.clear();
-	}
-	for (int a = 0; a < m_Doc->DocItems.count(); ++a)
-	{
-		PageItem *currItem = m_Doc->DocItems.at(a);
-		if (currItem->isGroup())
-			allItems = currItem->getAllChildren();
-		else
-			allItems.append(currItem);
-		for (int ii = 0; ii < allItems.count(); ii++)
-		{
-			pgit = allItems.at(ii);
-			if (((pgit->itemType() == PageItem::TextFrame) || (pgit->itemType() == PageItem::PathText)) && (pgit->isAnnotation()))
-			{
-				int annotType  = pgit->annotation().Type();
-				bool mustEmbed = ((annotType >= Annotation::Button) && (annotType <= Annotation::Listbox) && (annotType != Annotation::Checkbox));
-				if (pgit->itemText.length() > 0 || mustEmbed)
-					m_annotationFonts.insert(pgit->itemText.defaultStyle().charStyle().font().replacementName(), "");
-			}
-		}
-		allItems.clear();
 	}
 	ToSubset->setEnabled(false);
 	FromSubset->setEnabled(false);
@@ -468,7 +413,7 @@ void TabPDFOptions::restoreDefaults(PDFOptions & Optionen,
 		{
 			QString fontName = m_docFonts.at(fe);
 			const ScFace fontFace = AllFonts[fontName];
-			if (Opts.EmbedList.contains(fontName) && (!fontFace.isOTF()))
+			if (Opts.EmbedList.contains(fontName) && (!fontFace.isOTF() || Opts.supportsEmbeddedOpenTypeFonts()) && !fontFace.subset())
 				addFontItem(fontName, EmbedList);
 			else
 			{
@@ -517,10 +462,9 @@ void TabPDFOptions::restoreDefaults(PDFOptions & Optionen,
 	hideToolBar->setChecked(Opts.hideToolBar);
 	hideMenuBar->setChecked(Opts.hideMenuBar);
 	fitWindow->setChecked(Opts.fitWindow);
-	QMap<QString,QString>::Iterator itja;
 	actionCombo->clear();
 	actionCombo->addItem( tr("No Script"));
-	for (itja = m_Doc->JavaScripts.begin(); itja != m_Doc->JavaScripts.end(); ++itja)
+	for (auto itja = m_Doc->JavaScripts.begin(); itja != m_Doc->JavaScripts.end(); ++itja)
 		actionCombo->addItem(itja.key());
 	if (m_Doc->JavaScripts.contains(Opts.openAction))
 		setCurrentComboItem(actionCombo, Opts.openAction);
@@ -532,10 +476,7 @@ void TabPDFOptions::restoreDefaults(PDFOptions & Optionen,
 		facingPagesLeft->setChecked(true);
 	else if (Opts.PageLayout == PDFOptions::TwoColumnRight)
 		facingPagesRight->setChecked(true);
-	if ((Opts.Version == PDFOptions::PDFVersion_15) || (Opts.Version == PDFOptions::PDFVersion_X4))
-		useLayers2->setEnabled(true);
-	else
-		useLayers2->setEnabled(false);
+	useLayers2->setEnabled(Opts.Version.supportsOCGs());
 
 	Encry->setChecked( Opts.Encrypt );
 	PassOwner->setText(Opts.PassOwner);
@@ -552,13 +493,10 @@ void TabPDFOptions::restoreDefaults(PDFOptions & Optionen,
 
 	if (Opts.UseRGB)
 		OutCombo->setCurrentIndex(0);
+	else if (Opts.isGrayscale)
+		OutCombo->setCurrentIndex(2);
 	else
-	{
-		if (Opts.isGrayscale)
-			OutCombo->setCurrentIndex(2);
-		else
-			OutCombo->setCurrentIndex(1);
-	}
+		OutCombo->setCurrentIndex(1);
 	useSpot->setChecked(!Opts.UseSpotColors);
 	UseLPI->setChecked(Opts.UseLPI);
 	QMap<QString,LPIData>::Iterator itlp;
@@ -658,11 +596,11 @@ void TabPDFOptions::restoreDefaults(PDFOptions & Optionen,
 	docInfoMarks->setChecked(Opts.docInfoMarks);
 	if (!cmsUse)
 		X3Group->setEnabled(false);
-	if (cmsUse && (Opts.Version == PDFOptions::PDFVersion_X1a) && (!PDFXProfiles.isEmpty()))
+	if (cmsUse && (Opts.Version == PDFVersion::PDF_X1a) && (!PDFXProfiles.isEmpty()))
 		EnablePDFX(3);
-	else if (cmsUse && (Opts.Version == PDFOptions::PDFVersion_X3) && (!PDFXProfiles.isEmpty()))
+	else if (cmsUse && (Opts.Version == PDFVersion::PDF_X3) && (!PDFXProfiles.isEmpty()))
 		EnablePDFX(4);
-	else if (cmsUse && (Opts.Version == PDFOptions::PDFVersion_X4) && (!PDFXProfiles.isEmpty()))
+	else if (cmsUse && (Opts.Version == PDFVersion::PDF_X4) && (!PDFXProfiles.isEmpty()))
 		EnablePDFX(5);
 	else
 		X3Group->setEnabled(false);
@@ -675,7 +613,7 @@ void TabPDFOptions::restoreDefaults(PDFOptions & Optionen,
 	EffectType->addItem( tr("Glitter"));
 	EffectType->addItem( tr("Split"));
 	EffectType->addItem( tr("Wipe"));
-	if (Opts.Version == PDFOptions::PDFVersion_15)
+	if (Opts.Version.supportsPDF15PresentationEffects())
 	{
 		EffectType->addItem( tr("Push"));
 		EffectType->addItem( tr("Cover"));
@@ -748,7 +686,7 @@ void TabPDFOptions::storeValues(PDFOptions& pdfOptions)
 	if (Encry->isChecked())
 	{
 		int Perm = -64;
-		if (PDFVersionCombo->currentIndex() == 1)
+		if (PDFVersionCombo->version() == PDFVersion::PDF_14)
 			Perm &= ~0x00240000;
 		if (PrintSec->isChecked())
 			Perm += 4;
@@ -770,30 +708,27 @@ void TabPDFOptions::storeValues(PDFOptions& pdfOptions)
 		pdfOptions.UseProfiles = false;
 		pdfOptions.UseProfiles2 = false;
 	}
+	else if (OutCombo->currentIndex() == 2)
+	{
+		pdfOptions.isGrayscale = true;
+		pdfOptions.UseRGB = false;
+		pdfOptions.UseProfiles = false;
+		pdfOptions.UseProfiles2 = false;
+	}
 	else
 	{
-		if (OutCombo->currentIndex() == 2)
+		pdfOptions.isGrayscale = false;
+		pdfOptions.UseRGB = false;
+		if (/*CMSuse*/ ScCore->haveCMS())
 		{
-			pdfOptions.isGrayscale = true;
-			pdfOptions.UseRGB = false;
-			pdfOptions.UseProfiles = false;
-			pdfOptions.UseProfiles2 = false;
-		}
-		else
-		{
-			pdfOptions.isGrayscale = false;
-			pdfOptions.UseRGB = false;
-			if (/*CMSuse*/ ScCore->haveCMS())
-			{
-				pdfOptions.UseProfiles = EmbedProfs->isChecked();
-				pdfOptions.UseProfiles2 = EmbedProfs2->isChecked();
-				pdfOptions.Intent = IntendS->currentIndex();
-				pdfOptions.Intent2 = IntendI->currentIndex();
-				pdfOptions.EmbeddedI = NoEmbedded->isChecked();
-				pdfOptions.SolidProf = SolidPr->currentText();
-				pdfOptions.ImageProf = ImageP->currentText();
-				pdfOptions.PrintProf = PrintProfC->currentText();
-			}
+			pdfOptions.UseProfiles = EmbedProfs->isChecked();
+			pdfOptions.UseProfiles2 = EmbedProfs2->isChecked();
+			pdfOptions.Intent = IntendS->currentIndex();
+			pdfOptions.Intent2 = IntendI->currentIndex();
+			pdfOptions.EmbeddedI = NoEmbedded->isChecked();
+			pdfOptions.SolidProf = SolidPr->currentText();
+			pdfOptions.ImageProf = ImageP->currentText();
+			pdfOptions.PrintProf = PrintProfC->currentText();
 		}
 	}
 }
@@ -846,20 +781,22 @@ void TabPDFOptions::ToggleEncr()
 void TabPDFOptions::enableCMS(bool enable)
 {
 	QSignalBlocker blocker(PDFVersionCombo);
-	PDFOptions::PDFVersion currVersion = PDFVersionCombo->version();
+	PDFVersion currVersion = PDFVersionCombo->version();
 	PDFVersionCombo->setPDFXEnabled(enable);
 	cms = enable;
 	if (!enable)
-		currVersion = qMax(PDFOptions::PDFVersion_13, qMin(currVersion, PDFOptions::PDFVersion_15));
+		currVersion = qMax(PDFVersion::PDF_13, qMin((PDFVersion::Version) currVersion, PDFVersion::PDF_16));
 	PDFVersionCombo->setVersion(currVersion);
 	EnablePr(1);
 }
 
-void TabPDFOptions::EnablePDFX(int a)
+void TabPDFOptions::EnablePDFX(int /*a*/)
 {
-	useLayers->setEnabled((a == 2) || (a == 5));
+	PDFVersion pdfVer = PDFVersionCombo->version();
+
+	useLayers->setEnabled(pdfVer.supportsOCGs());
 	if (useLayers2)
-		useLayers2->setEnabled((a == 2) || (a == 5));
+		useLayers2->setEnabled(pdfVer.supportsOCGs());
 
 	int currentEff = EffectType->currentIndex();
 	disconnect(EffectType, SIGNAL(activated(int)), this, SLOT(SetEffOpts(int)));
@@ -871,7 +808,7 @@ void TabPDFOptions::EnablePDFX(int a)
 	EffectType->addItem( tr("Glitter"));
 	EffectType->addItem( tr("Split"));
 	EffectType->addItem( tr("Wipe"));
-	if (a == 2)
+	if (pdfVer.supportsPDF15PresentationEffects())
 	{
 		EffectType->addItem( tr("Push"));
 		EffectType->addItem( tr("Cover"));
@@ -897,8 +834,9 @@ void TabPDFOptions::EnablePDFX(int a)
 	}
 	connect(EffectType, SIGNAL(activated(int)), this, SLOT(SetEffOpts(int)));
 
-	if (a < 3)  // not PDF/X
+	if (!pdfVer.isPDFX())  // not PDF/X
 	{
+		checkEmbeddableFonts();
 		fontEmbeddingCombo->setNoEmbeddingEnabled(true);
 		X3Group->setEnabled(false);
 		setTabEnabled(indexOf(tabSecurity), true);
@@ -912,19 +850,20 @@ void TabPDFOptions::EnablePDFX(int a)
 		EnablePr(OutCombo->currentIndex());
 		return;
 	}
+
 	// PDF/X is selected
 	disconnect(OutCombo, SIGNAL(activated(int)), this, SLOT(EnablePr(int)));
 	OutCombo->setCurrentIndex(1);
 	OutCombo->setEnabled(false);
 	EnablePr(1);
-	if (a == 3) // X1, no profile embedding
+	if (pdfVer == PDFVersion::PDF_X1a) // X1, no profile embedding
 	{
 		EmbedProfs->setChecked(false);
 		EmbedProfs->setEnabled(false);
 		EmbedProfs2->setChecked(false);
 		EmbedProfs2->setEnabled(false);
 	}
-	if ((a == 4) || (a == 5)) // X3 or X4, enforcing color profiles on images
+	if (pdfVer == PDFVersion::PDF_X3 || pdfVer == PDFVersion::PDF_X4) // X3 or X4, enforcing color profiles on images
 	{
 		EmbedProfs->setEnabled(true);
 		EmbedProfs2->setChecked(true);
@@ -1004,7 +943,7 @@ void TabPDFOptions::EnablePr(int a)
 	EnableLPI(a);
 	bool setter = false;
 	if (a == 1)
-		setter = !PDFVersionCombo->versionIs(PDFOptions::PDFVersion_X1a);
+		setter = !PDFVersionCombo->versionIs(PDFVersion::PDF_X1a);
 
 	solidsProfileGroup->setEnabled(setter);
 	imageProfileGroup->setEnabled(setter);
@@ -1296,13 +1235,17 @@ void TabPDFOptions::EmbeddingModeChange()
 
 void TabPDFOptions::RemoveSubset()
 {
+	PDFVersion pdfVer = PDFVersionCombo->version();
+
 	QList<QListWidgetItem*> selection = SubsetList->selectedItems();
 	for (int i = 0; i < selection.count() ; ++i)
 	{
 		QListWidgetItem* fontItem = selection[i];
 		QString currentFont = fontItem->text();
 		const ScFace fontFace = AllFonts[currentFont];
-		if (fontFace.isOTF() || fontFace.subset())
+		if (fontFace.isOTF() && !pdfVer.supportsEmbeddedOpenTypeFonts())
+			continue;
+		if (fontFace.subset())
 			continue;
 		addFontItem(currentFont, EmbedList);
 		int currentRow = SubsetList->row(fontItem);
@@ -1349,6 +1292,7 @@ void TabPDFOptions::SelEFont(QListWidgetItem*)
 
 void TabPDFOptions::SelSFont(QListWidgetItem*)
 {
+	PDFVersion pdfVer = PDFVersionCombo->version();
 	QList<QListWidgetItem*> selection = SubsetList->selectedItems();
 	int enabledForEmbedding = selection.count();
 
@@ -1356,7 +1300,9 @@ void TabPDFOptions::SelSFont(QListWidgetItem*)
 	{
 		const QListWidgetItem* item = selection.at(i);
 		const ScFace face = AllFonts[item->text()];
-		if (face.isOTF() || face.subset())
+		if (face.isOTF() && !pdfVer.supportsEmbeddedOpenTypeFonts())
+			enabledForEmbedding--;
+		else if (face.subset())
 			enabledForEmbedding--;
 	}
 
@@ -1367,15 +1313,18 @@ void TabPDFOptions::SelSFont(QListWidgetItem*)
 
 void TabPDFOptions::EmbedAll()
 {
+	PDFVersion pdfVer = PDFVersionCombo->version();
+
 	EmbedList->clear();
 	SubsetList->clear();
 	ToSubset->setEnabled(false);
 	FromSubset->setEnabled(false);
+
 	for (int i = 0; i < m_docFonts.count(); ++i)
 	{
 		QString fontName = m_docFonts.at(i);
 		const ScFace fontFace = AllFonts[fontName];
-		if (!fontFace.subset() && !fontFace.isOTF())
+		if (!fontFace.subset() && (!fontFace.isOTF() || pdfVer.supportsEmbeddedOpenTypeFonts()))
 		{
 			QListWidgetItem* item = addFontItem(fontName, EmbedList);
 			if (m_annotationFonts.contains(item->text()))
@@ -1414,6 +1363,26 @@ void TabPDFOptions::SubsetAll()
 	}
 }
 
+void TabPDFOptions::checkEmbeddableFonts()
+{
+	PDFVersion pdfVer = PDFVersionCombo->version();
+
+	for (int i = 0; i < EmbedList->count(); ++i)
+	{
+		QListWidgetItem* item = EmbedList->item(i);
+		QString fontName = item->text();
+		if (m_annotationFonts.contains(fontName))
+			continue;
+		const ScFace fontFace = AllFonts[fontName];
+		if (fontFace.isOTF() && !pdfVer.supportsEmbeddedOpenTypeFonts())
+		{
+			delete EmbedList->takeItem(i);
+			addFontItem(fontName, SubsetList);
+			--i;
+		}
+	}
+}
+
 QListWidgetItem* TabPDFOptions::addFontItem(const QString& fontName, QListWidget* fontList)
 {
 	QListWidgetItem* item = nullptr;
