@@ -16,6 +16,7 @@ for which a new license (GPL+exception) is in place.
 #include <QMouseEvent>
 #include <QPaintEvent>
 #include <QPainter>
+#include <QPalette>
 #include <QPixmap>
 #include <QPolygon>
 #include <QPushButton>
@@ -31,49 +32,40 @@ for which a new license (GPL+exception) is in place.
 #include "units.h"
 #include "util.h"
 
-RulerT::RulerT(QWidget *pa, int ein, const QList<ParagraphStyle::TabRecord>& Tabs, bool ind, double wid) : QWidget(pa),
-	mousePressed(false),
-	tabValues(Tabs),
+RulerT::RulerT(QWidget *pa, int unit, const QList<ParagraphStyle::TabRecord>& tabs, bool ind, double wid) : QWidget(pa),
+	tabValues(tabs),
 	haveInd(ind),
-	unitIndex(ein),
-	offset(0),
-	actTab(-1),
-	leftIndent(0),
-	firstLine(0),
-	Width(0.0),
-	rulerCode(0),
-	mouseX(0),
-	offsetIncrement(5)
+	unitIndex(unit)
 {
 	QPalette palette;
 	palette.setColor(backgroundRole(), QColor(255,255,255));
 	setPalette(palette);
-	iter=unitRulerGetIter1FromIndex(unitIndex);
-	iter2=unitRulerGetIter2FromIndex(unitIndex);
+	m_iter = unitRulerGetIter1FromIndex(unitIndex);
+	m_iter2 = unitRulerGetIter2FromIndex(unitIndex);
 
 	setMouseTracking(true);
 	if (wid < 0)
 	{
 		setMinimumSize(QSize(400,25));
 		setMaximumSize(QSize(4000,25));
-		Width = 4000;
+		m_rulerWidth = 4000;
 		resize(400, 25);
 	}
 	else
 	{
-		Width = wid;
-		setMinimumSize(QSize(qMin(static_cast<int>(Width), 400),25));
-		setMaximumSize(QSize(4000,25));
+		m_rulerWidth = wid;
+		setMinimumSize(QSize(qMin(static_cast<int>(m_rulerWidth), 400), 25));
+		setMaximumSize(QSize(4000, 25));
 		resize(qMin(static_cast<int>(wid), 400), 25);
 	}
 }
 
-void RulerT::setTabs(const QList<ParagraphStyle::TabRecord>& Tabs, int dEin)
+void RulerT::setTabs(const QList<ParagraphStyle::TabRecord>& tabs, int unit)
 {
-	unitIndex = dEin;
-	iter  = unitRulerGetIter1FromIndex(unitIndex);
-	iter2 = unitRulerGetIter2FromIndex(unitIndex);
-	tabValues = Tabs;
+	unitIndex = unit;
+	m_iter  = unitRulerGetIter1FromIndex(unitIndex);
+	m_iter2 = unitRulerGetIter2FromIndex(unitIndex);
+	tabValues = tabs;
 	actTab    = -1;
 	repaint();
 }
@@ -81,20 +73,25 @@ void RulerT::setTabs(const QList<ParagraphStyle::TabRecord>& Tabs, int dEin)
 void RulerT::paintEvent(QPaintEvent *)
 {
 	double xl;
+
+	const QPalette& palette = this->palette();
+	const QColor& textColor = palette.color(QPalette::Text);
+
 	QPainter p;
 	p.begin(this);
 	p.drawLine(0, 24, width(), 24);
 	p.translate(-offset, 0);
-	p.setBrush(Qt::black);
+	p.setBrush(textColor);
 	p.setFont(font());
-	p.setPen(QPen(Qt::black, 1, Qt::SolidLine, Qt::FlatCap, Qt::MiterJoin));
-	for (xl = 0; xl < width()+offset; xl += iter)
+	p.setPen(QPen(textColor, 1, Qt::SolidLine, Qt::FlatCap, Qt::MiterJoin));
+	for (xl = 0; xl < width() + offset; xl += m_iter)
 	{
 		if (xl < offset)
 			continue;
 		p.drawLine(qRound(xl), 18, qRound(xl), 24);
 	}
-	for (xl = 0; xl < width()+(iter2/2)+offset; xl += iter2)
+
+	for (xl = 0; xl < width() + (m_iter2 / 2) + offset; xl += m_iter2)
 	{
 		if (xl < offset)
 			continue;
@@ -104,69 +101,68 @@ void RulerT::paintEvent(QPaintEvent *)
 			case 2:
 			{
 				QString tx;
-				int num1 = static_cast<int>(xl / iter2);
+				int num1 = static_cast<int>(xl / m_iter2);
 				if (num1 != 0)
 					tx = QString::number(num1);
-				double frac = (xl / iter2) - num1;
+				double frac = (xl / m_iter2) - num1;
 				if ((frac > 0.24) && (frac < 0.26))
 					tx += QChar(0xBC);
 				if ((frac > 0.49) && (frac < 0.51))
 					tx += QChar(0xBD);
 				if ((frac > 0.74) && (frac < 0.76))
 					tx += QChar(0xBE);
-				p.drawText(qRound(xl+2), 17, tx);
+				p.drawText(qRound(xl + 2), 17, tx);
 				break;
 			}
 			case 3:
-				p.drawText(qRound(xl+2), 17, QString::number(xl / iter));
+				p.drawText(qRound(xl + 2), 17, QString::number(xl / m_iter));
 				break;
 			default:
-				p.drawText(qRound(xl+2), 17, QString::number(xl / iter * 10));
+				p.drawText(qRound(xl + 2), 17, QString::number(xl / m_iter * 10));
 				break;
 		}
 	}
-	if (tabValues.count() != 0)
+
+	for (int i = 0; i < tabValues.count(); i++)
 	{
-		for (int yg = 0; yg < static_cast<int>(tabValues.count()); yg++)
+		if (i == actTab)
+			p.setPen(QPen(Qt::red, 2, Qt::SolidLine, Qt::FlatCap, Qt::MiterJoin));
+		else
+			p.setPen(QPen(textColor, 2, Qt::SolidLine, Qt::FlatCap, Qt::MiterJoin));
+		switch (static_cast<int>(tabValues[i].tabType))
 		{
-			if (yg == actTab)
-				p.setPen(QPen(Qt::red, 2, Qt::SolidLine, Qt::FlatCap, Qt::MiterJoin));
-			else
-				p.setPen(QPen(Qt::black, 2, Qt::SolidLine, Qt::FlatCap, Qt::MiterJoin));
-			switch (static_cast<int>(tabValues[yg].tabType))
-			{
-				case 0:
-					p.drawLine(qRound(tabValues[yg].tabPosition), 15, qRound(tabValues[yg].tabPosition), 23);
-					p.drawLine(qRound(tabValues[yg].tabPosition), 23, qRound(tabValues[yg].tabPosition+8), 23);
-					break;
-				case 1:
-					p.drawLine(qRound(tabValues[yg].tabPosition), 15, qRound(tabValues[yg].tabPosition), 23);
-					p.drawLine(qRound(tabValues[yg].tabPosition), 23, qRound(tabValues[yg].tabPosition-8), 23);
-					break;
-				case 2:
-				case 3:
-					p.drawLine(qRound(tabValues[yg].tabPosition), 15, qRound(tabValues[yg].tabPosition), 23);
-					p.drawLine(qRound(tabValues[yg].tabPosition-4), 23, qRound(tabValues[yg].tabPosition+4), 23);
-					p.drawLine(qRound(tabValues[yg].tabPosition+3), 20, qRound(tabValues[yg].tabPosition+2), 20);
-					break;
-				case 4:
-					p.drawLine(qRound(tabValues[yg].tabPosition), 15, qRound(tabValues[yg].tabPosition), 23);
-					p.drawLine(qRound(tabValues[yg].tabPosition-4), 23, qRound(tabValues[yg].tabPosition+4), 23);
-					break;
-				default:
-					break;
-			}
+			case 0:
+				p.drawLine(qRound(tabValues[i].tabPosition), 15, qRound(tabValues[i].tabPosition), 23);
+				p.drawLine(qRound(tabValues[i].tabPosition), 23, qRound(tabValues[i].tabPosition + 8), 23);
+				break;
+			case 1:
+				p.drawLine(qRound(tabValues[i].tabPosition), 15, qRound(tabValues[i].tabPosition), 23);
+				p.drawLine(qRound(tabValues[i].tabPosition), 23, qRound(tabValues[i].tabPosition - 8), 23);
+				break;
+			case 2:
+			case 3:
+				p.drawLine(qRound(tabValues[i].tabPosition), 15, qRound(tabValues[i].tabPosition), 23);
+				p.drawLine(qRound(tabValues[i].tabPosition - 4), 23, qRound(tabValues[i].tabPosition + 4), 23);
+				p.drawLine(qRound(tabValues[i].tabPosition + 3), 20, qRound(tabValues[i].tabPosition + 2), 20);
+				break;
+			case 4:
+				p.drawLine(qRound(tabValues[i].tabPosition), 15, qRound(tabValues[i].tabPosition), 23);
+				p.drawLine(qRound(tabValues[i].tabPosition - 4), 23, qRound(tabValues[i].tabPosition + 4), 23);
+				break;
+			default:
+				break;
 		}
 	}
+
 	if (haveInd)
 	{
 		p.setPen(QPen(Qt::blue, 1, Qt::SolidLine, Qt::FlatCap, Qt::MiterJoin));
 		p.setBrush(Qt::blue);
 		QPolygon cr;
-		cr.setPoints(3, qRound(firstLine+leftIndent), 12, qRound(firstLine+leftIndent-4), 0, qRound(firstLine+leftIndent+4), 0);
+		cr.setPoints(3, qRound(firstLine + leftIndent), 12, qRound(firstLine + leftIndent - 4), 0, qRound(firstLine + leftIndent + 4), 0);
 		p.drawPolygon(cr);
 		QPolygon cr2;
-		cr2.setPoints(3, qRound(leftIndent), 12, qRound(leftIndent+4), 24, qRound(leftIndent-4), 24);
+		cr2.setPoints(3, qRound(leftIndent), 12, qRound(leftIndent + 4), 24, qRound(leftIndent - 4), 24);
 		p.drawPolygon(cr2);
 	}
 	p.end();
@@ -180,14 +176,14 @@ void RulerT::mousePressEvent(QMouseEvent *m)
 	rulerCode = 0;
 	if (haveInd)
 	{
-		fpo = QRect(static_cast<int>(firstLine+leftIndent-offset)-4, 0, 8, 12);
+		fpo = QRect(static_cast<int>(firstLine + leftIndent - offset) - 4, 0, 8, 12);
 		if (fpo.contains(m->pos()))
 		{
 			rulerCode = 1;
 			mouseX = m->x();
 			return;
 		}
-		fpo = QRect(static_cast<int>(leftIndent-offset)-4, 12, 8, 12);
+		fpo = QRect(static_cast<int>(leftIndent - offset) - 4, 12, 8, 12);
 		if (fpo.contains(m->pos()))
 		{
 			rulerCode = 2;
@@ -197,13 +193,13 @@ void RulerT::mousePressEvent(QMouseEvent *m)
 	}
 	if (tabValues.count() != 0)
 	{
-		for (int yg = 0; yg < static_cast<int>(tabValues.count()); yg++)
+		for (int i = 0; i < tabValues.count(); ++i)
 		{
-			fpo = QRect(static_cast<int>(tabValues[yg].tabPosition-offset)-3, 15, 8, 8);
+			fpo = QRect(static_cast<int>(tabValues[i].tabPosition - offset) - 3, 15, 8, 8);
 			if (fpo.contains(m->pos()))
 			{
 				rulerCode = 3;
-				actTab = yg;
+				actTab = i;
 				mouseX = m->x();
 				emit tabSelected();
 				emit typeChanged(tabValues[actTab].tabType);
@@ -284,10 +280,10 @@ void RulerT::mouseMoveEvent(QMouseEvent *m)
 		{
 			case 1:
 				firstLine -= mouseX - m->x();
-				if (firstLine+leftIndent+offset < offset)
+				if (firstLine + leftIndent + offset < offset)
 					firstLine += mouseX - m->x();
-				if (firstLine+leftIndent > Width)
-					firstLine  = Width-leftIndent;
+				if (firstLine + leftIndent > m_rulerWidth)
+					firstLine  = m_rulerWidth - leftIndent;
 				emit firstLineMoved(firstLine);
 				repaint();
 				break;
@@ -296,8 +292,8 @@ void RulerT::mouseMoveEvent(QMouseEvent *m)
 				leftIndent -= mouseX - m->x();
 				if (leftIndent < 0)
 					leftIndent = 0;
-				if (leftIndent > Width-1)
-					leftIndent  = Width-1;
+				if (leftIndent > m_rulerWidth - 1)
+					leftIndent  = m_rulerWidth - 1;
 				firstLine = oldInd - leftIndent;
 				emit leftIndentMoved(leftIndent);
 				emit firstLineMoved(firstLine);
@@ -307,8 +303,8 @@ void RulerT::mouseMoveEvent(QMouseEvent *m)
 				tabValues[actTab].tabPosition -= mouseX - m->x();
 				if (tabValues[actTab].tabPosition < 0)
 					tabValues[actTab].tabPosition = 0;
-				if (tabValues[actTab].tabPosition > Width-1)
-					tabValues[actTab].tabPosition = Width-1;
+				if (tabValues[actTab].tabPosition > m_rulerWidth - 1)
+					tabValues[actTab].tabPosition = m_rulerWidth - 1;
 				updateTabList();
 				emit tabMoved(tabValues[actTab].tabPosition);
 				repaint();
@@ -324,13 +320,13 @@ void RulerT::mouseMoveEvent(QMouseEvent *m)
 		setCursor(IconManager::instance().loadCursor("tab.png", 3));
 		if (haveInd)
 		{
-			fpo = QRect(static_cast<int>(firstLine+leftIndent-offset)-4, 0, 8, 12);
+			fpo = QRect(static_cast<int>(firstLine + leftIndent - offset) - 4, 0, 8, 12);
 			if (fpo.contains(m->pos()))
 			{
 				setCursor(QCursor(Qt::SizeHorCursor));
 				return;
 			}
-			fpo = QRect(static_cast<int>(leftIndent-offset)-4, 12, 8, 12);
+			fpo = QRect(static_cast<int>(leftIndent - offset) - 4, 12, 8, 12);
 			if (fpo.contains(m->pos()))
 			{
 				setCursor(QCursor(Qt::SizeHorCursor));
@@ -339,9 +335,9 @@ void RulerT::mouseMoveEvent(QMouseEvent *m)
 		}
 		if (tabValues.count() != 0)
 		{
-			for (int yg = 0; yg < static_cast<int>(tabValues.count()); yg++)
+			for (int i = 0; i < static_cast<int>(tabValues.count()); ++i)
 			{
-				fpo = QRect(static_cast<int>(tabValues[yg].tabPosition-offset)-3, 15, 8, 8);
+				fpo = QRect(static_cast<int>(tabValues[i].tabPosition-offset) - 3, 15, 8, 8);
 				if (fpo.contains(m->pos()))
 				{
 					setCursor(QCursor(Qt::SizeHorCursor));
@@ -376,10 +372,10 @@ void RulerT::updateTabList()
 	int gg = static_cast<int>(tabValues.count()-1);
 	int g = gg;
 	tabValues.removeAt(actTab);
-	for (int yg = static_cast<int>(tabValues.count()-1); yg > -1; yg--)
+	for (int i = tabValues.count() - 1; i > -1; --i)
 	{
-		if (tb.tabPosition < tabValues[yg].tabPosition)
-			g = yg;
+		if (tb.tabPosition < tabValues[i].tabPosition)
+			g = i;
 	}
 	actTab = g;
 	if (gg == g)
@@ -404,7 +400,7 @@ void RulerT::increaseOffset()
 	offsetIncrement++;
 	if (offsetIncrement > 30)
 		offsetIncrement = 30;
-	if (offset + width() > static_cast<int>(Width))
+	if (offset + width() > static_cast<int>(m_rulerWidth))
 		offset -= 5;
 	repaint();
 }
@@ -471,9 +467,9 @@ void RulerT::moveFirstLine(double t)
 		firstLine = 0-leftIndent;
 		emit firstLineMoved(firstLine);
 	}
-	if (firstLine+leftIndent > Width)
+	if (firstLine+leftIndent > m_rulerWidth)
 	{
-		firstLine = Width-leftIndent;
+		firstLine = m_rulerWidth - leftIndent;
 		emit firstLineMoved(firstLine);
 	}
 	repaint();
@@ -481,11 +477,11 @@ void RulerT::moveFirstLine(double t)
 
 void RulerT::moveLeftIndent(double t)
 {
-	double oldInd = leftIndent+firstLine;
+	double oldInd = leftIndent + firstLine;
 	leftIndent = t;
-	if (leftIndent > Width-1)
+	if (leftIndent > m_rulerWidth - 1)
 	{
-		leftIndent  = Width-1;
+		leftIndent  = m_rulerWidth - 1;
 		emit leftIndentMoved(leftIndent);
 	}
 	firstLine = oldInd - leftIndent;
@@ -493,28 +489,22 @@ void RulerT::moveLeftIndent(double t)
 	repaint();
 }
 
-Tabruler::Tabruler( QWidget* parent, bool haveFirst, int dEin, const QList<ParagraphStyle::TabRecord>& Tabs, double wid ) : QWidget( parent ),
-	firstLineLabel(nullptr),
-	leftIndentLabel(nullptr),
-	rightIndentLabel(nullptr),
-	firstLineData(nullptr),
-	leftIndentData(nullptr),
-	rightIndentData(nullptr)
+Tabruler::Tabruler( QWidget* parent, bool haveFirst, int unit, const QList<ParagraphStyle::TabRecord>& tabs, double wid ): QWidget( parent )
 {
-	m_docUnitRatio=unitGetRatioFromIndex(dEin);
+	m_docUnitRatio = unitGetRatioFromIndex(unit);
 	double ww = (wid < 0) ? 4000 : wid;
 	tabrulerLayout = new QVBoxLayout( this );
-	tabrulerLayout->setMargin(0);
-	tabrulerLayout->setSpacing(5);
+	tabrulerLayout->setContentsMargins(0, 0, 0, 0);
+	tabrulerLayout->setSpacing(6);
 	layout2 = new QHBoxLayout;
-	layout2->setMargin(0);
-	layout2->setSpacing(5);
+	layout2->setContentsMargins(0, 0, 0, 0);
+	layout2->setSpacing(6);
 
 	rulerScrollL = new QToolButton(this);
 	rulerScrollL->setArrowType(Qt::LeftArrow);
 	rulerScrollL->setAutoRepeat( true );
 	layout2->addWidget( rulerScrollL );
-	ruler = new RulerT( this, dEin, Tabs, haveFirst, wid );
+	ruler = new RulerT( this, unit, tabs, haveFirst, wid );
 	ruler->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Minimum);
 	layout2->addWidget( ruler );
 	rulerScrollR = new QToolButton(this);
@@ -523,8 +513,8 @@ Tabruler::Tabruler( QWidget* parent, bool haveFirst, int dEin, const QList<Parag
 	layout2->addWidget( rulerScrollR );
 
 	layout1 = new QHBoxLayout;
-	layout1->setMargin(0);
-	layout1->setSpacing(5);
+	layout1->setContentsMargins(0, 0, 0, 0);
+	layout1->setSpacing(6);
 	layout1->setAlignment( Qt::AlignTop );
 	typeCombo = new QComboBox(this);
 	typeCombo->setEditable(false);
@@ -535,7 +525,7 @@ Tabruler::Tabruler( QWidget* parent, bool haveFirst, int dEin, const QList<Parag
 	typeCombo->addItem( tr( "Comma" ) );
 	typeCombo->addItem( tr( "Center" ) );
 	layout1->addWidget( typeCombo );
-	tabData = new ScrSpinBox( 0, ww / m_docUnitRatio, this, dEin );
+	tabData = new ScrSpinBox( 0, ww / m_docUnitRatio, this, unit );
 	tabData->setValue(0);
 	positionLabel = new QLabel( tr("&Position:"), this );
 	positionLabel->setBuddy(tabData);
@@ -552,47 +542,41 @@ Tabruler::Tabruler( QWidget* parent, bool haveFirst, int dEin, const QList<Parag
 	tabFillComboT->setBuddy(tabFillCombo);
 	layout1->addWidget( tabFillComboT );
 	layout1->addWidget( tabFillCombo );
-
-	layout4 = new QHBoxLayout;
-	layout4->setMargin(0);
-	layout4->setSpacing(5);
+	clearOneButton = new QToolButton( this );
+	clearOneButton->setIcon(IconManager::instance().loadIcon("16/edit-delete.png"));
+	layout1->addSpacing(12);
+	layout1->addWidget(clearOneButton);
+	clearButton = new QToolButton( this );
+	clearButton->setIcon(IconManager::instance().loadIcon("16/edit-delete-all.png"));
+	layout1->addWidget(clearButton);
 
 	indentLayout = new QHBoxLayout;
-	indentLayout->setMargin(0);
-	indentLayout->setSpacing(5);
+	indentLayout->setContentsMargins(0, 0, 0, 0);
+	indentLayout->setSpacing(6);
 	if (haveFirst)
 	{
-		firstLineData = new ScrSpinBox( -3000, ww / m_docUnitRatio, this, dEin);
+		firstLineData = new ScrSpinBox( -3000, ww / m_docUnitRatio, this, unit);
 		firstLineData->setValue(0);
 		firstLineLabel = new QLabel(this);
 		firstLineLabel->setText("");
 		firstLineLabel->setPixmap(IconManager::instance().loadPixmap("firstline.png"));
 		indentLayout->addWidget( firstLineLabel );
 		indentLayout->addWidget( firstLineData );
-		leftIndentData = new ScrSpinBox( 0, ww / m_docUnitRatio, this, dEin );
+		leftIndentData = new ScrSpinBox( 0, ww / m_docUnitRatio, this, unit);
 		leftIndentData->setValue(0);
 		leftIndentLabel = new QLabel(this);
 		leftIndentLabel->setText("");
 		leftIndentLabel->setPixmap(IconManager::instance().loadPixmap("leftindent.png"));
-		layout4->addWidget( leftIndentLabel );
-		layout4->addWidget( leftIndentData );
-		layout4->addStretch(10);
+		indentLayout->addWidget(leftIndentLabel);
+		indentLayout->addWidget(leftIndentData);
 		rightIndentLabel = new QLabel(this);
 		rightIndentLabel->setText("");
 		rightIndentLabel->setPixmap(IconManager::instance().loadPixmap("rightindent.png"));
-		rightIndentData = new ScrSpinBox(0, ww / m_docUnitRatio, this, dEin);
+		rightIndentData = new ScrSpinBox(0, ww / m_docUnitRatio, this, unit);
 		rightIndentData->setValue(0);
 		indentLayout->addWidget(rightIndentLabel);
 		indentLayout->addWidget(rightIndentData);
 	}
-	clearButton = new QPushButton( this );
-	clearButton->setText( tr( "Delete All" ) );
-	indentLayout->addSpacing(20);
-	indentLayout->addWidget( clearButton);
-	clearOneButton = new QPushButton( this );
-	clearOneButton->setText( tr( "Delete Selected" ) );
-	indentLayout->addWidget( clearOneButton);
-	indentLayout->addStretch(10);
 	if (!haveFirst)
 	{
 		QSpacerItem* spacer = new QSpacerItem( 20, 20, QSizePolicy::Expanding, QSizePolicy::Minimum );
@@ -604,12 +588,11 @@ Tabruler::Tabruler( QWidget* parent, bool haveFirst, int dEin, const QList<Parag
 	tabrulerLayout->addLayout( layout2 );
 	indentLayout->addStretch( 10 );
 	tabrulerLayout->addLayout( indentLayout );
-	tabrulerLayout->addLayout(layout4);
 
 	tabData->setEnabled(false);
 	tabFillCombo->setEnabled(false);
 	typeCombo->setEnabled(false);
-	if (Tabs.count() == 0)
+	if (tabs.count() == 0)
 		clearButton->setEnabled(false);
 	clearOneButton->setEnabled(false);
 	resize( minimumSizeHint() );
@@ -654,8 +637,7 @@ Tabruler::Tabruler( QWidget* parent, bool haveFirst, int dEin, const QList<Parag
 	clearButton->setToolTip( tr( "Delete all Tabulators" ) );
 	clearOneButton->setToolTip( tr("Delete selected Tabulator"));
 
-	QString ein = unitGetSuffixFromIndex(dEin);
-	if (dEin == 2)
+	if (unit == SC_INCHES)
 	{
 		if (haveFirst)
 		{
@@ -665,13 +647,6 @@ Tabruler::Tabruler( QWidget* parent, bool haveFirst, int dEin, const QList<Parag
 		}
 		tabData->setDecimals(4);
 	}
-	if (haveFirst)
-	{
-		firstLineData->setSuffix(ein);
-		leftIndentData->setSuffix(ein);
-		rightIndentData->setSuffix(ein);
-	}
-	tabData->setSuffix(ein);
 	m_haveFirst = haveFirst;
 
 	connect(ScQApp, SIGNAL(iconSetChanged()), this, SLOT(iconSetChange()));
@@ -696,9 +671,12 @@ void Tabruler::iconSetChange()
 
 	if (leftIndentLabel)
 		leftIndentLabel->setPixmap(iconManager.loadPixmap("leftindent.png"));
-	
+
 	if (rightIndentLabel)
 		rightIndentLabel->setPixmap(iconManager.loadPixmap("rightindent.png"));
+
+	clearOneButton->setIcon(iconManager.loadIcon("16/edit-delete.png"));
+	clearButton->setIcon(iconManager.loadIcon("16/edit-delete-all.png"));
 }
 
 void Tabruler::languageChange()
@@ -758,18 +736,18 @@ void Tabruler::languageChange()
 	tabData->setSuffix(unitSuffix);
 }
 
-void Tabruler::setTabs(const QList<ParagraphStyle::TabRecord>& Tabs, int dEin)
+void Tabruler::setTabs(const QList<ParagraphStyle::TabRecord>& tabs, int unit)
 {
-	m_docUnitRatio = unitGetRatioFromIndex(dEin);
-	tabData->setNewUnit(dEin);
+	m_docUnitRatio = unitGetRatioFromIndex(unit);
+	tabData->setNewUnit(unit);
 	if (m_haveFirst)
 	{
-		firstLineData->setNewUnit(dEin);
-		leftIndentData->setNewUnit(dEin);
-		rightIndentData->setNewUnit(dEin);
+		firstLineData->setNewUnit(unit);
+		leftIndentData->setNewUnit(unit);
+		rightIndentData->setNewUnit(unit);
 	}
-	ruler->setTabs(Tabs, dEin);
-	if (Tabs.count() == 0)
+	ruler->setTabs(tabs, unit);
+	if (tabs.count() == 0)
 		clearButton->setEnabled(false);
 	clearOneButton->setEnabled(false);
 	tabData->setEnabled(false);
@@ -883,35 +861,32 @@ void Tabruler::setTabFillChar(QChar t)
 		tabFillCombo->setEditable(false);
 		tabFillCombo->setCurrentIndex(0);
 	}
+	else if (t == '.')
+	{
+		tabFillCombo->setEditable(false);
+		tabFillCombo->setCurrentIndex(1);
+	}
+	else if (t == '-')
+	{
+		tabFillCombo->setEditable(false);
+		tabFillCombo->setCurrentIndex(2);
+	}
+	else if (t == '_')
+	{
+		tabFillCombo->setEditable(false);
+		tabFillCombo->setCurrentIndex(3);
+	}
 	else
-		if (t == '.')
+	{
+		tabFillCombo->setCurrentIndex(4);
+		tabFillCombo->setEditable(true);
+		if (!t.isNull())
 		{
-			tabFillCombo->setEditable(false);
-			tabFillCombo->setCurrentIndex(1);
+			bool sigBlocked = tabFillCombo->blockSignals(true);
+			tabFillCombo->setEditText(QString(t));
+			tabFillCombo->blockSignals(sigBlocked);
 		}
-		else
-			if (t == '-')
-			{
-				tabFillCombo->setEditable(false);
-				tabFillCombo->setCurrentIndex(2);
-			}
-			else
-				if (t == '_')
-				{
-					tabFillCombo->setEditable(false);
-					tabFillCombo->setCurrentIndex(3);
-				}
-				else
-				{
-					tabFillCombo->setCurrentIndex(4);
-					tabFillCombo->setEditable(true);
-					if (!t.isNull())
-					{
-						bool sigBlocked = tabFillCombo->blockSignals(true);
-						tabFillCombo->setEditText(QString(t));
-						tabFillCombo->blockSignals(sigBlocked);
-					}
-				}
+	}
 	emit tabrulerChanged();
 	emit tabsChanged();
 }
