@@ -42,7 +42,7 @@ public:
 	bool userActionOn(); // not yet implemented!!! This is needed badly.
                          // When user releases the mouse button or arrow key, changes must be checked
                          // and if in ScribusView a groupTransaction has been started it must be also
-                         // commmited
+                         // committed
 
 	PropertiesPalette_Text*  textPal { nullptr };
 
@@ -77,8 +77,6 @@ protected:
 	UndoManager *undoManager { nullptr };
 	
 	ScGuardedPtr<ScribusDoc> m_doc;
-	
-	int idTextItem;
 
 	void changeEvent(QEvent *e) override;
 	void closeEvent(QCloseEvent *closeEvent) override;
