@@ -30,11 +30,8 @@ for which a new license (GPL+exception) is in place.
 #include "util.h"
 #include "util_math.h"
 
-Tpalette::Tpalette(QWidget* parent) : QWidget(parent)
+TransparencyPalette::TransparencyPalette(QWidget* parent) : QWidget(parent)
 {
-	currentItem = nullptr;
-	patternList = nullptr;
-	TGradDia = nullptr;
 	TGradDia = new GradientVectorDialog(this->parentWidget());
 	TGradDia->hide();
 	setupUi(this);
@@ -44,6 +41,7 @@ Tpalette::Tpalette(QWidget* parent) : QWidget(parent)
 	strokeOpacity->setDecimals(0);
 	fillOpacity->setDecimals(0);
 	editFillSelectorButton();
+
 	connect(editLineSelector, SIGNAL(clicked()), this, SLOT(editLineSelectorButton()));
 	connect(editFillSelector, SIGNAL(clicked()), this, SLOT(editFillSelectorButton()));
 	connect(strokeOpacity, SIGNAL(valueChanged(double)), this, SLOT(slotTransS(double)));
@@ -64,7 +62,7 @@ Tpalette::Tpalette(QWidget* parent) : QWidget(parent)
 	connect(usePatternInverted, SIGNAL(clicked()), this, SLOT(switchPatternMode()));
 }
 
-void Tpalette::connectSignals()
+void TransparencyPalette::connectSignals()
 {
 	connect(gradEdit, SIGNAL(gradientChanged()), this, SIGNAL(gradientChanged()));
 	connect(namedGradient, SIGNAL(activated(const QString &)), this, SLOT(setNamedGradient(const QString &)));
@@ -75,7 +73,7 @@ void Tpalette::connectSignals()
 	connect(usePatternInverted, SIGNAL(clicked()), this, SLOT(switchPatternMode()));
 }
 
-void Tpalette::disconnectSignals()
+void TransparencyPalette::disconnectSignals()
 {
 	disconnect(gradEdit, SIGNAL(gradientChanged()), this, SIGNAL(gradientChanged()));
 	disconnect(namedGradient, SIGNAL(activated(const QString &)), this, SLOT(setNamedGradient(const QString &)));
@@ -86,7 +84,7 @@ void Tpalette::disconnectSignals()
 	disconnect(usePatternInverted, SIGNAL(clicked()), this, SLOT(switchPatternMode()));
 }
 
-void Tpalette::setCurrentItem(PageItem* item)
+void TransparencyPalette::setCurrentItem(PageItem* item)
 {
 	currentItem = item;
 	disconnectSignals();
@@ -94,6 +92,11 @@ void Tpalette::setCurrentItem(PageItem* item)
 	if (!currentItem || !currentDoc)
 		return;
 
+	if (currentItem->isGroup())
+		hideSelectionButtons();
+	else
+		showSelectionButtons();
+
 	setActTrans(currentItem->fillTransparency(), currentItem->lineTransparency());
 	setActBlend(currentItem->fillBlendmode(), currentItem->lineBlendmode());
 	gradEdit->setGradient(currentItem->mask_gradient);
@@ -113,7 +116,7 @@ void Tpalette::setCurrentItem(PageItem* item)
 		tabWidget->setCurrentIndex(1);
 	else
 		tabWidget->setCurrentIndex(2);
-	if (patternList->count() == 0)
+	if (patternList->isEmpty())
 		tabWidget->setTabEnabled(2, false);
 	else
 		tabWidget->setTabEnabled(2, true);
@@ -141,7 +144,7 @@ void Tpalette::setCurrentItem(PageItem* item)
 	connectSignals();
 }
 
-void Tpalette::setDocument(ScribusDoc* doc)
+void TransparencyPalette::setDocument(ScribusDoc* doc)
 {
 	this->disconnect(SIGNAL(NewTrans(double)));
 	this->disconnect(SIGNAL(NewTransS(double)));
@@ -176,13 +179,13 @@ void Tpalette::setDocument(ScribusDoc* doc)
 	}
 }
 
-void Tpalette::handleUpdateRequest(int updateFlags)
+void TransparencyPalette::handleUpdateRequest(int updateFlags)
 {
 	if (updateFlags & reqColorsUpdate)
 		updateColorList();
 }
 
-void Tpalette::updateColorList()
+void TransparencyPalette::updateColorList()
 {
 	if (!currentDoc)
 		return;
@@ -198,35 +201,44 @@ void Tpalette::updateColorList()
 		setCurrentItem(currentItem);
 }
 
-void Tpalette::hideSelectionButtons()
+void TransparencyPalette::showSelectionButtons()
+{
+	editLineSelector->show();
+	editLineSelector->setSizePolicy(QSizePolicy(QSizePolicy::Fixed, QSizePolicy::Fixed));
+	editFillSelector->show();
+	editFillSelector->setSizePolicy(QSizePolicy(QSizePolicy::Fixed, QSizePolicy::Fixed));
+}
+void TransparencyPalette::hideSelectionButtons()
 {
 	editLineSelector->hide();
 	editLineSelector->setSizePolicy(QSizePolicy(QSizePolicy::Ignored, QSizePolicy::Ignored));
 	editFillSelector->hide();
 	editFillSelector->setSizePolicy(QSizePolicy(QSizePolicy::Ignored, QSizePolicy::Ignored));
+	stackedWidget->setCurrentIndex(1);
+	editFillSelector->setChecked(true);
 }
 
-void Tpalette::updateFromItem()
+void TransparencyPalette::updateFromItem()
 {
 	setCurrentItem(currentItem);
 }
 
-void Tpalette::updateCList()
+void TransparencyPalette::updateCList()
 {
 	gradEdit->setColors(colorList);
 }
 
-void Tpalette::updateGradientList()
+void TransparencyPalette::updateGradientList()
 {
 	disconnect(namedGradient, SIGNAL(activated(const QString &)), this, SLOT(setNamedGradient(const QString &)));
 	namedGradient->clear();
 	namedGradient->setIconSize(QSize(48, 12));
 	namedGradient->addItem( tr("Custom"));
 	QStringList patK = gradientList->keys();
-	qSort(patK);
-	for (int a = 0; a < patK.count(); a++)
+	patK.sort();
+	for (int i = 0; i < patK.count(); i++)
 	{
-		VGradient gr = gradientList->value(patK[a]);
+		VGradient gr = gradientList->value(patK[i]);
 		QImage pixm(48, 12, QImage::Format_ARGB32_Premultiplied);
 		QPainter pb;
 		QBrush b(QColor(205,205,205), IconManager::instance().loadPixmap("testfill.png"));
@@ -235,7 +247,7 @@ void Tpalette::updateGradientList()
 		pb.end();
 		ScPainter *p = new ScPainter(&pixm, 48, 12);
 		p->setPen(Qt::black, 1, Qt::SolidLine, Qt::FlatCap, Qt::MiterJoin);
-		p->setFillMode(2);
+		p->setFillMode(ScPainter::Gradient);
 		p->fill_gradient = gr;
 		p->setGradient(VGradient::linear, FPoint(0,6), FPoint(48, 6), FPoint(0,0), 1, 0);
 		p->drawRect(0, 0, 48, 12);
@@ -243,25 +255,25 @@ void Tpalette::updateGradientList()
 		delete p;
 		QPixmap pm;
 		pm = QPixmap::fromImage(pixm);
-		namedGradient->addItem(pm, patK[a]);
+		namedGradient->addItem(pm, patK[i]);
 	}
 	connect(namedGradient, SIGNAL(activated(const QString&)), this, SLOT(setNamedGradient(const QString&)));
 }
 
-void Tpalette::setGradients(QHash<QString, VGradient> *docGradients)
+void TransparencyPalette::setGradients(QHash<QString, VGradient> *docGradients)
 {
 	gradientList = docGradients;
 	updateGradientList();
 }
 
-void Tpalette::setColors(const ColorList& newColorList)
+void TransparencyPalette::setColors(const ColorList& newColorList)
 {
 	colorList.clear();
 	colorList = newColorList;
 	updateCList();
 }
 
-void Tpalette::slotGrad(int number)
+void TransparencyPalette::slotGrad(int number)
 {
 	if (number == 1)
 	{
@@ -281,16 +293,16 @@ void Tpalette::slotGrad(int number)
 		if (gradientType->currentIndex() == 0)
 		{
 			if (transpCalcGradient->isChecked())
-				emit NewGradient(4);
+				emit NewGradient(GradMask_LinearLumAlpha);
 			else
-				emit NewGradient(1);
+				emit NewGradient(GradMask_Linear);
 		}
 		else
 		{
 			if (transpCalcGradient->isChecked())
-				emit NewGradient(5);
+				emit NewGradient(GradMask_RadialLumAlpha);
 			else
-				emit NewGradient(2);
+				emit NewGradient(GradMask_Radial);
 		}
 		connect(namedGradient, SIGNAL(activated(const QString &)), this, SLOT(setNamedGradient(const QString &)));
 	}
@@ -299,41 +311,41 @@ void Tpalette::slotGrad(int number)
 		if (transpCalcPattern->isChecked())
 		{
 			if (usePatternInverted->isChecked())
-				emit NewGradient(7);
+				emit NewGradient(GradMask_PatternLumAlphaInverted);
 			else
-				emit NewGradient(6);
+				emit NewGradient(GradMask_PatternLumAlpha);
 		}
 		else
 		{
 			if (usePatternInverted->isChecked())
-				emit NewGradient(8);
+				emit NewGradient(GradMask_PatternInverted);
 			else
-				emit NewGradient(3);
+				emit NewGradient(GradMask_Pattern);
 		}
 	}
 	else
-		emit NewGradient(0);
+		emit NewGradient(GradMask_None);
 }
 
-void Tpalette::slotGradType(int type)
+void TransparencyPalette::slotGradType(int type)
 {
 	if (type == 0)
 	{
 		if (transpCalcGradient->isChecked())
-			emit NewGradient(4);
+			emit NewGradient(GradMask_LinearLumAlpha);
 		else
-			emit NewGradient(1);
+			emit NewGradient(GradMask_Linear);
 	}
 	else
 	{
 		if (transpCalcGradient->isChecked())
-			emit NewGradient(5);
+			emit NewGradient(GradMask_RadialLumAlpha);
 		else
-			emit NewGradient(2);
+			emit NewGradient(GradMask_Radial);
 	}
 }
 
-void Tpalette::setNamedGradient(const QString &name)
+void TransparencyPalette::setNamedGradient(const QString &name)
 {
 	if (namedGradient->currentIndex() == 0)
 	{
@@ -350,62 +362,62 @@ void Tpalette::setNamedGradient(const QString &name)
 	if (gradientType->currentIndex() == 0)
 	{
 		if (transpCalcGradient->isChecked())
-			emit NewGradient(4);
+			emit NewGradient(GradMask_LinearLumAlpha);
 		else
-			emit NewGradient(1);
+			emit NewGradient(GradMask_Linear);
 	}
 	else
 	{
 		if (transpCalcGradient->isChecked())
-			emit NewGradient(5);
+			emit NewGradient(GradMask_RadialLumAlpha);
 		else
-			emit NewGradient(2);
+			emit NewGradient(GradMask_Radial);
 	}
 }
 
-void Tpalette::switchGradientMode()
+void TransparencyPalette::switchGradientMode()
 {
 	if (gradientType->currentIndex() == 0)
 	{
 		if (transpCalcGradient->isChecked())
-			emit NewGradient(4);
+			emit NewGradient(GradMask_LinearLumAlpha);
 		else
-			emit NewGradient(1);
+			emit NewGradient(GradMask_Linear);
 	}
 	else
 	{
 		if (transpCalcGradient->isChecked())
-			emit NewGradient(5);
+			emit NewGradient(GradMask_RadialLumAlpha);
 		else
-			emit NewGradient(2);
+			emit NewGradient(GradMask_Radial);
 	}
 }
 
-void Tpalette::switchPatternMode()
+void TransparencyPalette::switchPatternMode()
 {
 	if (transpCalcPattern->isChecked())
 	{
 		if (usePatternInverted->isChecked())
-			emit NewGradient(7);
+			emit NewGradient(GradMask_PatternLumAlphaInverted);
 		else
-			emit NewGradient(6);
+			emit NewGradient(GradMask_PatternLumAlpha);
 	}
 	else
 	{
 		if (usePatternInverted->isChecked())
-			emit NewGradient(8);
+			emit NewGradient(GradMask_PatternInverted);
 		else
-			emit NewGradient(3);
+			emit NewGradient(GradMask_Pattern);
 	}
 }
 
-void Tpalette::editGradientVector()
+void TransparencyPalette::editGradientVector()
 {
 	if (gradEditButton->isChecked())
 	{
 		TGradDia->unitChange(currentDoc->unitIndex());
 		TGradDia->setValues(currentItem->GrMaskStartX, currentItem->GrMaskStartY, currentItem->GrMaskEndX, currentItem->GrMaskEndY, currentItem->GrMaskFocalX, currentItem->GrMaskFocalY, currentItem->GrMaskScale, currentItem->GrMaskSkew, 0, 0);
-		if ((currentItem->GrMask == 1) || (currentItem->GrMask == 4))
+		if ((currentItem->GrMask == GradMask_Linear) || (currentItem->GrMask == GradMask_LinearLumAlpha))
 			TGradDia->selectLinear();
 		else
 			TGradDia->selectRadial();
@@ -418,7 +430,7 @@ void Tpalette::editGradientVector()
 	emit editGradient();
 }
 
-void Tpalette::setActiveGradDia(bool active)
+void TransparencyPalette::setActiveGradDia(bool active)
 {
 	if (!active)
 	{
@@ -427,13 +439,13 @@ void Tpalette::setActiveGradDia(bool active)
 	}
 }
 
-void Tpalette::setSpecialGradient(double x1, double y1, double x2, double y2, double fx, double fy, double sg, double sk)
+void TransparencyPalette::setSpecialGradient(double x1, double y1, double x2, double y2, double fx, double fy, double sg, double sk)
 {
 	if (TGradDia)
 		TGradDia->setValues(x1, y1, x2, y2, fx, fy, sg, sk, 0, 0);
 }
 
-void Tpalette::hideEditedPatterns(QStringList names)
+void TransparencyPalette::hideEditedPatterns(QStringList names)
 {
 	for (int a = 0; a < names.count(); a++)
 	{
@@ -443,13 +455,13 @@ void Tpalette::hideEditedPatterns(QStringList names)
 	}
 }
 
-void Tpalette::updatePatternList()
+void TransparencyPalette::updatePatternList()
 {
 	disconnect(patternBox, SIGNAL(itemClicked(QListWidgetItem*)), this, SLOT(selectPattern(QListWidgetItem*)));
 	patternBox->clear();
 	patternBox->setIconSize(QSize(48, 48));
 	QStringList patK = patternList->keys();
-	qSort(patK);
+	patK.sort();
 	for (int a = 0; a < patK.count(); a++)
 	{
 		ScPattern sp = patternList->value(patK[a]);
@@ -471,20 +483,20 @@ void Tpalette::updatePatternList()
 	connect(patternBox, SIGNAL(itemClicked(QListWidgetItem*)), this, SLOT(selectPattern(QListWidgetItem*)));
 }
 
-void Tpalette::setPatterns(QHash<QString, ScPattern> *docPatterns)
+void TransparencyPalette::setPatterns(QHash<QString, ScPattern> *docPatterns)
 {
 	patternList = docPatterns;
 	updatePatternList();
 }
 
-void Tpalette::selectPattern(QListWidgetItem *c)
+void TransparencyPalette::selectPattern(QListWidgetItem *c)
 {
 	if (c == nullptr)
 		return;
 	emit NewPattern(c->text());
 }
 
-void Tpalette::setActPattern(const QString& pattern, double scaleX, double scaleY, double offsetX, double offsetY, double rotation, double skewX, double skewY, bool mirrorX, bool mirrorY)
+void TransparencyPalette::setActPattern(const QString& pattern, double scaleX, double scaleY, double offsetX, double offsetY, double rotation, double skewX, double skewY, bool mirrorX, bool mirrorY)
 {
 	disconnect(patternBox, SIGNAL(itemClicked(QListWidgetItem*)), this, SLOT(selectPattern(QListWidgetItem*)));
 	QList<QListWidgetItem*> itl = patternBox->findItems(pattern, Qt::MatchExactly);
@@ -507,7 +519,7 @@ void Tpalette::setActPattern(const QString& pattern, double scaleX, double scale
 	connect(patternBox, SIGNAL(itemClicked(QListWidgetItem*)), this, SLOT(selectPattern(QListWidgetItem*)));
 }
 
-void Tpalette::changePatternProps()
+void TransparencyPalette::changePatternProps()
 {
 	PatternPropsDialog *dia = new PatternPropsDialog(this, currentUnit, false);
 	dia->spinXscaling->setValue(m_Pattern_scaleX);
@@ -541,7 +553,7 @@ void Tpalette::changePatternProps()
 	delete dia;
 }
 
-void Tpalette::setActTrans(double val, double val2)
+void TransparencyPalette::setActTrans(double val, double val2)
 {
 	disconnect(strokeOpacity, SIGNAL(valueChanged(double)), this, SLOT(slotTransS(double)));
 	disconnect(fillOpacity, SIGNAL(valueChanged(double)), this, SLOT(slotTransF(double)));
@@ -551,7 +563,7 @@ void Tpalette::setActTrans(double val, double val2)
 	connect(fillOpacity, SIGNAL(valueChanged(double)), this, SLOT(slotTransF(double)));
 }
 
-void Tpalette::setActBlend(int val, int val2)
+void TransparencyPalette::setActBlend(int val, int val2)
 {
 	disconnect(blendModeFill, SIGNAL(activated(int)), this, SIGNAL(NewBlend(int)));
 	disconnect(blendModeStroke, SIGNAL(activated(int)), this, SIGNAL(NewBlendS(int)));
@@ -561,17 +573,17 @@ void Tpalette::setActBlend(int val, int val2)
 	connect(blendModeStroke, SIGNAL(activated(int)), this, SIGNAL(NewBlendS(int)));
 }
 
-void Tpalette::slotTransS(double val)
+void TransparencyPalette::slotTransS(double val)
 {
 	emit NewTransS((100 - val) / 100.0);
 }
 
-void Tpalette::slotTransF(double val)
+void TransparencyPalette::slotTransF(double val)
 {
 	emit NewTrans((100 - val) / 100.0);
 }
 
-void Tpalette::editLineSelectorButton()
+void TransparencyPalette::editLineSelectorButton()
 {
 	if (editLineSelector->isChecked())
 	{
@@ -581,7 +593,7 @@ void Tpalette::editLineSelectorButton()
 	updateFromItem();
 }
 
-void Tpalette::editFillSelectorButton()
+void TransparencyPalette::editFillSelectorButton()
 {
 	if (editFillSelector->isChecked())
 	{
@@ -591,7 +603,7 @@ void Tpalette::editFillSelectorButton()
 	updateFromItem();
 }
 
-void Tpalette::unitChange(double, double, int unitIndex)
+void TransparencyPalette::unitChange(double, double, int unitIndex)
 {
 	if (TGradDia)
 		TGradDia->unitChange(unitIndex);
