@@ -40,9 +40,9 @@ class SCRIBUS_API FormatsManager
 		{
             ALLIMAGES 		= 1|2|4|8|16|32|64|128|256|512|1024|2048|4096|8192|16384|32768|524288|1048576|2097152|4194304|8388608,
 #ifdef GMAGICK_FOUND
-            IMAGESIMGFRAME	= 1|2|4|16|32|64|128|256|512|65536|1048576|2097152|4194304|8388608,  // all Types suitable for Image Frames
+            IMAGESIMGFRAME	= 1|2|4|16|32|64|128|256|512|32768|65536|1048576|2097152|4194304|8388608,  // all Types suitable for Image Frames
 #else
-            IMAGESIMGFRAME	= 1|2|4|16|32|64|128|256|512|262144|524288|1048576|2097152|4194304|8388608,  // all Types suitable for Image Frames
+            IMAGESIMGFRAME	= 1|2|4|16|32|64|128|256|512|32768|262144|524288|1048576|2097152|4194304|8388608,  // all Types suitable for Image Frames
 #endif
 			VECTORIMAGES	= 1|64|1024|2048|16384|32768|131072|262144|4194304,  // All pure vector image types
             RASTORIMAGES	= 2|4|8|32|128|256|512|65536|524288|1048576|2097152|8388608,  // All pure rastor image types
@@ -103,7 +103,7 @@ class SCRIBUS_API FormatsManager
 		};
 */
 		FormatsManager();
-		~FormatsManager();
+		~FormatsManager() = default;
 
 	/**
 		 * @brief Returns a pointer to the FormatsManager instance
@@ -115,21 +115,21 @@ class SCRIBUS_API FormatsManager
 		 * Must be called when FormatsManager is no longer needed.
 	 */
 		static void deleteInstance();
-		void imageFormatSupported(const QString&);
+
 		//! Returns the name of a format, eg "Encapsulated PostScript"
-		QString nameOfFormat(int type);
+		QString nameOfFormat(int type) const;
 		
 		//! Returns the mimetypes of a format, eg "application/postscript"
-		QStringList mimetypeOfFormat(int type);
+		QStringList mimetypeOfFormat(int type) const;
 		
 		//! Returns in the form of "EPS (*.eps *.EPS *.epsf *.EPSF *.epsi *.EPSI)"
-		QString extensionsForFormat(int type);
+		QString extensionsForFormat(int type) const;
 		
 		//! Returns in the form of "*.eps *.epsf *.epsi" or "eps|epsf|epsi"
- 		QString extensionListForFormat(int type, int listType);
+ 		QString extensionListForFormat(int type, int listType) const;
 		
 		//! Returns in the form of "All Supported Formats (*.eps *.EPS *.epsf *.EPSF *.epsi *.EPSI);;EPS (*.eps *.EPS);;EPSI (*.epsf *.EPSF);;EPSI (*.epsi *.EPSI);;All Files (*)"
-		QString fileDialogFormatList(int type);
+		QString fileDialogFormatList(int type) const;
 		
 	protected:
 		QMap<int, QString> m_fmtNames;
@@ -139,8 +139,9 @@ class SCRIBUS_API FormatsManager
 		
 		QList<QByteArray> m_qtSupportedImageFormats;
 		QList<QByteArray> m_supportedImageFormats;
-		void updateSupportedImageFormats(QList<QByteArray>& supportedImageFormats);
-		void fileTypeStrings(int type, QString& formatList, QString& formatText, QString& formatAll, bool lowerCaseOnly=false);
+
+		void updateSupportedImageFormats(QList<QByteArray>& supportedImageFormats) const;
+		void fileTypeStrings(int type, QString& formatList, QString& formatText, QString& formatAll, bool lowerCaseOnly=false) const;
 		
 	private:
 	/**
