@@ -28,10 +28,11 @@ int findParagraphStyle(ScribusDoc* doc, const ParagraphStyle& parStyle)
 	//qDebug() << QString("looking up %1/ %2").arg(parStyle.name()).arg(parStyle.alignment()); 
 	if (named)
 	{
-		for (int i=0; i < doc->paragraphStyles().count(); ++i)
+		const auto& paragraphStyles = doc->paragraphStyles();
+		for (int i=0; i < paragraphStyles.count(); ++i)
 		{
 			//qDebug() << QString("%1 %2").arg(i).arg(doc->paragraphStyles()[i].name());
-			if (parStyle.name() == doc->paragraphStyles()[i].name()) {
+			if (parStyle.name() == paragraphStyles[i].name()) {
 				return i;
 			}
 		}
@@ -42,7 +43,12 @@ int findParagraphStyle(ScribusDoc* doc, const ParagraphStyle& parStyle)
 
 int findParagraphStyle(ScribusDoc* doc, const QString &name)
 {
-	for (int i=0; i < doc->paragraphStyles().count(); ++i)
+	// This make behavior consistent with findParagraphStyle(ScribusDoc*, const ParagraphStyle&)
+	// for unnamed styles
+	if (name.isEmpty())
+		return -1;
+
+	for (int i = 0; i < doc->paragraphStyles().count(); ++i)
 	{
 		if (name == doc->paragraphStyles()[i].name())
 			return i;
